@@ -46,7 +46,7 @@ class GUI_EXPORT QgsColorButton: public QPushButton
      * @param cdo Options for the color chooser dialog
      * @note changed in 1.9
      */
-    QgsColorButton( QWidget *parent = 0, QString cdt = "", QColorDialog::ColorDialogOptions cdo = 0 );
+    QgsColorButton( QWidget *parent = 0, const QString& cdt = "", const QColorDialog::ColorDialogOptions& cdo = 0 );
     ~QgsColorButton();
 
     /**
@@ -67,7 +67,7 @@ class GUI_EXPORT QgsColorButton: public QPushButton
      *
      * @param cdo Options for the color chooser dialog
      */
-    void setColorDialogOptions( QColorDialog::ColorDialogOptions cdo );
+    void setColorDialogOptions( const QColorDialog::ColorDialogOptions& cdo );
 
     /**
      * Returns the options for the color chooser dialog.
@@ -81,7 +81,7 @@ class GUI_EXPORT QgsColorButton: public QPushButton
      *
      * @param cdt Title for the color chooser dialog
      */
-    void setColorDialogTitle( QString cdt );
+    void setColorDialogTitle( const QString& cdt );
 
     /**
      * Returns the title, which the color chooser dialog shows.
@@ -121,39 +121,39 @@ class GUI_EXPORT QgsColorButton: public QPushButton
     void colorChanged( const QColor &color );
 
   protected:
-    void changeEvent( QEvent* e );
-    void showEvent( QShowEvent* e );
+    void changeEvent( QEvent* e ) override;
+    void showEvent( QShowEvent* e ) override;
     static const QPixmap& transpBkgrd();
 
     /**
      * Reimplemented to detect right mouse button clicks on the color button and allow dragging colors
      */
-    void mousePressEvent( QMouseEvent* e );
+    void mousePressEvent( QMouseEvent* e ) override;
 
     /**
      * Reimplemented to allow dragging colors from button
      */
-    void mouseMoveEvent( QMouseEvent *e );
+    void mouseMoveEvent( QMouseEvent *e ) override;
 
     /**
      * Reimplemented to allow color picking
      */
-    void mouseReleaseEvent( QMouseEvent *e );
+    void mouseReleaseEvent( QMouseEvent *e ) override;
 
     /**
      * Reimplemented to allow cancelling color pick via keypress, and sample via space bar press
      */
-    void keyPressEvent( QKeyEvent *e );
+    void keyPressEvent( QKeyEvent *e ) override;
 
     /**
      * Reimplemented to accept dragged colors
      */
-    void dragEnterEvent( QDragEnterEvent * e );
+    void dragEnterEvent( QDragEnterEvent * e ) override;
 
     /**
      * Reimplemented to accept dropped colors
      */
-    void dropEvent( QDropEvent *e );
+    void dropEvent( QDropEvent *e ) override;
 
   private:
     QString mColorDialogTitle;
