@@ -38,7 +38,7 @@ class GUI_EXPORT QgsColorWidget : public QWidget
 
   public:
 
-    /*! Specifies the color component which the widget alters
+    /** Specifies the color component which the widget alters
      */
     enum ColorComponent
     {
@@ -52,7 +52,7 @@ class GUI_EXPORT QgsColorWidget : public QWidget
       Alpha /*!< alpha component (opacity) of color */
     };
 
-    /**Construct a new color widget.
+    /** Construct a new color widget.
      * @param parent parent QWidget for the widget
      * @param component color component the widget alters
      */
@@ -60,19 +60,19 @@ class GUI_EXPORT QgsColorWidget : public QWidget
 
     virtual ~QgsColorWidget();
 
-    /**Returns the current color for the widget
+    /** Returns the current color for the widget
      * @returns current widget color
      * @see setColor
      */
     QColor color() const;
 
-    /**Returns the color component which the widget controls
+    /** Returns the color component which the widget controls
      * @returns color component for widget
      * @see setComponent
      */
     ColorComponent component() const { return mComponent; }
 
-    /**Returns the current value of the widget's color component
+    /** Returns the current value of the widget's color component
      * @returns value of color component, or -1 if widget has multiple components or an invalid color
      * set
      * @see setComponentValue
@@ -80,27 +80,27 @@ class GUI_EXPORT QgsColorWidget : public QWidget
      */
     int componentValue() const;
 
-    /**Create an icon for dragging colors
+    /** Create an icon for dragging colors
      * @param color for icon
      */
-    static QPixmap createDragIcon( const QColor color );
+    static QPixmap createDragIcon( const QColor &color );
 
   public slots:
 
-    /**Sets the color for the widget
+    /** Sets the color for the widget
      * @param color widget color
      * @param emitSignals set to true to emit the colorChanged signal after setting color
      * @see color
      */
-    virtual void setColor( const QColor color, const bool emitSignals = false );
+    virtual void setColor( const QColor &color, const bool emitSignals = false );
 
-    /**Sets the color component which the widget controls
+    /** Sets the color component which the widget controls
      * @param component color component for widget
      * @see component
      */
     virtual void setComponent( const ColorComponent component );
 
-    /**Alters the widget's color by setting the value for the widget's color component
+    /** Alters the widget's color by setting the value for the widget's color component
      * @param value value for widget's color component. This value is automatically
      * clipped to the range of valid values for the color component.
      * @see componentValue
@@ -112,10 +112,10 @@ class GUI_EXPORT QgsColorWidget : public QWidget
 
   signals:
 
-    /**Emitted when the widget's color changes
+    /** Emitted when the widget's color changes
      * @param color new widget color
      */
-    void colorChanged( const QColor color );
+    void colorChanged( const QColor &color );
 
   protected:
 
@@ -123,22 +123,22 @@ class GUI_EXPORT QgsColorWidget : public QWidget
 
     ColorComponent mComponent;
 
-    /**QColor wipes the hue information when it is ambiguous (eg, for saturation = 0). So
+    /** QColor wipes the hue information when it is ambiguous (eg, for saturation = 0). So
      * the hue is stored in mExplicit hue to keep it around, as it is useful when modifying colors
     */
     int mExplicitHue;
 
-    /**Returns the range of valid values for the color widget's component
+    /** Returns the range of valid values for the color widget's component
      * @returns maximum value allowed for color component, or -1 if widget has multiple components
      */
     int componentRange() const;
 
-    /**Returns the range of valid values a color component
+    /** Returns the range of valid values a color component
      * @returns maximum value allowed for color component
      */
     int componentRange( const ColorComponent component ) const;
 
-    /**Returns the value of a component of the widget's current color. This method correctly
+    /** Returns the value of a component of the widget's current color. This method correctly
      * handles hue values when the color has an ambiguous hue (eg black or white shades)
      * @param component color component to return
      * @returns value of color component, or -1 if widget has an invalid color set
@@ -146,13 +146,13 @@ class GUI_EXPORT QgsColorWidget : public QWidget
      */
     int componentValue( const ColorComponent component ) const;
 
-    /**Returns the hue for the widget. This may differ from the hue for the QColor returned by color(),
+    /** Returns the hue for the widget. This may differ from the hue for the QColor returned by color(),
      * as QColor returns a hue of -1 if the color's hue is ambiguous (eg, if the saturation is zero).
      * @returns explicitly set hue for widget
      */
     int hue() const;
 
-    /**Alters a color by modifiying the value of a specific color component
+    /** Alters a color by modifiying the value of a specific color component
      * @param color color to alter
      * @param component color component to alter
      * @param newValue new value of color component. Values are automatically clipped to a
@@ -160,16 +160,16 @@ class GUI_EXPORT QgsColorWidget : public QWidget
      */
     void alterColor( QColor& color, const QgsColorWidget::ColorComponent component, const int newValue ) const;
 
-    /**Generates a checkboard pattern pixmap for use as a background to transparent colors
+    /** Generates a checkboard pattern pixmap for use as a background to transparent colors
      * @returns checkerboard pixmap
      */
     static const QPixmap& transparentBackground();
 
     //Reimplemented to accept dragged colors
-    void dragEnterEvent( QDragEnterEvent * e );
+    void dragEnterEvent( QDragEnterEvent * e ) override;
 
     //Reimplemented to accept dropped colors
-    void dropEvent( QDropEvent *e );
+    void dropEvent( QDropEvent *e ) override;
 };
 
 
@@ -186,25 +186,25 @@ class GUI_EXPORT QgsColorWheel : public QgsColorWidget
 
   public:
 
-    /**Constructs a new color wheel widget.
+    /** Constructs a new color wheel widget.
      * @param parent parent QWidget for the widget
      */
     QgsColorWheel( QWidget* parent = 0 );
 
     virtual ~QgsColorWheel();
 
-    void paintEvent( QPaintEvent* event );
+    void paintEvent( QPaintEvent* event ) override;
 
   public slots:
 
-    virtual void setColor( const QColor color, const bool emitSignals = false );
+    virtual void setColor( const QColor &color, const bool emitSignals = false ) override;
 
   protected:
 
-    virtual void resizeEvent( QResizeEvent *event );
-    virtual void mouseMoveEvent( QMouseEvent *event );
-    virtual void mousePressEvent( QMouseEvent *event );
-    virtual void mouseReleaseEvent( QMouseEvent *event );
+    virtual void resizeEvent( QResizeEvent *event ) override;
+    virtual void mouseMoveEvent( QMouseEvent *event ) override;
+    virtual void mousePressEvent( QMouseEvent *event ) override;
+    virtual void mouseReleaseEvent( QMouseEvent *event ) override;
 
   private:
 
@@ -242,18 +242,18 @@ class GUI_EXPORT QgsColorWheel : public QgsColorWidget
     /*Conical gradient brush used for drawing hue wheel*/
     QBrush mWheelBrush;
 
-    /**Creates cache images for specified widget size
+    /** Creates cache images for specified widget size
      * @param size widget size for images
     */
     void createImages( const QSizeF size );
 
-    /**Creates the hue wheel image*/
+    /** Creates the hue wheel image*/
     void createWheel();
 
-    /**Creates the inner triangle image*/
+    /** Creates the inner triangle image*/
     void createTriangle();
 
-    /**Sets the widget color based on a point in the widget
+    /** Sets the widget color based on a point in the widget
      * @param pos position for color
     */
     void setColorFromPos( const QPointF pos );
@@ -275,7 +275,7 @@ class GUI_EXPORT QgsColorBox : public QgsColorWidget
 
   public:
 
-    /**Construct a new color box widget.
+    /** Construct a new color box widget.
      * @param parent parent QWidget for the widget
      * @param component constant color component for the widget. The color components
      * which vary along the horizontal and vertical axis are automatically assigned
@@ -285,20 +285,19 @@ class GUI_EXPORT QgsColorBox : public QgsColorWidget
 
     virtual ~QgsColorBox();
 
-    virtual QSize sizeHint() const;
-    void paintEvent( QPaintEvent* event );
+    virtual QSize sizeHint() const override;
+    void paintEvent( QPaintEvent* event ) override;
 
-    virtual void setComponent( const ColorComponent component );
+    virtual void setComponent( const ColorComponent component ) override;
 
   public slots:
-
-    virtual void setColor( const QColor color, const bool emitSignals = false );
+    virtual void setColor( const QColor &color, const bool emitSignals = false ) override;
 
   protected:
 
-    virtual void resizeEvent( QResizeEvent *event );
-    virtual void mouseMoveEvent( QMouseEvent *event );
-    virtual void mousePressEvent( QMouseEvent *event );
+    virtual void resizeEvent( QResizeEvent *event ) override;
+    virtual void mouseMoveEvent( QMouseEvent *event ) override;
+    virtual void mousePressEvent( QMouseEvent *event ) override;
 
   private:
 
@@ -311,37 +310,37 @@ class GUI_EXPORT QgsColorBox : public QgsColorWidget
     /*Whether the cached image requires redrawing*/
     bool mDirty;
 
-    /**Creates the color box background cached image
+    /** Creates the color box background cached image
     */
     void createBox();
 
-    /**Returns the range of permissible values along the x axis
+    /** Returns the range of permissible values along the x axis
      * @returns maximum color component value for x axis
     */
     int valueRangeX() const;
 
-    /**Returns the range of permissible values along the y axis
+    /** Returns the range of permissible values along the y axis
      * @returns maximum color component value for y axis
     */
     int valueRangeY() const;
 
-    /**Returns the color component which varies along the y axis
+    /** Returns the color component which varies along the y axis
     */
     QgsColorWidget::ColorComponent yComponent() const;
 
-    /**Returns the value of the color component which varies along the y axis
+    /** Returns the value of the color component which varies along the y axis
     */
     int yComponentValue() const;
 
-    /**Returns the color component which varies along the x axis
+    /** Returns the color component which varies along the x axis
     */
     QgsColorWidget::ColorComponent xComponent() const;
 
-    /**Returns the value of the color component which varies along the x axis
+    /** Returns the value of the color component which varies along the x axis
     */
     int xComponentValue() const;
 
-    /**Updates the widget's color based on a point within the widget
+    /** Updates the widget's color based on a point within the widget
      * @param point point within the widget
     */
     void setColorFromPoint( const QPoint& point );
@@ -362,7 +361,7 @@ class GUI_EXPORT QgsColorRampWidget : public QgsColorWidget
 
   public:
 
-    /*! Specifies the orientation of a color ramp
+    /** Specifies the orientation of a color ramp
      */
     enum Orientation
     {
@@ -370,7 +369,7 @@ class GUI_EXPORT QgsColorRampWidget : public QgsColorWidget
       Vertical /*!< vertical ramp */
     };
 
-    /**Construct a new color ramp widget.
+    /** Construct a new color ramp widget.
      * @param parent parent QWidget for the widget
      * @param component color component which varies along the ramp
      * @param orientation orientation for widget
@@ -381,62 +380,62 @@ class GUI_EXPORT QgsColorRampWidget : public QgsColorWidget
 
     virtual ~QgsColorRampWidget();
 
-    virtual QSize sizeHint() const;
-    void paintEvent( QPaintEvent* event );
+    virtual QSize sizeHint() const override;
+    void paintEvent( QPaintEvent* event ) override;
 
-    /**Sets the orientation for the color ramp
+    /** Sets the orientation for the color ramp
      * @param orientation new orientation for the ramp
      * @see orientation
      */
     void setOrientation( const Orientation orientation );
 
-    /**Fetches the orientation for the color ramp
+    /** Fetches the orientation for the color ramp
      * @returns orientation for the ramp
      * @see setOrientation
      */
     Orientation orientation() const { return mOrientation; }
 
-    /**Sets the margin between the edge of the widget and the ramp
+    /** Sets the margin between the edge of the widget and the ramp
      * @param margin margin around the ramp
      * @see interiorMargin
      */
     void setInteriorMargin( const int margin );
 
-    /**Fetches the margin between the edge of the widget and the ramp
+    /** Fetches the margin between the edge of the widget and the ramp
      * @returns margin around the ramp
      * @see setInteriorMargin
      */
     int interiorMargin() const { return mMargin; }
 
-    /**Sets whether the ramp should be drawn within a frame
+    /** Sets whether the ramp should be drawn within a frame
      * @param showFrame set to true to draw a frame around the ramp
      * @see showFrame
      */
     void setShowFrame( const bool showFrame );
 
-    /**Fetches whether the ramp is drawn within a frame
+    /** Fetches whether the ramp is drawn within a frame
      * @returns true if a frame is drawn around the ramp
      * @see setShowFrame
      */
     bool showFrame() const { return mShowFrame; }
 
-    /**Sets the size for drawing the triangular markers on the ramp
+    /** Sets the size for drawing the triangular markers on the ramp
      * @param markerSize marker size in pixels
      */
     void setMarkerSize( const int markerSize );
 
   signals:
 
-    /**Emitted when the widget's color component value changes
+    /** Emitted when the widget's color component value changes
      * @param value new value of color component
      */
     void valueChanged( const int value );
 
   protected:
 
-    virtual void mouseMoveEvent( QMouseEvent *event );
-    virtual void mousePressEvent( QMouseEvent *event );
-    virtual void keyPressEvent( QKeyEvent * event );
+    virtual void mouseMoveEvent( QMouseEvent *event ) override;
+    virtual void mousePressEvent( QMouseEvent *event ) override;
+    virtual void keyPressEvent( QKeyEvent * event ) override;
 
   private:
 
@@ -455,7 +454,7 @@ class GUI_EXPORT QgsColorRampWidget : public QgsColorWidget
     /*Polygon for lower triangle marker*/
     QPolygonF mBottomTriangle;
 
-    /**Updates the widget's color based on a point within the widget
+    /** Updates the widget's color based on a point within the widget
      * @param point point within the widget
     */
     void setColorFromPoint( const QPointF &point );
@@ -475,7 +474,7 @@ class GUI_EXPORT QgsColorSliderWidget : public QgsColorWidget
 
   public:
 
-    /**Construct a new color slider widget.
+    /** Construct a new color slider widget.
      * @param parent parent QWidget for the widget
      * @param component color component which is controlled by the slider
      */
@@ -483,9 +482,9 @@ class GUI_EXPORT QgsColorSliderWidget : public QgsColorWidget
 
     virtual ~QgsColorSliderWidget();
 
-    virtual void setComponent( const ColorComponent component );
-    virtual void setComponentValue( const int value );
-    virtual void setColor( const QColor color, const bool emitSignals = false );
+    virtual void setComponent( const ColorComponent component ) override;
+    virtual void setComponentValue( const int value ) override;
+    virtual void setColor( const QColor &color, const bool emitSignals = false ) override;
 
   private:
 
@@ -495,7 +494,7 @@ class GUI_EXPORT QgsColorSliderWidget : public QgsColorWidget
     /*Spin box widget*/
     QSpinBox* mSpinBox;
 
-    /**Converts the real value of a color component to a friendly display value. For instance,
+    /** Converts the real value of a color component to a friendly display value. For instance,
      * alpha values from 0-255 have little meaning to users, so we translate them to 0-100%
      * @param realValue actual value of the color component
      * @returns display value of color component
@@ -503,7 +502,7 @@ class GUI_EXPORT QgsColorSliderWidget : public QgsColorWidget
     */
     int convertRealToDisplay( const int realValue ) const;
 
-    /**Converts the display value of a color component to a real value.
+    /** Converts the display value of a color component to a real value.
      * @param displayValue friendly display value of the color component
      * @returns real value of color component
      * @see convertRealToDisplay
@@ -512,15 +511,15 @@ class GUI_EXPORT QgsColorSliderWidget : public QgsColorWidget
 
   private slots:
 
-    /**Called when the color for the ramp changes
+    /** Called when the color for the ramp changes
     */
-    void rampColorChanged( const QColor color );
+    void rampColorChanged( const QColor &color );
 
-    /**Called when the value of the spin box changes
+    /** Called when the value of the spin box changes
     */
     void spinChanged( int value );
 
-    /**Called when the value for the ramp changes
+    /** Called when the value for the ramp changes
     */
     void rampChanged( int value );
 
@@ -540,21 +539,21 @@ class GUI_EXPORT QgsColorTextWidget : public QgsColorWidget
 
   public:
 
-    /**Construct a new color line edit widget.
+    /** Construct a new color line edit widget.
      * @param parent parent QWidget for the widget
      */
     QgsColorTextWidget( QWidget* parent = 0 );
 
     virtual ~QgsColorTextWidget();
 
-    virtual void setColor( const QColor color, const bool emitSignals = false );
+    virtual void setColor( const QColor &color, const bool emitSignals = false ) override;
 
   protected:
-    void resizeEvent( QResizeEvent * event );
+    void resizeEvent( QResizeEvent * event ) override;
 
   private:
 
-    /*! Specifies the display format for a color
+    /** Specifies the display format for a color
      */
     enum ColorTextFormat
     {
@@ -572,17 +571,17 @@ class GUI_EXPORT QgsColorTextWidget : public QgsColorWidget
     /*Display format for colors*/
     ColorTextFormat mFormat;
 
-    /**Updates the text based on the current color
+    /** Updates the text based on the current color
     */
     void updateText();
 
   private slots:
 
-    /**Called when the user enters text into the widget
+    /** Called when the user enters text into the widget
     */
     void textChanged();
 
-    /**Called when the dropdown arrow is clicked to show the format selection menu
+    /** Called when the dropdown arrow is clicked to show the format selection menu
     */
     void showMenu();
 };
@@ -600,16 +599,16 @@ class GUI_EXPORT QgsColorPreviewWidget : public QgsColorWidget
 
   public:
 
-    /**Construct a new color preview widget.
+    /** Construct a new color preview widget.
      * @param parent parent QWidget for the widget
      */
     QgsColorPreviewWidget( QWidget* parent = 0 );
 
     virtual ~QgsColorPreviewWidget();
 
-    void paintEvent( QPaintEvent* event );
+    void paintEvent( QPaintEvent* event ) override;
 
-    /**Returns the secondary color for the widget
+    /** Returns the secondary color for the widget
      * @returns secondary widget color, or an invalid color if the widget
      * has no secondary color
      * @see color
@@ -619,7 +618,7 @@ class GUI_EXPORT QgsColorPreviewWidget : public QgsColorWidget
 
   public slots:
 
-    /**Sets the second color for the widget
+    /** Sets the second color for the widget
      * @param color secondary widget color. Set to an invalid color to prevent
      * drawing of a secondary color
      * @see setColor
@@ -630,13 +629,13 @@ class GUI_EXPORT QgsColorPreviewWidget : public QgsColorWidget
   protected:
 
     //reimplemented to allow dragging colors
-    void mousePressEvent( QMouseEvent* e );
+    void mousePressEvent( QMouseEvent* e ) override;
 
     //reimplemented to click colors
-    void mouseReleaseEvent( QMouseEvent* e );
+    void mouseReleaseEvent( QMouseEvent* e ) override;
 
     //reimplemented to allow dragging colors
-    void mouseMoveEvent( QMouseEvent *e );
+    void mouseMoveEvent( QMouseEvent *e ) override;
 
   private:
 
