@@ -17,11 +17,11 @@
 #define QGSCOMPOSERHTML_H
 
 #include "qgscomposermultiframe.h"
+#include "qgsfeature.h"
 #include <QUrl>
 
 class QWebPage;
 class QImage;
-class QgsFeature;
 class QgsVectorLayer;
 class QgsNetworkContentFetcher;
 class QgsDistanceArea;
@@ -43,7 +43,7 @@ class CORE_EXPORT QgsComposerHtml: public QgsComposerMultiFrame
 
     ~QgsComposerHtml();
 
-    /**Sets the source mode for item's HTML content.
+    /** Sets the source mode for item's HTML content.
      * @param mode ContentMode for the item's source
      * @see contentMode
      * @see setUrl
@@ -52,7 +52,7 @@ class CORE_EXPORT QgsComposerHtml: public QgsComposerMultiFrame
      */
     void setContentMode( ContentMode mode ) { mContentMode = mode; }
 
-    /**Returns the source mode for item's HTML content.
+    /** Returns the source mode for item's HTML content.
      * @returns ContentMode for the item's source
      * @see setContentMode
      * @see url
@@ -61,7 +61,7 @@ class CORE_EXPORT QgsComposerHtml: public QgsComposerMultiFrame
      */
     ContentMode contentMode() const { return mContentMode; }
 
-    /**Sets the URL for content to display in the item when the item is using
+    /** Sets the URL for content to display in the item when the item is using
      * the QgsComposerHtml::Url mode. Content is automatically fetched and the
      * HTML item refreshed after calling this function.
      * @param url URL of content to display in the item
@@ -70,7 +70,7 @@ class CORE_EXPORT QgsComposerHtml: public QgsComposerMultiFrame
      */
     void setUrl( const QUrl& url );
 
-    /**Returns the URL of the content displayed in the item if the item is using
+    /** Returns the URL of the content displayed in the item if the item is using
      * the QgsComposerHtml::Url mode.
      * @returns url for content displayed in item
      * @see setUrl
@@ -78,7 +78,7 @@ class CORE_EXPORT QgsComposerHtml: public QgsComposerMultiFrame
      */
     const QUrl& url() const { return mUrl; }
 
-    /**Sets the HTML to display in the item when the item is using
+    /** Sets the HTML to display in the item when the item is using
      * the QgsComposerHtml::ManualHtml mode. Setting the HTML using this function
      * does not automatically refresh the item's contents. Call loadHtml to trigger
      * a refresh of the item after setting the HTML content.
@@ -88,9 +88,9 @@ class CORE_EXPORT QgsComposerHtml: public QgsComposerMultiFrame
      * @see loadHtml
      * @note added in 2.5
      */
-    void setHtml( const QString html );
+    void setHtml( const QString& html );
 
-    /**Returns the HTML source displayed in the item if the item is using
+    /** Returns the HTML source displayed in the item if the item is using
      * the QgsComposerHtml::ManualHtml mode.
      * @returns HTML displayed in item
      * @see setHtml
@@ -99,7 +99,7 @@ class CORE_EXPORT QgsComposerHtml: public QgsComposerMultiFrame
      */
     QString html() const { return mHtml; }
 
-    /**Returns whether html item will evaluate QGIS expressions prior to rendering
+    /** Returns whether html item will evaluate QGIS expressions prior to rendering
      * the HTML content. If set, any content inside [% %] tags will be
      * treated as a QGIS expression and evaluated against the current atlas
      * feature.
@@ -109,7 +109,7 @@ class CORE_EXPORT QgsComposerHtml: public QgsComposerMultiFrame
      */
     bool evaluateExpressions() const { return mEvaluateExpressions; }
 
-    /**Sets whether the html item will evaluate QGIS expressions prior to rendering
+    /** Sets whether the html item will evaluate QGIS expressions prior to rendering
      * the HTML content. If set, any content inside [% %] tags will be
      * treated as a QGIS expression and evaluated against the current atlas
      * feature.
@@ -119,14 +119,14 @@ class CORE_EXPORT QgsComposerHtml: public QgsComposerMultiFrame
      */
     void setEvaluateExpressions( bool evaluateExpressions );
 
-    /**Returns whether html item is using smart breaks. Smart breaks prevent
+    /** Returns whether html item is using smart breaks. Smart breaks prevent
      * the html frame contents from breaking mid-way though a line of text.
      * @returns true if html item is using smart breaks
      * @see setUseSmartBreaks
      */
     bool useSmartBreaks() const { return mUseSmartBreaks; }
 
-    /**Sets whether the html item should use smart breaks. Smart breaks prevent
+    /** Sets whether the html item should use smart breaks. Smart breaks prevent
      * the html frame contents from breaking mid-way though a line of text.
      * @param useSmartBreaks set to true to prevent content from breaking
      * mid-way through a line of text
@@ -134,7 +134,7 @@ class CORE_EXPORT QgsComposerHtml: public QgsComposerMultiFrame
      */
     void setUseSmartBreaks( bool useSmartBreaks );
 
-    /**Sets the maximum distance allowed when calculating where to place page breaks
+    /** Sets the maximum distance allowed when calculating where to place page breaks
      * in the html. This distance is the maximum amount of empty space allowed
      * at the bottom of a frame after calculating the optimum break location. Setting
      * a larger value will result in better choice of page break location, but more
@@ -148,7 +148,7 @@ class CORE_EXPORT QgsComposerHtml: public QgsComposerMultiFrame
      */
     void setMaxBreakDistance( double maxBreakDistance );
 
-    /**Returns the maximum distance allowed when calculating where to place page breaks
+    /** Returns the maximum distance allowed when calculating where to place page breaks
      * in the html. This distance is the maximum amount of empty space allowed
      * at the bottom of a frame after calculating the optimum break location. This setting
      * is only effective if useSmartBreaks is true.
@@ -159,7 +159,7 @@ class CORE_EXPORT QgsComposerHtml: public QgsComposerMultiFrame
      */
     double maxBreakDistance() const { return mMaxBreakDistance; }
 
-    /**Sets the user stylesheet CSS rules to use while rendering the HTML content. These
+    /** Sets the user stylesheet CSS rules to use while rendering the HTML content. These
      * allow for overriding the styles specified within the HTML source. Setting the stylesheet
      * using this function does not automatically refresh the item's contents. Call loadHtml
      * to trigger a refresh of the item after setting the stylesheet rules.
@@ -169,9 +169,9 @@ class CORE_EXPORT QgsComposerHtml: public QgsComposerMultiFrame
      * @see loadHtml
      * @note added in 2.5
      */
-    void setUserStylesheet( const QString stylesheet );
+    void setUserStylesheet( const QString& stylesheet );
 
-    /**Returns the user stylesheet CSS rules used while rendering the HTML content. These
+    /** Returns the user stylesheet CSS rules used while rendering the HTML content. These
      * overriding the styles specified within the HTML source.
      * @returns CSS rules for user stylesheet
      * @see setUserStylesheet
@@ -180,7 +180,7 @@ class CORE_EXPORT QgsComposerHtml: public QgsComposerMultiFrame
      */
     QString userStylesheet() const { return mUserStylesheet; }
 
-    /**Sets whether user stylesheets are enabled for the HTML content.
+    /** Sets whether user stylesheets are enabled for the HTML content.
      * @param stylesheetEnabled set to true to enable user stylesheets
      * @see userStylesheetEnabled
      * @see setUserStylesheet
@@ -188,7 +188,7 @@ class CORE_EXPORT QgsComposerHtml: public QgsComposerMultiFrame
      */
     void setUserStylesheetEnabled( const bool stylesheetEnabled );
 
-    /**Returns whether user stylesheets are enabled for the HTML content.
+    /** Returns whether user stylesheets are enabled for the HTML content.
      * @returns true if user stylesheets are enabled
      * @see setUserStylesheetEnabled
      * @see userStylesheet
@@ -207,19 +207,20 @@ class CORE_EXPORT QgsComposerHtml: public QgsComposerMultiFrame
 
   public slots:
 
-    /**Reloads the html source from the url and redraws the item.
+    /** Reloads the html source from the url and redraws the item.
      * @param useCache set to true to use a cached copy of remote html
      * content
+     * @param context expression context for evaluating data defined urls and expressions in html
      * @see setUrl
      * @see url
      */
-    void loadHtml( const bool useCache = false );
+    void loadHtml( const bool useCache = false, const QgsExpressionContext* context = 0 );
 
-    /**Recalculates the frame sizes for the current viewport dimensions*/
+    /** Recalculates the frame sizes for the current viewport dimensions*/
     void recalculateFrameSizes() override;
     void refreshExpressionContext();
 
-    virtual void refreshDataDefinedProperty( const QgsComposerObject::DataDefinedProperty property = QgsComposerObject::AllProperties ) override;
+    virtual void refreshDataDefinedProperty( const QgsComposerObject::DataDefinedProperty property = QgsComposerObject::AllProperties, const QgsExpressionContext* context = 0 ) override;
 
   private slots:
     void frameLoaded( bool ok = true );
@@ -240,7 +241,7 @@ class CORE_EXPORT QgsComposerHtml: public QgsComposerMultiFrame
     bool mUseSmartBreaks;
     double mMaxBreakDistance;
 
-    QgsFeature* mExpressionFeature;
+    QgsFeature mExpressionFeature;
     QgsVectorLayer* mExpressionLayer;
     QgsDistanceArea* mDistanceArea;
 
@@ -255,12 +256,12 @@ class CORE_EXPORT QgsComposerHtml: public QgsComposerMultiFrame
     void renderCachedImage();
 
     //fetches html content from a url and returns it as a string
-    QString fetchHtml( QUrl url );
+    QString fetchHtml( const QUrl& url );
 
     /** Sets the current feature, the current layer and a list of local variable substitutions for evaluating expressions */
-    void setExpressionContext( QgsFeature* feature, QgsVectorLayer* layer );
+    void setExpressionContext( const QgsFeature& feature, QgsVectorLayer* layer );
 
-    /**calculates the max width of frames in the html multiframe*/
+    /** Calculates the max width of frames in the html multiframe*/
     double maxFrameWidth() const;
 };
 
