@@ -55,7 +55,7 @@ class CORE_EXPORT QgsComposerMap : public QgsComposerItem
     QgsComposerMap( QgsComposition *composition );
     virtual ~QgsComposerMap();
 
-    /** return correct graphics item type. */
+    /** Return correct graphics item type. */
     virtual int type() const override { return ComposerMap; }
 
     /** \brief Preview style  */
@@ -113,7 +113,7 @@ class CORE_EXPORT QgsComposerMap : public QgsComposerItem
       LineBorder
     };
 
-    /**Enum for different frame borders*/
+    /** Enum for different frame borders*/
     enum Border
     {
       Left,
@@ -159,18 +159,18 @@ class CORE_EXPORT QgsComposerMap : public QgsComposerItem
     /** \brief Get identification number*/
     int id() const {return mId;}
 
-    /**True if a draw is already in progress*/
+    /** True if a draw is already in progress*/
     bool isDrawing() const {return mDrawing;}
 
-    /** resizes an item in x- and y direction (canvas coordinates)*/
+    /** Resizes an item in x- and y direction (canvas coordinates)*/
     void resize( double dx, double dy );
 
-    /**Move content of map
+    /** Move content of map
        @param dx move in x-direction (item and canvas coordinates)
        @param dy move in y-direction (item and canvas coordinates)*/
     void moveContent( double dx, double dy ) override;
 
-    /**Zoom content of map
+    /** Zoom content of map
      * @param delta value from wheel event that describes direction (positive /negative number)
      * @param x x-position of mouse cursor (in item coordinates)
      * @param y y-position of mouse cursor (in item coordinates)
@@ -178,7 +178,7 @@ class CORE_EXPORT QgsComposerMap : public QgsComposerItem
     */
     Q_DECL_DEPRECATED void zoomContent( int delta, double x, double y ) override;
 
-    /**Zoom content of item. Does nothing per default (but implemented in composer map)
+    /** Zoom content of item. Does nothing per default (but implemented in composer map)
      * @param factor zoom factor, where > 1 results in a zoom in and < 1 results in a zoom out
      * @param point item point for zoom center
      * @param mode zoom mode
@@ -186,16 +186,16 @@ class CORE_EXPORT QgsComposerMap : public QgsComposerItem
     */
     virtual void zoomContent( const double factor, const QPointF point, const ZoomMode mode = QgsComposerItem::Zoom ) override;
 
-    /**Sets new scene rectangle bounds and recalculates hight and extent*/
+    /** Sets new scene rectangle bounds and recalculates hight and extent*/
     void setSceneRect( const QRectF& rectangle ) override;
 
     /** \brief Scale */
     double scale() const;
 
-    /**Sets new scale and changes only mExtent*/
+    /** Sets new scale and changes only mExtent*/
     void setNewScale( double scaleDenominator, bool forceUpdate = true );
 
-    /**Sets new extent for the map. This method may change the width or height of the map
+    /** Sets new extent for the map. This method may change the width or height of the map
      * item to ensure that the extent exactly matches the specified extent, with no
      * overlap or margin. This method implicitly alters the map scale.
      * @param extent new extent for the map
@@ -203,7 +203,7 @@ class CORE_EXPORT QgsComposerMap : public QgsComposerItem
     */
     void setNewExtent( const QgsRectangle& extent );
 
-    /**Zooms the map so that the specified extent is fully visible within the map item.
+    /** Zooms the map so that the specified extent is fully visible within the map item.
      * This method will not change the width or height of the map, and may result in
      * an overlap or margin from the specified extent. This method implicitly alters the
      * map scale.
@@ -213,17 +213,17 @@ class CORE_EXPORT QgsComposerMap : public QgsComposerItem
     */
     void zoomToExtent( const QgsRectangle& extent );
 
-    /**Sets new Extent for the current atlas preview and changes width, height (and implicitely also scale).
+    /** Sets new Extent for the current atlas preview and changes width, height (and implicitely also scale).
       Atlas preview extents are only temporary, and are regenerated whenever the atlas feature changes
     */
     void setNewAtlasFeatureExtent( const QgsRectangle& extent );
 
-    /**Called when atlas preview is toggled, to force map item to update its extent and redraw
+    /** Called when atlas preview is toggled, to force map item to update its extent and redraw
      * @deprecated no longer required
     */
     Q_DECL_DEPRECATED void toggleAtlasPreview() {}
 
-    /**Returns a pointer to the current map extent, which is either the original user specified
+    /** Returns a pointer to the current map extent, which is either the original user specified
      * extent or the temporary atlas-driven feature extent depending on the current atlas state
      * of the composition. Both a const and non-const version are included.
      * @returns pointer to current map extent
@@ -235,28 +235,28 @@ class CORE_EXPORT QgsComposerMap : public QgsComposerItem
     PreviewMode previewMode() const {return mPreviewMode;}
     void setPreviewMode( PreviewMode m );
 
-    /**Getter for flag that determines if the stored layer set should be used or the current layer set of the qgis mapcanvas */
+    /** Getter for flag that determines if the stored layer set should be used or the current layer set of the qgis mapcanvas */
     bool keepLayerSet() const {return mKeepLayerSet;}
-    /**Setter for flag that determines if the stored layer set should be used or the current layer set of the qgis mapcanvas */
+    /** Setter for flag that determines if the stored layer set should be used or the current layer set of the qgis mapcanvas */
     void setKeepLayerSet( bool enabled ) {mKeepLayerSet = enabled;}
 
-    /**Getter for stored layer set that is used if mKeepLayerSet is true */
+    /** Getter for stored layer set that is used if mKeepLayerSet is true */
     QStringList layerSet() const {return mLayerSet;}
-    /**Setter for stored layer set that is used if mKeepLayerSet is true */
+    /** Setter for stored layer set that is used if mKeepLayerSet is true */
     void setLayerSet( const QStringList& layerSet ) {mLayerSet = layerSet;}
-    /**Stores the current layer set of the qgis mapcanvas in mLayerSet*/
+    /** Stores the current layer set of the qgis mapcanvas in mLayerSet*/
     void storeCurrentLayerSet();
 
-    /**Getter for flag that determines if current styles of layers should be overridden by previously stored styles. @note added in 2.8 */
+    /** Getter for flag that determines if current styles of layers should be overridden by previously stored styles. @note added in 2.8 */
     bool keepLayerStyles() const { return mKeepLayerStyles; }
-    /**Setter for flag that determines if current styles of layers should be overridden by previously stored styles. @note added in 2.8 */
+    /** Setter for flag that determines if current styles of layers should be overridden by previously stored styles. @note added in 2.8 */
     void setKeepLayerStyles( bool enabled ) { mKeepLayerStyles = enabled; }
 
-    /**Getter for stored overrides of styles for layers. @note added in 2.8 */
+    /** Getter for stored overrides of styles for layers. @note added in 2.8 */
     QMap<QString, QString> layerStyleOverrides() const { return mLayerStyleOverrides; }
-    /**Setter for stored overrides of styles for layers. @note added in 2.8 */
+    /** Setter for stored overrides of styles for layers. @note added in 2.8 */
     void setLayerStyleOverrides( const QMap<QString, QString>& overrides );
-    /**Stores the current layer styles into style overrides. @note added in 2.8 */
+    /** Stores the current layer styles into style overrides. @note added in 2.8 */
     void storeCurrentLayerStyles();
 
     // Set cache outdated
@@ -267,28 +267,28 @@ class CORE_EXPORT QgsComposerMap : public QgsComposerItem
     //! @deprecated since 2.4 - use mapSettings() - may return 0 if not initialized with QgsMapRenderer
     Q_DECL_DEPRECATED const QgsMapRenderer* mapRenderer() const;
 
-    /**Sets offset values to shift image (useful for live updates when moving item content)*/
+    /** Sets offset values to shift image (useful for live updates when moving item content)*/
     void setOffset( double xOffset, double yOffset );
 
-    /**True if composer map renders a WMS layer*/
+    /** True if composer map renders a WMS layer*/
     bool containsWMSLayer() const;
 
-    /**True if composer map contains layers with blend modes or flattened layers for vectors */
+    /** True if composer map contains layers with blend modes or flattened layers for vectors */
     bool containsAdvancedEffects() const;
 
-    /** stores state in Dom node
+    /** Stores state in Dom node
      * @param elem is Dom element corresponding to 'Composer' tag
      * @param doc Dom document
      */
     bool writeXML( QDomElement& elem, QDomDocument & doc ) const override;
 
-    /** sets state from Dom document
+    /** Sets state from Dom document
      * @param itemElem is Dom node corresponding to 'ComposerMap' tag
      * @param doc is Dom document
      */
     bool readXML( const QDomElement& itemElem, const QDomDocument& doc ) override;
 
-    /**Enables a coordinate grid that is shown on top of this composermap.
+    /** Enables a coordinate grid that is shown on top of this composermap.
      * @deprecated use grid()->setEnabled() or grids() instead
      */
     Q_DECL_DEPRECATED void setGridEnabled( bool enabled );
@@ -298,7 +298,7 @@ class CORE_EXPORT QgsComposerMap : public QgsComposerItem
      */
     Q_DECL_DEPRECATED bool gridEnabled() const;
 
-    /**Sets coordinate grid style to solid or cross
+    /** Sets coordinate grid style to solid or cross
      * @deprecated use grid()->setStyle() or grids() instead
     */
     Q_DECL_DEPRECATED void setGridStyle( GridStyle style );
@@ -308,7 +308,7 @@ class CORE_EXPORT QgsComposerMap : public QgsComposerItem
      */
     Q_DECL_DEPRECATED GridStyle gridStyle() const;
 
-    /**Sets coordinate interval in x-direction for composergrid.
+    /** Sets coordinate interval in x-direction for composergrid.
      * @deprecated use grid()->setIntervalX() or grids() instead
     */
     Q_DECL_DEPRECATED void setGridIntervalX( double interval );
@@ -318,7 +318,7 @@ class CORE_EXPORT QgsComposerMap : public QgsComposerItem
      */
     Q_DECL_DEPRECATED double gridIntervalX() const;
 
-    /**Sets coordinate interval in y-direction for composergrid.
+    /** Sets coordinate interval in y-direction for composergrid.
      * @deprecated use grid()->setIntervalY() or grids() instead
     */
     Q_DECL_DEPRECATED void setGridIntervalY( double interval );
@@ -328,7 +328,7 @@ class CORE_EXPORT QgsComposerMap : public QgsComposerItem
      */
     Q_DECL_DEPRECATED double gridIntervalY() const;
 
-    /**Sets x-coordinate offset for composer grid
+    /** Sets x-coordinate offset for composer grid
      * @deprecated use grid()->setOffsetX() or grids() instead
     */
     Q_DECL_DEPRECATED void setGridOffsetX( double offset );
@@ -338,7 +338,7 @@ class CORE_EXPORT QgsComposerMap : public QgsComposerItem
      */
     Q_DECL_DEPRECATED double gridOffsetX() const;
 
-    /**Sets y-coordinate offset for composer grid
+    /** Sets y-coordinate offset for composer grid
      * @deprecated use grid()->setOffsetY() or grids() instead
     */
     Q_DECL_DEPRECATED void setGridOffsetY( double offset );
@@ -348,7 +348,7 @@ class CORE_EXPORT QgsComposerMap : public QgsComposerItem
      */
     Q_DECL_DEPRECATED double gridOffsetY() const;
 
-    /**Sets the pen to draw composer grid
+    /** Sets the pen to draw composer grid
      * @deprecated use grid()->setPenWidth(), grid()->setPenColor() or grids() instead
     */
     Q_DECL_DEPRECATED void setGridPen( const QPen& p );
@@ -358,17 +358,17 @@ class CORE_EXPORT QgsComposerMap : public QgsComposerItem
      */
     Q_DECL_DEPRECATED QPen gridPen() const;
 
-    /**Sets width of grid pen
+    /** Sets width of grid pen
      * @deprecated use grid()->setPenWidth() or grids() instead
     */
     Q_DECL_DEPRECATED void setGridPenWidth( double w );
 
-    /**Sets the color of the grid pen
+    /** Sets the color of the grid pen
      * @deprecated use grid()->setPenColor() or grids() instead
     */
     Q_DECL_DEPRECATED void setGridPenColor( const QColor& c );
 
-    /**Sets font for grid annotations
+    /** Sets font for grid annotations
      * @deprecated use grid()->setAnnotationFont() or grids() instead
     */
     Q_DECL_DEPRECATED void setGridAnnotationFont( const QFont& f );
@@ -378,17 +378,17 @@ class CORE_EXPORT QgsComposerMap : public QgsComposerItem
      */
     Q_DECL_DEPRECATED QFont gridAnnotationFont() const;
 
-    /**Sets font color for grid annotations
+    /** Sets font color for grid annotations
      * @deprecated use grid()->setAnnotationFontColor() or grids() instead
     */
     Q_DECL_DEPRECATED void setAnnotationFontColor( const QColor& c );
 
-    /**Get font color for grid annotations
+    /** Get font color for grid annotations
      * @deprecated use grid()->annotationFontColor() or grids() instead
     */
     Q_DECL_DEPRECATED QColor annotationFontColor() const;
 
-    /**Sets coordinate precision for grid annotations
+    /** Sets coordinate precision for grid annotations
      * @deprecated use grid()->setAnnotationPrecision or grids() instead
     */
     Q_DECL_DEPRECATED void setGridAnnotationPrecision( int p );
@@ -398,7 +398,7 @@ class CORE_EXPORT QgsComposerMap : public QgsComposerItem
      */
     Q_DECL_DEPRECATED int gridAnnotationPrecision() const;
 
-    /**Sets flag if grid annotation should be shown
+    /** Sets flag if grid annotation should be shown
      * @deprecated use grid()->setAnnotationEnabled() or grids() instead
     */
     Q_DECL_DEPRECATED void setShowGridAnnotation( bool show );
@@ -418,7 +418,7 @@ class CORE_EXPORT QgsComposerMap : public QgsComposerItem
      */
     Q_DECL_DEPRECATED GridAnnotationPosition gridAnnotationPosition( QgsComposerMap::Border border ) const;
 
-    /**Sets distance between map frame and annotations
+    /** Sets distance between map frame and annotations
      * @deprecated use grid()->setAnnotationFrameDistance() or grids() instead
     */
     Q_DECL_DEPRECATED void setAnnotationFrameDistance( double d );
@@ -448,7 +448,7 @@ class CORE_EXPORT QgsComposerMap : public QgsComposerItem
      */
     Q_DECL_DEPRECATED GridAnnotationFormat gridAnnotationFormat() const;
 
-    /**Set grid frame style (NoGridFrame or Zebra)
+    /** Set grid frame style (NoGridFrame or Zebra)
      * @deprecated use grid()->setFrameStyle() or grids() instead
     */
     Q_DECL_DEPRECATED void setGridFrameStyle( GridFrameStyle style );
@@ -458,7 +458,7 @@ class CORE_EXPORT QgsComposerMap : public QgsComposerItem
      */
     Q_DECL_DEPRECATED GridFrameStyle gridFrameStyle() const;
 
-    /**Set grid frame width
+    /** Set grid frame width
      * @deprecated use grid()->setFrameWidth() or grids() instead
     */
     Q_DECL_DEPRECATED void setGridFrameWidth( double w );
@@ -468,7 +468,7 @@ class CORE_EXPORT QgsComposerMap : public QgsComposerItem
      */
     Q_DECL_DEPRECATED double gridFrameWidth() const;
 
-    /**Set grid frame pen thickness
+    /** Set grid frame pen thickness
      * @note: this function was added in version 2.1
      * @deprecated use grid()->setFramePenSize() or grids() instead
     */
@@ -479,43 +479,43 @@ class CORE_EXPORT QgsComposerMap : public QgsComposerItem
      */
     Q_DECL_DEPRECATED double gridFramePenSize() const;
 
-    /**Sets pen color for grid frame
+    /** Sets pen color for grid frame
      * @note: this function was added in version 2.1
      * @deprecated use grid()->setFramePenColor() or grids() instead
     */
     Q_DECL_DEPRECATED void setGridFramePenColor( const QColor& c );
 
-    /**Get pen color for grid frame
+    /** Get pen color for grid frame
      * @note: this function was added in version 2.1
      * @deprecated use grid()->framePenColor() or grids() instead
     */
     Q_DECL_DEPRECATED QColor gridFramePenColor() const;
 
-    /**Sets first fill color for grid zebra frame
+    /** Sets first fill color for grid zebra frame
      * @note: this function was added in version 2.1
      * @deprecated use grid()->setFrameFillColor1() or grids() instead
     */
     Q_DECL_DEPRECATED void setGridFrameFillColor1( const QColor& c );
 
-    /**Get first fill color for grid zebra frame
+    /** Get first fill color for grid zebra frame
      * @note: this function was added in version 2.1
      * @deprecated use grid()->frameFillColor1() or grids() instead
     */
     Q_DECL_DEPRECATED QColor gridFrameFillColor1() const;
 
-    /**Sets second fill color for grid zebra frame
+    /** Sets second fill color for grid zebra frame
      * @note: this function was added in version 2.1
      * @deprecated use grid()->setFrameFillColor2() or grids() instead
     */
     Q_DECL_DEPRECATED void setGridFrameFillColor2( const QColor& c );
 
-    /**Get second fill color for grid zebra frame
+    /** Get second fill color for grid zebra frame
      * @note: this function was added in version 2.1
      * @deprecated use grid()->frameFillColor2() or grids() instead
     */
     Q_DECL_DEPRECATED QColor gridFrameFillColor2() const;
 
-    /**Sets length of the cross segments (if grid style is cross)
+    /** Sets length of the cross segments (if grid style is cross)
      * @deprecated use grid()->setCrossLength() or grids() instead
     */
     Q_DECL_DEPRECATED void setCrossLength( double l );
@@ -545,7 +545,7 @@ class CORE_EXPORT QgsComposerMap : public QgsComposerItem
      */
     Q_DECL_DEPRECATED void setGridBlendMode( QPainter::CompositionMode blendMode );
 
-    /**Returns the map item's grid stack, which is used to control how grids
+    /** Returns the map item's grid stack, which is used to control how grids
      * are drawn over the map's contents.
      * @returns pointer to grid stack
      * @see grid()
@@ -553,14 +553,14 @@ class CORE_EXPORT QgsComposerMap : public QgsComposerItem
      */
     QgsComposerMapGridStack* grids() { return mGridStack; }
 
-    /**Returns the map item's first grid. This is a convenience function.
+    /** Returns the map item's first grid. This is a convenience function.
      * @returns pointer to first grid for map item
      * @see grids()
      * @note introduced in QGIS 2.5
      */
     QgsComposerMapGrid* grid();
 
-    /**Returns the map item's overview stack, which is used to control how overviews
+    /** Returns the map item's overview stack, which is used to control how overviews
      * are drawn over the map's contents.
      * @returns pointer to overview stack
      * @see overview()
@@ -568,36 +568,36 @@ class CORE_EXPORT QgsComposerMap : public QgsComposerItem
      */
     QgsComposerMapOverviewStack* overviews() { return mOverviewStack; }
 
-    /**Returns the map item's first overview. This is a convenience function.
+    /** Returns the map item's first overview. This is a convenience function.
      * @returns pointer to first overview for map item
      * @see overviews()
      * @note introduced in QGIS 2.5
      */
     QgsComposerMapOverview* overview();
 
-    /**In case of annotations, the bounding rectangle can be larger than the map item rectangle */
+    /** In case of annotations, the bounding rectangle can be larger than the map item rectangle */
     QRectF boundingRect() const override;
 
     /* reimplement setFrameOutlineWidth, so that updateBoundingRect() is called after setting the frame width */
     virtual void setFrameOutlineWidth( const double outlineWidth ) override;
 
-    /**Sets rotation for the map - this does not affect the composer item shape, only the
+    /** Sets rotation for the map - this does not affect the composer item shape, only the
       way the map is drawn within the item
      * @deprecated Use setMapRotation( double rotation ) instead
      */
     Q_DECL_DEPRECATED void setRotation( double r ) override;
 
-    /**Returns the rotation used for drawing the map within the composer item
+    /** Returns the rotation used for drawing the map within the composer item
      * @deprecated Use mapRotation() instead
      */
     Q_DECL_DEPRECATED double rotation() const { return mMapRotation;}
 
-    /**Sets rotation for the map - this does not affect the composer item shape, only the
+    /** Sets rotation for the map - this does not affect the composer item shape, only the
       way the map is drawn within the item
       @note this function was added in version 2.1*/
     void setMapRotation( double r );
 
-    /**Returns the rotation used for drawing the map within the composer item
+    /** Returns the rotation used for drawing the map within the composer item
      * @returns rotation for map
      * @param valueType controls whether the returned value is the user specified rotation,
      * or the current evaluated rotation (which may be affected by data driven rotation
@@ -607,21 +607,21 @@ class CORE_EXPORT QgsComposerMap : public QgsComposerItem
 
     void updateItem() override;
 
-    /**Sets canvas pointer (necessary to query and draw map canvas items)*/
+    /** Sets canvas pointer (necessary to query and draw map canvas items)*/
     void setMapCanvas( QGraphicsView* canvas ) { mMapCanvas = canvas; }
 
     void setDrawCanvasItems( bool b ) { mDrawCanvasItems = b; }
     bool drawCanvasItems() const { return mDrawCanvasItems; }
 
-    /**Returns the conversion factor map units -> mm*/
+    /** Returns the conversion factor map units -> mm*/
     double mapUnitsToMM() const;
 
-    /**Sets overview frame map. -1 disables the overview frame
+    /** Sets overview frame map. -1 disables the overview frame
      * @deprecated use overview()->setFrameMap() or overviews() instead
     */
     Q_DECL_DEPRECATED void setOverviewFrameMap( int mapId );
 
-    /**Returns id of overview frame (or -1 if no overfiew frame)
+    /** Returns id of overview frame (or -1 if no overfiew frame)
      * @deprecated use overview()->frameMapId() or overviews() instead
     */
     Q_DECL_DEPRECATED int overviewFrameMapId() const;
@@ -666,51 +666,51 @@ class CORE_EXPORT QgsComposerMap : public QgsComposerItem
     */
     Q_DECL_DEPRECATED void setOverviewCentered( bool centered );
 
-    /**Sets mId to a number not yet used in the composition. mId is kept if it is not in use.
+    /** Sets mId to a number not yet used in the composition. mId is kept if it is not in use.
         Usually, this function is called before adding the composer map to the composition*/
     void assignFreeId();
 
-    /**Calculates width and hight of the picture (in mm) such that it fits into the item frame with the given rotation
+    /** Calculates width and hight of the picture (in mm) such that it fits into the item frame with the given rotation
      * @deprecated Use bool QgsComposerItem::imageSizeConsideringRotation( double& width, double& height, double rotation )
      * instead
      */
     Q_DECL_DEPRECATED bool imageSizeConsideringRotation( double& width, double& height ) const;
-    /**Calculates corner point after rotation and scaling
+    /** Calculates corner point after rotation and scaling
      * @deprecated Use QgsComposerItem::cornerPointOnRotatedAndScaledRect( double& x, double& y, double width, double height, double rotation )
      * instead
      */
     Q_DECL_DEPRECATED bool cornerPointOnRotatedAndScaledRect( double& x, double& y, double width, double height ) const;
-    /**Calculates width / height of the bounding box of a rotated rectangle
+    /** Calculates width / height of the bounding box of a rotated rectangle
     * @deprecated Use QgsComposerItem::sizeChangedByRotation( double& width, double& height, double rotation )
     * instead
     */
     Q_DECL_DEPRECATED void sizeChangedByRotation( double& width, double& height );
 
-    /**Returns whether the map extent is set to follow the current atlas feature.
+    /** Returns whether the map extent is set to follow the current atlas feature.
      * @returns true if map will follow the current atlas feature.
      * @see setAtlasDriven
      * @see atlasScalingMode
     */
     bool atlasDriven() const { return mAtlasDriven; }
 
-    /**Sets whether the map extent will follow the current atlas feature.
+    /** Sets whether the map extent will follow the current atlas feature.
      * @param enabled set to true if the map extents should be set by the current atlas feature.
      * @see atlasDriven
      * @see setAtlasScalingMode
     */
     void setAtlasDriven( bool enabled );
 
-    /**Returns true if the map uses a fixed scale when in atlas mode
+    /** Returns true if the map uses a fixed scale when in atlas mode
      * @deprecated since 2.4 Use atlasScalingMode() instead
     */
     Q_DECL_DEPRECATED bool atlasFixedScale() const;
 
-    /**Set to true if the map should use a fixed scale when in atlas mode
+    /** Set to true if the map should use a fixed scale when in atlas mode
      * @deprecated since 2.4 Use setAtlasScalingMode() instead
     */
     Q_DECL_DEPRECATED void setAtlasFixedScale( bool fixed );
 
-    /**Returns the current atlas scaling mode. This controls how the map's extents
+    /** Returns the current atlas scaling mode. This controls how the map's extents
      * are calculated for the current atlas feature when an atlas composition
      * is enabled.
      * @returns the current scaling mode
@@ -720,7 +720,7 @@ class CORE_EXPORT QgsComposerMap : public QgsComposerItem
     */
     AtlasScalingMode atlasScalingMode() const { return mAtlasScalingMode; }
 
-    /**Sets the current atlas scaling mode. This controls how the map's extents
+    /** Sets the current atlas scaling mode. This controls how the map's extents
      * are calculated for the current atlas feature when an atlas composition
      * is enabled.
      * @param mode atlas scaling mode to set
@@ -730,7 +730,7 @@ class CORE_EXPORT QgsComposerMap : public QgsComposerItem
     */
     void setAtlasScalingMode( AtlasScalingMode mode ) { mAtlasScalingMode = mode; }
 
-    /**Returns the margin size (percentage) used when the map is in atlas mode.
+    /** Returns the margin size (percentage) used when the map is in atlas mode.
      * @param valueType controls whether the returned value is the user specified atlas margin,
      * or the current evaluated atlas margin (which may be affected by data driven atlas margin
      * settings).
@@ -741,7 +741,7 @@ class CORE_EXPORT QgsComposerMap : public QgsComposerItem
     */
     double atlasMargin( const QgsComposerObject::PropertyValueType valueType = QgsComposerObject::EvaluatedValue );
 
-    /**Sets the margin size (percentage) used when the map is in atlas mode.
+    /** Sets the margin size (percentage) used when the map is in atlas mode.
      * @param margin size in percentage to leave around the atlas feature's extent
      * @note this is only used if atlasScalingMode() is Auto.
      * @see atlasScalingMode
@@ -755,14 +755,14 @@ class CORE_EXPORT QgsComposerMap : public QgsComposerItem
     /** Returns whether updates to the composer map are enabled. */
     bool updatesEnabled() const { return mUpdatesEnabled; }
 
-    /**Get the number of layers that this item requires for exporting as layers
+    /** Get the number of layers that this item requires for exporting as layers
      * @returns 0 if this item is to be placed on the same layer as the previous item,
      * 1 if it should be placed on its own layer, and >1 if it requires multiple export layers
      * @note this method was added in version 2.4
     */
     int numberExportLayers() const override;
 
-    /**Returns a polygon representing the current visible map extent, considering map extents and rotation.
+    /** Returns a polygon representing the current visible map extent, considering map extents and rotation.
      * If the map rotation is 0, the result is the same as currentMapExtent
      * @returns polygon with the four corner points representing the visible map extent. The points are
      * clockwise, starting at the top-left point
@@ -773,25 +773,27 @@ class CORE_EXPORT QgsComposerMap : public QgsComposerItem
     //overriden to show "Map 1" type names
     virtual QString displayName() const override;
 
-    /**Returns extent that considers rotation and shift with mOffsetX / mOffsetY*/
+    /** Returns extent that considers rotation and shift with mOffsetX / mOffsetY*/
     QPolygonF transformedMapPolygon() const;
 
-    /**Transforms map coordinates to item coordinates (considering rotation and move offset)*/
+    /** Transforms map coordinates to item coordinates (considering rotation and move offset)*/
     QPointF mapToItemCoords( const QPointF& mapCoords ) const;
 
     Q_DECL_DEPRECATED void connectMapOverviewSignals();
 
-    /**Calculates the extent to request and the yShift of the top-left point in case of rotation.
+    /** Calculates the extent to request and the yShift of the top-left point in case of rotation.
      * @note added in 2.6 */
     void requestedExtent( QgsRectangle& extent ) const;
 
+    virtual QgsExpressionContext* createExpressionContext() const override;
+
   signals:
     void extentChanged();
 
-    /**Is emitted on rotation change to notify north arrow pictures*/
+    /** Is emitted on rotation change to notify north arrow pictures*/
     void mapRotationChanged( double newRotation );
 
-    /**Is emitted when the map has been prepared for atlas rendering, just before actual rendering*/
+    /** Is emitted when the map has been prepared for atlas rendering, just before actual rendering*/
     void preparedForAtlas();
 
     /** Emitted when layer style overrides are changed... a means to let
@@ -802,25 +804,25 @@ class CORE_EXPORT QgsComposerMap : public QgsComposerItem
 
   public slots:
 
-    /**Forces an update of the cached map image*/
+    /** Forces an update of the cached map image*/
     void updateCachedImage();
 
-    /**Updates the cached map image if the map is set to Render mode
+    /** Updates the cached map image if the map is set to Render mode
      * @see updateCachedImage
     */
     void renderModeUpdateCachedImage();
 
-    /**Updates the bounding rect of this item. Call this function before doing any changes related to annotation out of the map rectangle */
+    /** Updates the bounding rect of this item. Call this function before doing any changes related to annotation out of the map rectangle */
     void updateBoundingRect();
 
-    /**@deprecated use QgsComposerMapOverview::overviewExtentChanged instead*/
+    /** @deprecated use QgsComposerMapOverview::overviewExtentChanged instead*/
     void overviewExtentChanged() {}
 
-    virtual void refreshDataDefinedProperty( const QgsComposerObject::DataDefinedProperty property = QgsComposerObject::AllProperties ) override;
+    virtual void refreshDataDefinedProperty( const QgsComposerObject::DataDefinedProperty property = QgsComposerObject::AllProperties, const QgsExpressionContext* context = 0 ) override;
 
   protected slots:
 
-    /**Called when layers are added or removed from the layer registry. Updates the maps
+    /** Called when layers are added or removed from the layer registry. Updates the maps
      * layer set and redraws the map if required.
      * @note added in QGIS 2.9
     */
@@ -828,7 +830,7 @@ class CORE_EXPORT QgsComposerMap : public QgsComposerItem
 
   private:
 
-    /**Unique identifier*/
+    /** Unique identifier*/
     int mId;
 
     QgsComposerMapGridStack* mGridStack;
@@ -860,74 +862,77 @@ class CORE_EXPORT QgsComposerMap : public QgsComposerItem
     /** \brief set to true if in state of drawing. Concurrent requests to draw method are returned if set to true */
     bool mDrawing;
 
-    /**Offset in x direction for showing map cache image*/
+    /** Offset in x direction for showing map cache image*/
     double mXOffset;
-    /**Offset in y direction for showing map cache image*/
+    /** Offset in y direction for showing map cache image*/
     double mYOffset;
 
-    /**Map rotation*/
+    /** Map rotation*/
     double mMapRotation;
-    /**Temporary evaluated map rotation. Data defined rotation may mean this value
+    /** Temporary evaluated map rotation. Data defined rotation may mean this value
      * differs from mMapRotation*/
     double mEvaluatedMapRotation;
 
-    /**Flag if layers to be displayed should be read from qgis canvas (true) or from stored list in mLayerSet (false)*/
+    /** Flag if layers to be displayed should be read from qgis canvas (true) or from stored list in mLayerSet (false)*/
     bool mKeepLayerSet;
 
-    /**Stored layer list (used if layer live-link mKeepLayerSet is disabled)*/
+    /** Stored layer list (used if layer live-link mKeepLayerSet is disabled)*/
     QStringList mLayerSet;
 
     bool mKeepLayerStyles;
-    /**Stored style names (value) to be used with particular layer IDs (key) instead of default style */
+    /** Stored style names (value) to be used with particular layer IDs (key) instead of default style */
     QMap<QString, QString> mLayerStyleOverrides;
 
     /** Whether updates to the map are enabled */
     bool mUpdatesEnabled;
 
-    /**Establishes signal/slot connection for update in case of layer change*/
+    /** Establishes signal/slot connection for update in case of layer change*/
     void connectUpdateSlot();
 
-    /**Removes layer ids from mLayerSet that are no longer present in the qgis main map*/
+    /** Removes layer ids from mLayerSet that are no longer present in the qgis main map*/
     void syncLayerSet();
 
-    /**Returns first map grid or creates an empty one if none*/
+    /** Returns first map grid or creates an empty one if none*/
     const QgsComposerMapGrid* constFirstMapGrid() const;
 
-    /**Returns first map overview or creates an empty one if none*/
+    /** Returns first map overview or creates an empty one if none*/
     const QgsComposerMapOverview* constFirstMapOverview() const;
 
-    /**Current bounding rectangle. This is used to check if notification to the graphics scene is necessary*/
+    /** Current bounding rectangle. This is used to check if notification to the graphics scene is necessary*/
     QRectF mCurrentRectangle;
     QGraphicsView* mMapCanvas;
-    /**True if annotation items, rubber band, etc. from the main canvas should be displayed*/
+    /** True if annotation items, rubber band, etc. from the main canvas should be displayed*/
     bool mDrawCanvasItems;
 
-    /**Adjusts an extent rectangle to match the provided item width and height, so that extent
+    /** Adjusts an extent rectangle to match the provided item width and height, so that extent
      * center of extent remains the same */
     void adjustExtentToItemShape( double itemWidth, double itemHeight, QgsRectangle& extent ) const;
 
-    /**True if map is being controlled by an atlas*/
+    /** True if map is being controlled by an atlas*/
     bool mAtlasDriven;
-    /**Current atlas scaling mode*/
+    /** Current atlas scaling mode*/
     AtlasScalingMode mAtlasScalingMode;
-    /**Margin size for atlas driven extents (percentage of feature size) - when in auto scaling mode*/
+    /** Margin size for atlas driven extents (percentage of feature size) - when in auto scaling mode*/
     double mAtlasMargin;
 
     void init();
 
-    /**Resets the item tooltip to reflect current map id*/
+    /** Resets the item tooltip to reflect current map id*/
     void updateToolTip();
 
-    /**Returns a list of the layers to render for this map item*/
-    QStringList layersToRender() const;
+    /** Returns a list of the layers to render for this map item*/
+    QStringList layersToRender( const QgsExpressionContext* context = 0 ) const;
 
-    /**Returns extent that considers mOffsetX / mOffsetY (during content move)*/
+    /** Returns current layer style overrides for this map item*/
+    QMap<QString, QString> layerStyleOverridesToRender( const QgsExpressionContext& context ) const;
+
+    /** Returns extent that considers mOffsetX / mOffsetY (during content move)*/
     QgsRectangle transformedExtent() const;
 
-    /** mapPolygon variant using a given extent */
+    /** MapPolygon variant using a given extent */
     void mapPolygon( const QgsRectangle& extent, QPolygonF& poly ) const;
 
-    /**Scales a composer map shift (in MM) and rotates it by mRotation
+    /** Scales a composer map shift (in MM) and rotates it by mRotation
         @param xShift in: shift in x direction (in item units), out: xShift in map units
         @param yShift in: shift in y direction (in item units), out: yShift in map units*/
     void transformShift( double& xShift, double& yShift ) const;
@@ -946,15 +951,17 @@ class CORE_EXPORT QgsComposerMap : public QgsComposerItem
       SelectionBoxes
     };
 
-    /**Test if a part of the copmosermap needs to be drawn, considering mCurrentExportLayer*/
+    /** Test if a part of the copmosermap needs to be drawn, considering mCurrentExportLayer*/
     bool shouldDrawPart( PartType part ) const;
 
-    /**Refresh the map's extents, considering data defined extent, scale and rotation
+    /** Refresh the map's extents, considering data defined extent, scale and rotation
+     * @param context expression context for evaluating data defined map parameters
      * @note this method was added in version 2.5
      */
-    void refreshMapExtents();
+    void refreshMapExtents( const QgsExpressionContext* context = 0 );
 
     friend class QgsComposerMapOverview; //to access mXOffset, mYOffset
+    friend class TestQgsComposerMap;
 };
 Q_NOWARN_DEPRECATED_POP
 
