@@ -8,25 +8,25 @@
 // <int>.<int>.<int>-<any text>.
 // or else upgrading old project file will not work
 // reliably.
-#define VERSION "2.10.1-Pisa"
+#define VERSION "2.12.3-Lyon"
 
 //used in vim src/core/qgis.cpp
 //The way below should work but it resolves to a number like 0110 which the compiler treats as octal I think
 //because debuggin it out shows the decimal number 72 which results in incorrect version status.
 //As a short term fix I (Tim) am defining the version in top level cmake. It would be good to 
 //reinstate this more generic approach below at some point though
-//#define VERSION_INT 2101
-#define VERSION_INT 21001
-#define ABISYM(x) x ## 21001
+//#define VERSION_INT 2123
+#define VERSION_INT 21203
+#define ABISYM(x) x ## 21203
 //used in main.cpp and anywhere else where the release name is needed
-#define RELEASE_NAME "Pisa"
+#define RELEASE_NAME "Lyon"
 
 #define QGIS_PLUGIN_SUBDIR "lib/qgis/plugins"
 #define QGIS_DATA_SUBDIR "share/qgis"
 #define QGIS_LIBEXEC_SUBDIR "lib/qgis"
 #define QGIS_LIB_SUBDIR "lib"
 #define CMAKE_INSTALL_PREFIX "/usr/local"
-#define CMAKE_SOURCE_DIR "/usr/obj/qgis-2.10.1/qgis-2.10.1"
+#define CMAKE_SOURCE_DIR "/usr/obj/ports/qgis-2.12.3/qgis-2.12.3"
 
 #define QSCINTILLA_VERSION_STR "2.8"
 
