@@ -53,7 +53,7 @@ class CORE_EXPORT QgsCoordinateTransform : public QObject
 {
     Q_OBJECT
   public:
-    /*! Default constructor. Make sure you use initialised() manually if you use this one! */
+    /** Default constructor. Make sure you use initialised() manually if you use this one! */
     QgsCoordinateTransform();
 
     /** Constructs a QgsCoordinateTransform using QgsCoordinateReferenceSystem objects.
@@ -72,7 +72,7 @@ class CORE_EXPORT QgsCoordinateTransform : public QObject
      * @param theSourceWkt Wkt, typically of the layer's coordinate system
      * @param theDestWkt Wkt, typically of the map canvas coordinate system
      */
-    QgsCoordinateTransform( QString theSourceWkt, QString theDestWkt );
+    QgsCoordinateTransform( const QString& theSourceWkt, const QString& theDestWkt );
 
     /*!
      * Constructs a QgsCoordinateTransform using a Spatial Reference Id
@@ -82,7 +82,7 @@ class CORE_EXPORT QgsCoordinateTransform : public QObject
      * @param theSourceCRSType On of the enum members defined in QgsCoordinateReferenceSystem::CrsType
      */
     QgsCoordinateTransform( long theSourceSrid,
-                            QString theDestWkt,
+                            const QString& theDestWkt,
                             QgsCoordinateReferenceSystem::CrsType theSourceCRSType = QgsCoordinateReferenceSystem::PostgisCrsId );
 
     //! destructor
@@ -121,16 +121,16 @@ class CORE_EXPORT QgsCoordinateTransform : public QObject
      */
     const QgsCoordinateReferenceSystem& destCRS() const { return mDestCRS; }
 
-    /*! Transform the point from Source Coordinate System to Destination Coordinate System
+    /** Transform the point from Source Coordinate System to Destination Coordinate System
      * If the direction is ForwardTransform then coordinates are transformed from layer CS --> map canvas CS,
      * otherwise points are transformed from map canvas CS to layerCS.
      * @param p Point to transform
      * @param direction TransformDirection (defaults to ForwardTransform)
      * @return QgsPoint in Destination Coordinate System
      */
-    QgsPoint transform( const QgsPoint p, TransformDirection direction = ForwardTransform ) const;
+    QgsPoint transform( const QgsPoint &p, TransformDirection direction = ForwardTransform ) const;
 
-    /*! Transform the point specified by x,y from Source Coordinate System to Destination Coordinate System
+    /** Transform the point specified by x,y from Source Coordinate System to Destination Coordinate System
      * If the direction is ForwardTransform then coordinates are transformed from layer CS --> map canvas CS,
      * otherwise points are transformed from map canvas CS to layerCS.
      * @param x x cordinate of point to transform
@@ -140,7 +140,7 @@ class CORE_EXPORT QgsCoordinateTransform : public QObject
      */
     QgsPoint transform( const double x, const double y, TransformDirection direction = ForwardTransform ) const;
 
-    /*! Transform a QgsRectangle to the dest Coordinate system
+    /** Transform a QgsRectangle to the dest Coordinate system
      * If the direction is ForwardTransform then coordinates are transformed from layer CS --> map canvas CS,
      * otherwise points are transformed from map canvas CS to layerCS.
      * It assumes that rect is a bounding box, and creates a bounding box
@@ -152,15 +152,18 @@ class CORE_EXPORT QgsCoordinateTransform : public QObject
      * longitude line is required
      * @return QgsRectangle in Destination Coordinate System
      */
-    QgsRectangle transformBoundingBox( const QgsRectangle theRect, TransformDirection direction = ForwardTransform, const bool handle180Crossover = false ) const;
+    QgsRectangle transformBoundingBox( const QgsRectangle &theRect, TransformDirection direction = ForwardTransform, const bool handle180Crossover = false ) const;
 
     // Same as for the other transform() functions, but alters the x
     // and y variables in place. The second one works with good old-fashioned
     // C style arrays.
     void transformInPlace( double& x, double& y, double &z, TransformDirection direction = ForwardTransform ) const;
-#ifdef QT_ARCH_ARM
-    void transformInPlace( qreal& x, qreal& y, double &z, TransformDirection direction = ForwardTransform ) const;
-#endif
+    void transformInPlace( float& x, float& y, double &z, TransformDirection direction = ForwardTransform ) const;
+    void transformInPlace( float& x, float& y, float& z, TransformDirection direction = ForwardTransform ) const;
+
+    void transformInPlace( QVector<float>& x, QVector<float>& y, QVector<float>& z,
+                           TransformDirection direction = ForwardTransform ) const;
+
 
     //! @note not available in python bindings
     void transformInPlace( QVector<double>& x, QVector<double>& y, QVector<double>& z,
@@ -168,23 +171,16 @@ class CORE_EXPORT QgsCoordinateTransform : public QObject
 
     void transformPolygon( QPolygonF& poly, TransformDirection direction = ForwardTransform ) const;
 
-#ifdef ANDROID
-    void transformInPlace( float& x, float& y, float& z, TransformDirection direction = ForwardTransform ) const;
-
-    void transformInPlace( QVector<float>& x, QVector<float>& y, QVector<float>& z,
-                           TransformDirection direction = ForwardTransform ) const;
-#endif
-
-    /*! Transform a QgsRectangle to the dest Coordinate system
+    /** Transform a QgsRectangle to the dest Coordinate system
      * If the direction is ForwardTransform then coordinates are transformed from layer CS --> map canvas CS,
      * otherwise points are transformed from map canvas CS to layerCS.
      * @param theRect rect to transform
      * @param direction TransformDirection (defaults to ForwardTransform)
      * @return QgsRectangle in Destination Coordinate System
      */
-    QgsRectangle transform( const QgsRectangle theRect, TransformDirection direction = ForwardTransform ) const;
+    QgsRectangle transform( const QgsRectangle &theRect, TransformDirection direction = ForwardTransform ) const;
 
-    /*! Transform an array of coordinates to a different Coordinate System
+    /** Transform an array of coordinates to a different Coordinate System
      * If the direction is ForwardTransform then coordinates are transformed from layer CS --> map canvas CS,
      * otherwise points are transformed from map canvas CS to layerCS.
      * @param numPoint number of coordinates in arrays
@@ -200,14 +196,14 @@ class CORE_EXPORT QgsCoordinateTransform : public QObject
      * Flag to indicate whether the coordinate systems have been initialised
      * @return true if initialised, otherwise false
      */
-    bool isInitialised() const {return mInitialisedFlag;};
+    bool isInitialised() const {return mInitialisedFlag;}
 
-    /*! See if the transform short circuits because src and dest are equivalent
+    /** See if the transform short circuits because src and dest are equivalent
      * @return bool True if it short circuits
      */
-    bool isShortCircuited() {return mShortCircuit;};
+    bool isShortCircuited() {return mShortCircuit;}
 
-    /*! Change the destination coordinate system by passing it a qgis srsid
+    /** Change the destination coordinate system by passing it a qgis srsid
     * A QGIS srsid is a unique key value to an entry on the tbl_srs in the
     * srs.db sqlite database.
     * @note This slot will usually be called if the
@@ -218,12 +214,12 @@ class CORE_EXPORT QgsCoordinateTransform : public QObject
     * @param theCRSID -  A long representing the srsid of the srs to be used */
     void setDestCRSID( long theCRSID );
 
-    /**Returns list of datum transformations for the given src and dest CRS
+    /** Returns list of datum transformations for the given src and dest CRS
      * @note not available in python bindings
      */
     static QList< QList< int > > datumTransformations( const QgsCoordinateReferenceSystem& srcCRS, const QgsCoordinateReferenceSystem& destCRS );
     static QString datumTransformString( int datumTransform );
-    /**Gets name of source and dest geographical CRS (to show in a tooltip)
+    /** Gets name of source and dest geographical CRS (to show in a tooltip)
         @return epsgNr epsg code of the transformation (or 0 if not in epsg db)*/
     static bool datumTransformCrsInfo( int datumTransform, int& epsgNr, QString& srcProjection, QString& dstProjection, QString &remarks, QString &scope, bool &preferred, bool &deprecated );
 
@@ -236,13 +232,13 @@ class CORE_EXPORT QgsCoordinateTransform : public QObject
     //!initialise is used to actually create the Transformer instance
     void initialise();
 
-    /*! Restores state from the given Dom node.
+    /** Restores state from the given Dom node.
     * @param theNode The node from which state will be restored
     * @return bool True on success, False on failure
     */
     bool readXML( QDomNode & theNode );
 
-    /*! Stores state to the given Dom node in the given document
+    /** Stores state to the given Dom node in the given document
     * @param theNode The node in which state will be restored
     * @param theDoc The document in which state will be stored
     * @return bool True on success, False on failure
@@ -294,10 +290,10 @@ class CORE_EXPORT QgsCoordinateTransform : public QObject
      */
     void setFinder();
 
-    /**Removes +nadgrids and +towgs84 from proj4 string*/
+    /** Removes +nadgrids and +towgs84 from proj4 string*/
     static QString stripDatumTransform( const QString& proj4 );
     static void searchDatumTransform( const QString& sql, QList< int >& transforms );
-    /**In certain situations, null grid shifts have to be added to src / dst proj string*/
+    /** In certain situations, null grid shifts have to be added to src / dst proj string*/
     void addNullGridShifts( QString& srcProjString, QString& destProjString );
 };
 
