@@ -14,7 +14,6 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-/* $Id$ */
 #ifndef QGSCREDENTIALDIALOG_H
 #define QGSCREDENTIALDIALOG_H
 
@@ -24,6 +23,7 @@
 
 #include <QString>
 
+class QPushButton;
 
 /** \ingroup gui
  * A generic dialog for requesting credentials
@@ -32,11 +32,31 @@ class GUI_EXPORT QgsCredentialDialog : public QDialog, public QgsCredentials, pr
 {
     Q_OBJECT
   public:
-    QgsCredentialDialog( QWidget *parent = 0, Qt::WFlags fl = QgisGui::ModalDialogFlags );
+    QgsCredentialDialog( QWidget *parent = 0, const Qt::WindowFlags& fl = QgisGui::ModalDialogFlags );
     ~QgsCredentialDialog();
 
+  signals:
+    void credentialsRequested( QString, QString *, QString *, QString, bool * );
+
+    void credentialsRequestedMasterPassword( QString *, bool, bool * );
+
+  private slots:
+    void requestCredentials( const QString&, QString *, QString *, const QString&, bool * );
+
+    void requestCredentialsMasterPassword( QString *password, bool stored, bool *ok );
+
+    void on_chkMasterPassShow_stateChanged( int state );
+    void on_leMasterPass_textChanged( const QString& pass );
+    void on_leMasterPassVerify_textChanged( const QString& pass );
+    void on_chkbxEraseAuthDb_toggled( bool checked );
+
   protected:
-    virtual bool request( QString realm, QString &username, QString &password, QString message = QString::null );
+    virtual bool request( const QString& realm, QString &username, QString &password, const QString& message = QString::null ) override;
+
+    virtual bool requestMasterPassword( QString &password, bool stored = false ) override;
+
+  private:
+    QPushButton *mOkButton;
 };
 
 #endif
