@@ -21,6 +21,7 @@
 #include <QExplicitlySharedDataPointer>
 #include "qgis.h"
 #include "qgsfield.h"
+#include "qgsexpressioncontext.h"
 
 class QgsExpression;
 class QgsVectorLayer;
@@ -81,7 +82,7 @@ class CORE_EXPORT QgsDataDefined
 
     virtual ~QgsDataDefined();
 
-    /**Returns whether the data defined container is set to all the default
+    /** Returns whether the data defined container is set to all the default
      * values, ie, disabled, with empty expression and no assigned field
      * @returns true if data defined container is set to default values
      * @note added in QGIS 2.7
@@ -91,30 +92,76 @@ class CORE_EXPORT QgsDataDefined
     bool isActive() const;
     void setActive( bool active );
 
+    /**
+     * Returns if the field or the expression part is active.
+     *
+     * @return True if it is in expression mode.
+     */
     bool useExpression() const;
+
+    /**
+     * Controls if the field or the expression part is active.
+     * For QGIS<=2.10 it is mandatory to call this after {@link setExpressionString}
+     * or {@link setField}.
+     *
+     * @param use True if it should be set to expression mode.
+     */
     void setUseExpression( bool use );
 
+    /**
+     * Returns the expression string of this QgsDataDefined.
+     *
+     * @return An expression
+     *
+     * @see field()
+     * @see expressionOrField()
+     */
     QString expressionString() const;
+
+    /**
+     * Sets the expression for this QgsDataDefined.
+     * Will also set useExpression to true.
+     *
+     * @param expr The expression to set
+     *
+     * @see setField
+     */
     void setExpressionString( const QString& expr );
 
-    // @note not available in python bindings
+    /**
+     * Returns an expression which represents a single field if useExpression returns false, otherwise
+     * returns the current expression string.
+     * @return An expression
+     *
+     * @note added in 2.12
+     */
+    QString expressionOrField() const;
+
+    //! @note not available in python bindings
     QMap<QString, QVariant> expressionParams() const;
-    // @note not available in python bindings
-    void setExpressionParams( QMap<QString, QVariant> params );
-    void insertExpressionParam( QString key, QVariant param );
+    //! @note not available in python bindings
+    void setExpressionParams( const QMap<QString, QVariant>& params );
+    void insertExpressionParam( const QString& key, const QVariant& param );
 
     /** Prepares the expression using a vector layer
      * @param layer vector layer
      * @returns true if expression was successfully prepared
      */
-    bool prepareExpression( QgsVectorLayer* layer );
+    Q_DECL_DEPRECATED bool prepareExpression( QgsVectorLayer* layer );
 
     /** Prepares the expression using a fields collection
      * @param fields
      * @returns true if expression was successfully prepared
      * @note added in QGIS 2.9
      */
-    bool prepareExpression( const QgsFields &fields = QgsFields() );
+    Q_DECL_DEPRECATED bool prepareExpression( const QgsFields &fields );
+
+    /** Prepares the expression using an expression context.
+     * @param context expression context
+     * @returns true if expression was successfully prepared
+     * @note added in QGIS 2.12
+     */
+    bool prepareExpression( const QgsExpressionContext &context = QgsExpressionContext() );
 
     /** Returns whether the data defined object's expression is prepared
      * @returns true if expression is prepared
@@ -126,15 +173,36 @@ class CORE_EXPORT QgsDataDefined
     /** Returns the columns referenced by the QgsDataDefined
      * @param layer vector layer, used for preparing the expression if required
      */
-    QStringList referencedColumns( QgsVectorLayer* layer );
+    Q_DECL_DEPRECATED QStringList referencedColumns( QgsVectorLayer* layer );
 
     /** Returns the columns referenced by the QgsDataDefined
      * @param fields vector layer, used for preparing the expression if required
      * @note added in QGIS 2.9
      */
-    QStringList referencedColumns( const QgsFields& fields = QgsFields() );
+    Q_DECL_DEPRECATED QStringList referencedColumns( const QgsFields& fields );
 
+    /** Returns the columns referenced by the QgsDataDefined
+     * @param context expression context, used for preparing the expression if required
+     * @note added in QGIS 2.12
+     */
+    QStringList referencedColumns( const QgsExpressionContext& context = QgsExpressionContext() );
+
+    /**
+     * Get the field which this QgsDataDefined represents. Be aware that this may return
+     * a field name which may not be active if useExpression is true.
+     *
+     * @return A fieldname
+     *
+     * @see expressionOrField()
+     */
     QString field() const;
+
+    /**
+     * Set the field name which this QgsDataDefined represents.
+     * Will set useExpression to false.
+     *
+     * @param field
+     */
     void setField( const QString& field );
 
     /** Encodes the QgsDataDefined into a string map.
@@ -144,7 +212,7 @@ class CORE_EXPORT QgsDataDefined
      */
     QgsStringMap toMap( const QString& baseName = QString() ) const;
 
-    /**Returns a DOM element containing the properties of the data defined container.
+    /** Returns a DOM element containing the properties of the data defined container.
      * @param document DOM document
      * @param elementName name for DOM element
      * @returns DOM element corresponding to data defined container
@@ -153,7 +221,7 @@ class CORE_EXPORT QgsDataDefined
      */
     QDomElement toXmlElement( QDomDocument &document, const QString &elementName ) const;
 
-    /**Sets the properties of the data defined container from an XML element. Calling
+    /** Sets the properties of the data defined container from an XML element. Calling
      * this will overwrite all the current properties of the container.
      * @param element DOM element
      * @returns true if properties were successfully read from element
