@@ -21,9 +21,11 @@
 #include <QPointer>
 #include <QToolButton>
 #include <QScopedPointer>
+#include "qgsexpressioncontext.h"
 
 class QgsVectorLayer;
 class QgsDataDefined;
+class QgsMapCanvas;
 
 /** \ingroup gui
  * \class QgsDataDefinedAssistant
@@ -35,7 +37,27 @@ class QgsDataDefined;
 class GUI_EXPORT QgsDataDefinedAssistant: public QDialog
 {
   public:
+    QgsDataDefinedAssistant() : mMapCanvas( 0 ) {}
+
     virtual QgsDataDefined dataDefined() const = 0;
+
+    /** Sets the map canvas associated with the widget. This allows the widget to retrieve the current
+     * map scale and other properties from the canvas.
+     * @param canvas map canvas
+     * @see mapCanvas()
+     * @note added in QGIS 2.12
+     */
+    virtual void setMapCanvas( QgsMapCanvas* canvas ) { mMapCanvas = canvas; }
+
+    /** Returns the map canvas associated with the widget.
+     * @see setMapCanvas
+     * @note added in QGIS 2.12
+     */
+    const QgsMapCanvas* mapCanvas() const { return mMapCanvas; }
+
+  protected:
+
+    QgsMapCanvas* mMapCanvas;
 };
 
 /** \ingroup gui
@@ -70,8 +92,8 @@ class GUI_EXPORT QgsDataDefinedButton: public QToolButton
     QgsDataDefinedButton( QWidget* parent = 0,
                           const QgsVectorLayer* vl = 0,
                           const QgsDataDefined* datadefined = 0,
-                          DataTypes datatypes = AnyType,
-                          QString description = "" );
+                          const QgsDataDefinedButton::DataTypes& datatypes = AnyType,
+                          const QString& description = QString() );
     ~QgsDataDefinedButton();
 
     /**
@@ -84,8 +106,8 @@ class GUI_EXPORT QgsDataDefinedButton: public QToolButton
      */
     void init( const QgsVectorLayer* vl,
                const QgsDataDefined* datadefined = 0,
-               DataTypes datatypes = AnyType,
-               QString description = QString( "" ) );
+               const QgsDataDefinedButton::DataTypes& datatypes = AnyType,
+               const QString& description = QString() );
 
     QMap< QString, QString > definedProperty() const { return mProperty; }
 
@@ -153,7 +175,7 @@ class GUI_EXPORT QgsDataDefinedButton: public QToolButton
     /**
      * Register list of sibling widgets that get disabled/enabled when data definition or expression is set/unset
      */
-    void registerEnabledWidgets( QList<QWidget*> wdgts );
+    void registerEnabledWidgets( const QList<QWidget*>& wdgts );
 
     /**
      * Register a sibling widget that gets disabled/enabled when data definition or expression is set/unset
@@ -175,7 +197,7 @@ class GUI_EXPORT QgsDataDefinedButton: public QToolButton
     /**
      * Register list of sibling widgets that get checked when data definition or expression is active
      */
-    void registerCheckedWidgets( QList<QWidget*> wdgts );
+    void registerCheckedWidgets( const QList<QWidget*>& wdgts );
 
     /**
      * Register a sibling widget that get checked when data definition or expression is active
@@ -194,6 +216,18 @@ class GUI_EXPORT QgsDataDefinedButton: public QToolButton
      */
     void clearCheckedWidgets() { mCheckedWidgets.clear(); }
 
+    //! Callback function for retrieving the expression context for the button
+    typedef QgsExpressionContext( *ExpressionContextCallback )( const void* context );
+
+    /** Register callback function for retrieving the expression context for the button
+     * @param fnGetExpressionContext call back function, will be called when the data defined
+     * button requires the current expression context
+     * @param context context for callback function
+     * @note added in QGIS 2.12
+     * @note not available in Python bindings
+     */
+    void registerGetExpressionContextCallback( ExpressionContextCallback fnGetExpressionContext, const void* context );
+
     /**
      * Sets an assistant used to define the data defined object properties.
      * Ownership of the assistant is transferred to the widget.
@@ -201,9 +235,16 @@ class GUI_EXPORT QgsDataDefinedButton: public QToolButton
      * @param assistant data defined assistant. Set to null to remove the assistant
      * option from the button.
      * @note added in 2.10
+     * @see assistant()
      */
     void setAssistant( const QString& title, QgsDataDefinedAssistant * assistant );
 
+    /** Returns the assistant used to defined the data defined object properties, if set.
+     * @see setAssistant()
+     * @note added in QGIS 2.12
+     */
+    QgsDataDefinedAssistant* assistant();
+
     /**
      * Common descriptions for expected input values
      */
@@ -283,12 +324,12 @@ class GUI_EXPORT QgsDataDefinedButton: public QToolButton
     /**
      * Set the current defined expression
      */
-    void setExpression( QString exp ) { mProperty.insert( "expression", exp ); }
+    void setExpression( const QString& exp ) { mProperty.insert( "expression", exp ); }
 
     /**
      * Set the current defined field
      */
-    void setField( QString field ) { mProperty.insert( "field", field ); }
+    void setField( const QString& field ) { mProperty.insert( "field", field ); }
 
   private:
     void showDescriptionDialog();
@@ -306,6 +347,8 @@ class GUI_EXPORT QgsDataDefinedButton: public QToolButton
     QMenu* mDefineMenu;
     QAction* mActionDataTypes;
     QMenu* mFieldsMenu;
+    QMenu* mVariablesMenu;
+    QAction* mActionVariables;
 
     QAction* mActionActive;
     QAction* mActionDescription;
@@ -332,6 +375,9 @@ class GUI_EXPORT QgsDataDefinedButton: public QToolButton
     static QIcon mIconDataDefineExpressionOn;
     static QIcon mIconDataDefineExpressionError;
 
+    ExpressionContextCallback mExpressionContextCallback;
+    const void* mExpressionContextCallbackContext;
+
   private slots:
     void aboutToShowMenu();
     void menuActionTriggered( QAction* action );
