@@ -15,22 +15,26 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-/* $Id: qgsdatasourceuri.h 13336 2010-04-20 14:54:50Z jef $ */
 
 #ifndef QGSDATASOURCEURI_H
 #define QGSDATASOURCEURI_H
 
-#include <QString>
+#include "qgis.h"
+
+#include <QMap>
 
 /** \ingroup core
  * Class for storing the component parts of a PostgreSQL/RDBMS datasource URI.
  * This structure stores the database connection information, including host, database,
  * user name, password, schema, password, and sql where clause
+ *
+ * Extended to support generic params so that it may be used by any provider.
+ * The 2 modes (the old - RDMS specific and the new generic) may not yet be mixed.
+ * (Radim Blazek 4/2012)
  */
 class CORE_EXPORT QgsDataSourceURI
 {
   public:
-    //! \note enumeration added in version 1.1
     enum SSLmode { SSLprefer, SSLdisable, SSLallow, SSLrequire };
 
     //! default constructor
@@ -39,26 +43,65 @@ class CORE_EXPORT QgsDataSourceURI
     //! constructor which parses input URI
     QgsDataSourceURI( QString uri );
 
+    //! constructor which parses input encoded URI (generic mode)
+    QgsDataSourceURI( const QByteArray & uri );
+
     //! return connection part of URI
-    QString connectionInfo() const;
+    QString connectionInfo( bool expandAuthConfig = true ) const;
 
     //! return complete uri
-    QString uri() const;
+    QString uri( bool expandAuthConfig = true ) const;
+
+    //! return complete encoded uri (generic mode)
+    QByteArray encodedUri() const;
+
+    //! set complete encoded uri (generic mode)
+    // \note not available in python bindings
+    void setEncodedUri( const QByteArray & uri );
+
+    //! set complete encoded uri (generic mode)
+    void setEncodedUri( const QString & uri );
 
     //! quoted table name
     QString quotedTablename() const;
 
+    //! Set generic param (generic mode)
+    // \note if key exists, another is inserted
+    void setParam( const QString &key, const QString &value );
+    //! @note available in python as setParamList
+    void setParam( const QString &key, const QStringList &value );
+
+    //! Remove generic param (generic mode)
+    // \note remove all occurrences of key, returns number of params removed
+    int removeParam( const QString &key );
+
+    //! Get generic param (generic mode)
+    QString param( const QString &key ) const;
+
+    //! Get multiple generic param (generic mode)
+    QStringList params( const QString &key ) const;
+
+    //! Test if param exists (generic mode)
+    bool hasParam( const QString &key ) const;
+
     //! Set all connection related members at once
-    //! \note This optional sslmode parameter has been added in version 1.1
     void setConnection( const QString& aHost,
                         const QString& aPort,
                         const QString& aDatabase,
                         const QString& aUsername,
                         const QString& aPassword,
-                        SSLmode sslmode = SSLprefer );
+                        SSLmode sslmode = SSLprefer,
+                        const QString& authConfigId = QString() );
+
+    //! Set all connection related members at once (for the service case)
+    void setConnection( const QString& aService,
+                        const QString& aDatabase,
+                        const QString& aUsername,
+                        const QString& aPassword,
+                        SSLmode sslmode = SSLprefer,
+                        const QString& authConfigId = QString() );
 
     //! Set database
-    // \note added in 1.4
     void setDatabase( const QString &database );
 
     //! Set all data source related members at once
@@ -68,17 +111,20 @@ class CORE_EXPORT QgsDataSourceURI
                         const QString& aSql = QString(),
                         const QString& aKeyColumn = QString() );
 
+    //! Set authentication configuration ID
+    void setAuthConfigId( const QString& authcfg );
+
     //! set username
-    // added in 1.5
-    void setUsername( QString username );
+    void setUsername( const QString& username );
 
     //! set password
-    // added in 1.5
-    void setPassword( QString password );
+    void setPassword( const QString& password );
 
     //! Removes password element from uris
     static QString removePassword( const QString& aUri );
 
+    //! Any associated authentication configuration ID
+    QString authConfigId() const;
     QString username() const;
     QString schema() const;
     QString table() const;
@@ -86,23 +132,36 @@ class CORE_EXPORT QgsDataSourceURI
     QString geometryColumn() const;
 
     //! set use Estimated Metadata
-    // added in 1.5
     void setUseEstimatedMetadata( bool theFlag );
     bool useEstimatedMetadata() const;
 
+    void disableSelectAtId( bool theFlag );
+    bool selectAtIdDisabled() const;
+
     void clearSchema();
-    void setSql( QString sql );
+
+    //! set the table schema
+    // @note added in 2.11
+    void setSchema( const QString& schema );
+
+    void setSql( const QString& sql );
 
-    // added in version 1.1
     QString host() const;
     QString database() const;
     QString port() const;
     QString password() const;
     enum SSLmode sslMode() const;
 
-    // added in version 1.2
+    QString service() const;
+
     QString keyColumn() const;
-    void setKeyColumn( QString column );
+    void setKeyColumn( const QString& column );
+
+    QGis::WkbType wkbType() const;
+    void setWkbType( QGis::WkbType type );
+
+    QString srid() const;
+    void setSrid( const QString& srid );
 
   private:
     void skipBlanks( const QString &uri, int &i );
@@ -113,10 +172,12 @@ class CORE_EXPORT QgsDataSourceURI
 
     //! host name
     QString mHost;
-    //! database name
-    QString mDatabase;
     //! port the database server listens on
     QString mPort;
+    //! service name
+    QString mService;
+    //! database name
+    QString mDatabase;
     //! schema
     QString mSchema;
     //! spatial table
@@ -125,6 +186,8 @@ class CORE_EXPORT QgsDataSourceURI
     QString mGeometryColumn;
     //! SQL query or where clause used to limit features returned from the layer
     QString mSql;
+    //! authentication configuration ID
+    QString mAuthConfigId;
     //! username
     QString mUsername;
     //! password
@@ -133,8 +196,16 @@ class CORE_EXPORT QgsDataSourceURI
     enum SSLmode mSSLmode;
     //! key column
     QString mKeyColumn;
-    //Use estimated metadata flag
+    //! Use estimated metadata flag
     bool mUseEstimatedMetadata;
+    //! Disable SelectAtId capability (eg. to trigger the attribute table memory model for expensive views)
+    bool mSelectAtIdDisabled;
+    //! geometry type (or QGis::WKBUnknown if not specified)
+    QGis::WkbType mWkbType;
+    //! SRID or a null string if not specified
+    QString mSrid;
+    //! Generic params store
+    QMap<QString, QString> mParams;
 };
 
 #endif //QGSDATASOURCEURI_H
