@@ -3,7 +3,7 @@
      --------------------------------------
     Date                 : 5.1.2014
     Copyright            : (C) 2014 Matthias Kuhn
-    Email                : matthias dot kuhn at gmx dot ch
+    Email                : matthias at opengis dot ch
  ***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -28,8 +28,8 @@ class GUI_EXPORT QgsDummyConfigDlg : public QgsEditorConfigWidget, private Ui::Q
 
     // QgsEditorConfigWidget interface
   public:
-    virtual QgsEditorWidgetConfig config();
-    virtual void setConfig( const QgsEditorWidgetConfig& config );
+    virtual QgsEditorWidgetConfig config() override;
+    virtual void setConfig( const QgsEditorWidgetConfig& config ) override;
 };
 
 #endif // QGSDUMMYCONFIGDLG_H
