@@ -25,6 +25,72 @@
 #include "QStandardItemModel"
 #include "QStandardItem"
 #include "QSortFilterProxyModel"
+#include "QStringListModel"
+
+/** An expression item that can be used in the QgsExpressionBuilderWidget tree.
+  */
+class QgsExpressionItem : public QStandardItem
+{
+  public:
+    enum ItemType
+    {
+      Header,
+      Field,
+      ExpressionNode
+    };
+
+    QgsExpressionItem( const QString& label,
+                       const QString& expressionText,
+                       const QString& helpText,
+                       QgsExpressionItem::ItemType itemType = ExpressionNode )
+        : QStandardItem( label )
+    {
+      mExpressionText = expressionText;
+      mHelpText = helpText;
+      mType = itemType;
+      setData( itemType, ItemTypeRole );
+    }
+
+    QgsExpressionItem( const QString& label,
+                       const QString& expressionText,
+                       QgsExpressionItem::ItemType itemType = ExpressionNode )
+        : QStandardItem( label )
+    {
+      mExpressionText = expressionText;
+      mType = itemType;
+      setData( itemType, ItemTypeRole );
+    }
+
+    QString getExpressionText() const { return mExpressionText; }
+
+    /** Get the help text that is associated with this expression item.
+      *
+      * @return The help text.
+      */
+    QString getHelpText() const { return mHelpText; }
+    /** Set the help text for the current item
+      *
+      * @note The help text can be set as a html string.
+      */
+    void setHelpText( const QString& helpText ) { mHelpText = helpText; }
+
+    /** Get the type of expression item eg header, field, ExpressionNode.
+      *
+      * @return The QgsExpressionItem::ItemType
+      */
+    QgsExpressionItem::ItemType getItemType() const { return mType; }
+
+    //! Custom sort order role
+    static const int CustomSortRole = Qt::UserRole + 1;
+    //! Item type role
+    static const int ItemTypeRole = Qt::UserRole + 2;
+
+  private:
+    QString mExpressionText;
+    QString mHelpText;
+    QgsExpressionItem::ItemType mType;
+
+};
 
 /** Search proxy used to filter the QgsExpressionBuilderWidget tree.
   * The default search for a tree model only searches top level this will handle one
@@ -40,69 +106,37 @@ class QgsExpressionItemSearchProxy : public QSortFilterProxyModel
 
     bool filterAcceptsRow( int source_row, const QModelIndex &source_parent ) const override
     {
-      if ( source_parent == qobject_cast<QStandardItemModel*>( sourceModel() )->invisibleRootItem()->index() )
+      QModelIndex index = sourceModel()->index( source_row, 0, source_parent );
+      QgsExpressionItem::ItemType itemType = QgsExpressionItem::ItemType( sourceModel()->data( index, QgsExpressionItem::ItemTypeRole ).toInt() );
+
+      if ( itemType == QgsExpressionItem::Header )
         return true;
 
       return QSortFilterProxyModel::filterAcceptsRow( source_row, source_parent );
     }
+
+  protected:
+
+    bool lessThan( const QModelIndex &left, const QModelIndex &right ) const override
+    {
+      int leftSort = sourceModel()->data( left, QgsExpressionItem::CustomSortRole ).toInt();
+      int rightSort = sourceModel()->data( right,  QgsExpressionItem::CustomSortRole ).toInt();
+      if ( leftSort != rightSort )
+        return leftSort < rightSort;
+
+      QString leftString = sourceModel()->data( left, Qt::DisplayRole ).toString();
+      QString rightString = sourceModel()->data( right, Qt::DisplayRole ).toString();
+
+      //ignore $ prefixes when sorting
+      if ( leftString.startsWith( "$" ) )
+        leftString = leftString.mid( 1 );
+      if ( rightString.startsWith( "$" ) )
+        rightString = rightString.mid( 1 );
+
+      return QString::localeAwareCompare( leftString, rightString ) < 0;
+    }
 };
 
-/** An expression item that can be used in the QgsExpressionBuilderWidget tree.
-  */
-class QgsExpressionItem : public QStandardItem
-{
-  public:
-    enum ItemType
-    {
-      Header,
-      Field,
-      ExpressionNode
-    };
-
-    QgsExpressionItem( QString label,
-                       QString expressionText,
-                       QString helpText,
-                       QgsExpressionItem::ItemType itemType = ExpressionNode )
-        : QStandardItem( label )
-    {
-      mExpressionText = expressionText;
-      mHelpText = helpText;
-      mType = itemType;
-    }
-
-    QgsExpressionItem( QString label,
-                       QString expressionText,
-                       QgsExpressionItem::ItemType itemType = ExpressionNode )
-        : QStandardItem( label )
-    {
-      mExpressionText = expressionText;
-      mType = itemType;
-    }
-
-    QString getExpressionText() { return mExpressionText; }
-
-    /** Get the help text that is associated with this expression item.
-      *
-      * @return The help text.
-      */
-    QString getHelpText() {  return mHelpText; }
-    /** Set the help text for the current item
-      *
-      * @note The help text can be set as a html string.
-      */
-    void setHelpText( QString helpText ) { mHelpText = helpText; }
-
-    /** Get the type of expression item eg header, field, ExpressionNode.
-      *
-      * @return The QgsExpressionItem::ItemType
-      */
-    QgsExpressionItem::ItemType getItemType() { return mType; }
-
-  private:
-    QString mExpressionText;
-    QString mHelpText;
-    QgsExpressionItem::ItemType mType;
-};
 
 /** A reusable widget that can be used to build a expression string.
   * See QgsExpressionBuilderDialog for exmaple of usage.
@@ -126,6 +160,12 @@ class GUI_EXPORT QgsExpressionBuilderWidget : public QWidget, private Ui::QgsExp
 
     void loadFieldNames( const QgsFields& fields );
 
+    /** Loads field names and values from the specified map.
+     *  @note The field values must be quoted appropriately if they are strings.
+     *  @note added in QGIS 2.12
+     */
+    void loadFieldsAndValues( const QMap<QString, QStringList>& fieldValues );
+
     /** Sets geometry calculator used in distance/area calculations. */
     void setGeomCalculator( const QgsDistanceArea & da );
 
@@ -136,26 +176,44 @@ class GUI_EXPORT QgsExpressionBuilderWidget : public QWidget, private Ui::QgsExp
     /** Sets the expression string for the widget */
     void setExpressionText( const QString& expression );
 
+    /** Returns the expression context for the widget. The context is used for the expression
+     * preview result and for populating the list of available functions and variables.
+     * @see setExpressionContext
+     * @note added in QGIS 2.12
+     */
+    QgsExpressionContext expressionContext() const { return mExpressionContext; }
+
+    /** Sets the expression context for the widget. The context is used for the expression
+     * preview result and for populating the list of available functions and variables.
+     * @param context expression context
+     * @see expressionContext
+     * @note added in QGIS 2.12
+     */
+    void setExpressionContext( const QgsExpressionContext& context );
+
     /** Registers a node item for the expression builder.
       * @param group The group the item will be show in the tree view.  If the group doesn't exsit it will be created.
       * @param label The label that is show to the user for the item in the tree.
       * @param expressionText The text that is inserted into the expression area when the user double clicks on the item.
       * @param helpText The help text that the user will see when item is selected.
       * @param type The type of the expression item.
+      * @param highlightedItem set to true to make the item highlighted, which inserts a bold copy of the item at the top level
+      * @param sortOrder sort ranking for item
       */
-    void registerItem( QString group, QString label, QString expressionText,
-                       QString helpText = "",
-                       QgsExpressionItem::ItemType type = QgsExpressionItem::ExpressionNode );
+    void registerItem( const QString& group, const QString& label, const QString& expressionText,
+                       const QString& helpText = "",
+                       QgsExpressionItem::ItemType type = QgsExpressionItem::ExpressionNode,
+                       bool highlightedItem = false, int sortOrder = 1 );
 
     bool isExpressionValid();
 
-    void saveToRecent( QString key );
+    void saveToRecent( const QString& key );
 
-    void loadRecent( QString key );
+    void loadRecent( const QString& key );
 
     /** Create a new file in the function editor
      */
-    void newFunctionFile( QString fileName = "scratch" );
+    void newFunctionFile( const QString& fileName = "scratch" );
 
     /** Save the current function editor text to the given file.
      */
@@ -167,11 +225,11 @@ class GUI_EXPORT QgsExpressionBuilderWidget : public QWidget, private Ui::QgsExp
 
     /** Load code into the function editor
      */
-    void loadFunctionCode( QString code );
+    void loadFunctionCode( const QString& code );
 
     /** Update the list of function files found at the given path
      */
-    void updateFunctionFileList( QString path );
+    void updateFunctionFileList( const QString& path );
 
   public slots:
     void currentChanged( const QModelIndex &index, const QModelIndex & );
@@ -182,8 +240,9 @@ class GUI_EXPORT QgsExpressionBuilderWidget : public QWidget, private Ui::QgsExp
     void on_expressionTree_doubleClicked( const QModelIndex &index );
     void on_txtExpressionString_textChanged();
     void on_txtSearchEdit_textChanged();
-    void on_lblPreview_linkActivated( QString link );
-    void on_mValueListWidget_itemDoubleClicked( QListWidgetItem* item );
+    void on_txtSearchEditValues_textChanged();
+    void on_lblPreview_linkActivated( const QString& link );
+    void on_mValuesListView_doubleClicked( const QModelIndex &index );
     void operatorButtonClicked();
     void showContextMenu( const QPoint & );
     void loadSampleValues();
@@ -201,10 +260,11 @@ class GUI_EXPORT QgsExpressionBuilderWidget : public QWidget, private Ui::QgsExp
     void expressionParsed( bool isValid );
 
   private:
-    void runPythonCode( QString code );
+    void runPythonCode( const QString& code );
     void updateFunctionTree();
-    void fillFieldValues( int fieldIndex, int countLimit );
+    void fillFieldValues( const QString &fieldName, int countLimit );
     QString loadFunctionHelp( QgsExpressionItem* functionName );
+    QString helpStylesheet() const;
 
     /** Formats an expression preview result for display in the widget
      * by truncating the string
@@ -212,9 +272,13 @@ class GUI_EXPORT QgsExpressionBuilderWidget : public QWidget, private Ui::QgsExp
      */
     QString formatPreviewString( const QString &previewString ) const;
 
+    void loadExpressionContext();
+
     QString mFunctionsPath;
     QgsVectorLayer *mLayer;
     QStandardItemModel *mModel;
+    QStringListModel *mValuesModel;
+    QSortFilterProxyModel *mProxyValues;
     QgsExpressionItemSearchProxy *mProxyModel;
     QMap<QString, QgsExpressionItem*> mExpressionGroups;
     QgsFeature mFeature;
@@ -222,6 +286,8 @@ class GUI_EXPORT QgsExpressionBuilderWidget : public QWidget, private Ui::QgsExp
     bool mExpressionValid;
     QgsDistanceArea mDa;
     QString mRecentKey;
+    QMap<QString, QStringList> mFieldValues;
+    QgsExpressionContext mExpressionContext;
 
 };
 
