@@ -33,9 +33,9 @@
 class CORE_EXPORT QgsSimpleFillSymbolLayerV2 : public QgsFillSymbolLayerV2
 {
   public:
-    QgsSimpleFillSymbolLayerV2( QColor color = DEFAULT_SIMPLEFILL_COLOR,
+    QgsSimpleFillSymbolLayerV2( const QColor& color = DEFAULT_SIMPLEFILL_COLOR,
                                 Qt::BrushStyle style = DEFAULT_SIMPLEFILL_STYLE,
-                                QColor borderColor = DEFAULT_SIMPLEFILL_BORDERCOLOR,
+                                const QColor& borderColor = DEFAULT_SIMPLEFILL_BORDERCOLOR,
                                 Qt::PenStyle borderStyle = DEFAULT_SIMPLEFILL_BORDERSTYLE,
                                 double borderWidth = DEFAULT_SIMPLEFILL_BORDERWIDTH,
                                 Qt::PenJoinStyle penJoinStyle = DEFAULT_SIMPLEFILL_JOINSTYLE
@@ -60,7 +60,7 @@ class CORE_EXPORT QgsSimpleFillSymbolLayerV2 : public QgsFillSymbolLayerV2
 
     QgsSymbolLayerV2* clone() const override;
 
-    void toSld( QDomDocument &doc, QDomElement &element, QgsStringMap props ) const override;
+    void toSld( QDomDocument &doc, QDomElement &element, const QgsStringMap& props ) const override;
 
     QString ogrFeatureStyle( double mmScaleFactor, double mapUnitScaleFactor ) const override;
 
@@ -68,7 +68,7 @@ class CORE_EXPORT QgsSimpleFillSymbolLayerV2 : public QgsFillSymbolLayerV2
     void setBrushStyle( Qt::BrushStyle style ) { mBrushStyle = style; }
 
     QColor borderColor() const { return mBorderColor; }
-    void setBorderColor( QColor borderColor ) { mBorderColor = borderColor; }
+    void setBorderColor( const QColor& borderColor ) { mBorderColor = borderColor; }
 
     /** Get outline color.
      * @note added in 2.1 */
@@ -116,10 +116,10 @@ class CORE_EXPORT QgsSimpleFillSymbolLayerV2 : public QgsFillSymbolLayerV2
 
     double estimateMaxBleed() const override;
 
-    double dxfWidth( const QgsDxfExport& e, const QgsSymbolV2RenderContext& context ) const override;
-    QColor dxfColor( const QgsSymbolV2RenderContext& context ) const override;
+    double dxfWidth( const QgsDxfExport& e, QgsSymbolV2RenderContext& context ) const override;
+    QColor dxfColor( QgsSymbolV2RenderContext& context ) const override;
     Qt::PenStyle dxfPenStyle() const override;
-    QColor dxfBrushColor( const QgsSymbolV2RenderContext& context ) const override;
+    QColor dxfBrushColor( QgsSymbolV2RenderContext &context ) const override;
     Qt::BrushStyle dxfBrushStyle() const override;
 
   protected:
@@ -176,8 +176,8 @@ class CORE_EXPORT QgsGradientFillSymbolLayerV2 : public QgsFillSymbolLayerV2
       Repeat
     };
 
-    QgsGradientFillSymbolLayerV2( QColor color = DEFAULT_SIMPLEFILL_COLOR,
-                                  QColor color2 = Qt::white,
+    QgsGradientFillSymbolLayerV2( const QColor& color = DEFAULT_SIMPLEFILL_COLOR,
+                                  const QColor& color2 = Qt::white,
                                   GradientColorType gradientColorType = SimpleTwoColor,
                                   GradientType gradientType = Linear,
                                   GradientCoordinateMode coordinateMode = Feature,
@@ -206,51 +206,51 @@ class CORE_EXPORT QgsGradientFillSymbolLayerV2 : public QgsFillSymbolLayerV2
 
     double estimateMaxBleed() const override;
 
-    /**Type of gradient, eg linear or radial*/
+    /** Type of gradient, eg linear or radial*/
     GradientType gradientType() const { return mGradientType; }
     void setGradientType( GradientType gradientType ) { mGradientType = gradientType; }
 
-    /**Gradient color mode, controls how gradient color stops are created*/
+    /** Gradient color mode, controls how gradient color stops are created*/
     GradientColorType gradientColorType() const { return mGradientColorType; }
     void setGradientColorType( GradientColorType gradientColorType ) { mGradientColorType = gradientColorType; }
 
-    /**Color ramp used for the gradient fill, only used if the gradient color type is set to ColorRamp*/
+    /** Color ramp used for the gradient fill, only used if the gradient color type is set to ColorRamp*/
     QgsVectorColorRampV2* colorRamp() { return mGradientRamp; }
     void setColorRamp( QgsVectorColorRampV2* ramp );
 
-    /**Color for endpoint of gradient, only used if the gradient color type is set to SimpleTwoColor*/
+    /** Color for endpoint of gradient, only used if the gradient color type is set to SimpleTwoColor*/
     QColor color2() const { return mColor2; }
-    void setColor2( QColor color2 ) { mColor2 = color2; }
+    void setColor2( const QColor& color2 ) { mColor2 = color2; }
 
-    /**Coordinate mode for gradient. Controls how the gradient stops are positioned.*/
+    /** Coordinate mode for gradient. Controls how the gradient stops are positioned.*/
     GradientCoordinateMode coordinateMode() const { return mCoordinateMode; }
     void setCoordinateMode( GradientCoordinateMode coordinateMode ) { mCoordinateMode = coordinateMode; }
 
-    /**Gradient spread mode. Controls how the gradient behaves outside of the predefined stops*/
+    /** Gradient spread mode. Controls how the gradient behaves outside of the predefined stops*/
     GradientSpread gradientSpread() const { return mGradientSpread; }
     void setGradientSpread( GradientSpread gradientSpread ) { mGradientSpread = gradientSpread; }
 
-    /**Starting point of gradient fill, in the range [0,0] - [1,1]*/
+    /** Starting point of gradient fill, in the range [0,0] - [1,1]*/
     void setReferencePoint1( QPointF referencePoint ) { mReferencePoint1 = referencePoint; }
     QPointF referencePoint1() const { return mReferencePoint1; }
 
-    /**Sets the starting point of the gradient to be the feature centroid*/
+    /** Sets the starting point of the gradient to be the feature centroid*/
     void setReferencePoint1IsCentroid( bool isCentroid ) { mReferencePoint1IsCentroid = isCentroid; }
     bool referencePoint1IsCentroid() const { return mReferencePoint1IsCentroid; }
 
-    /**End point of gradient fill, in the range [0,0] - [1,1]*/
+    /** End point of gradient fill, in the range [0,0] - [1,1]*/
     void setReferencePoint2( QPointF referencePoint ) { mReferencePoint2 = referencePoint; }
     QPointF referencePoint2() const { return mReferencePoint2; }
 
-    /**Sets the end point of the gradient to be the feature centroid*/
+    /** Sets the end point of the gradient to be the feature centroid*/
     void setReferencePoint2IsCentroid( bool isCentroid ) { mReferencePoint2IsCentroid = isCentroid; }
     bool referencePoint2IsCentroid() const { return mReferencePoint2IsCentroid; }
 
-    /**Offset for gradient fill*/
+    /** Offset for gradient fill*/
     void setOffset( QPointF offset ) { mOffset = offset; }
     QPointF offset() const { return mOffset; }
 
-    /**Units for gradient fill offset*/
+    /** Units for gradient fill offset*/
     void setOffsetUnit( QgsSymbolV2::OutputUnit unit ) { mOffsetUnit = unit; }
     QgsSymbolV2::OutputUnit offsetUnit() const { return mOffsetUnit; }
 
@@ -288,13 +288,13 @@ class CORE_EXPORT QgsGradientFillSymbolLayerV2 : public QgsFillSymbolLayerV2
     //helper functions for data defined symbology
     void applyDataDefinedSymbology( QgsSymbolV2RenderContext& context, const QPolygonF& points );
 
-    /**Applies the gradient to a brush*/
+    /** Applies the gradient to a brush*/
     void applyGradient( const QgsSymbolV2RenderContext& context, QBrush& brush, const QColor& color, const QColor& color2,
                         const GradientColorType &gradientColorType, QgsVectorColorRampV2 *gradientRamp, const GradientType &gradientType,
                         const GradientCoordinateMode &coordinateMode, const GradientSpread &gradientSpread,
                         const QPointF &referencePoint1, const QPointF &referencePoint2, const double angle );
 
-    /**rotates a reference point by a specified angle around the point (0.5, 0.5)*/
+    /** Rotates a reference point by a specified angle around the point (0.5, 0.5)*/
     QPointF rotateReferencePoint( const QPointF & refPoint, double angle );
 };
 
@@ -308,7 +308,7 @@ class CORE_EXPORT QgsShapeburstFillSymbolLayerV2 : public QgsFillSymbolLayerV2
       ColorRamp
     };
 
-    QgsShapeburstFillSymbolLayerV2( QColor color = DEFAULT_SIMPLEFILL_COLOR, QColor color2 = Qt::white,
+    QgsShapeburstFillSymbolLayerV2( const QColor& color = DEFAULT_SIMPLEFILL_COLOR, const QColor& color2 = Qt::white,
                                     ShapeburstColorType colorType = SimpleTwoColor,
                                     int blurRadius = 0, bool useWholeShape = true, double maxDistance = 5 );
 
@@ -334,20 +334,20 @@ class CORE_EXPORT QgsShapeburstFillSymbolLayerV2 : public QgsFillSymbolLayerV2
 
     double estimateMaxBleed() const override;
 
-    /**Sets the blur radius, which controls the amount of blurring applied to the fill.
+    /** Sets the blur radius, which controls the amount of blurring applied to the fill.
      * @param blurRadius Radius for fill blur. Values between 0 - 17 are valid, where higher values results in a stronger blur. Set to 0 to disable blur.
      * @note added in 2.3
      * @see blurRadius
     */
     void setBlurRadius( int blurRadius ) { mBlurRadius = blurRadius; }
-    /**Returns the blur radius, which controls the amount of blurring applied to the fill.
+    /** Returns the blur radius, which controls the amount of blurring applied to the fill.
      * @returns Integer representing the radius for fill blur. Higher values indicate a stronger blur. A 0 value indicates that blurring is disabled.
      * @note added in 2.3
      * @see setBlurRadius
     */
     int blurRadius() const { return mBlurRadius; }
 
-    /**Sets whether the shapeburst fill should be drawn using the entire shape.
+    /** Sets whether the shapeburst fill should be drawn using the entire shape.
      * @param useWholeShape Set to true if shapeburst should cover entire shape. If false, setMaxDistance is used to calculate how far from the boundary of the shape should
      * be shaded
      * @note added in 2.3
@@ -355,7 +355,7 @@ class CORE_EXPORT QgsShapeburstFillSymbolLayerV2 : public QgsFillSymbolLayerV2
      * @see setMaxDistance
     */
     void setUseWholeShape( bool useWholeShape ) { mUseWholeShape = useWholeShape; }
-    /**Returns whether the shapeburst fill is set to cover the entire shape.
+    /** Returns whether the shapeburst fill is set to cover the entire shape.
      * @returns True if shapeburst fill will cover the entire shape. If false, shapeburst is drawn to a distance of maxDistance from the polygon's boundary.
      * @note added in 2.3
      * @see setUseWholeShape
@@ -363,7 +363,7 @@ class CORE_EXPORT QgsShapeburstFillSymbolLayerV2 : public QgsFillSymbolLayerV2
     */
     bool useWholeShape() const { return mUseWholeShape; }
 
-    /**Sets the maximum distance to shape inside of the shape from the polygon's boundary.
+    /** Sets the maximum distance to shape inside of the shape from the polygon's boundary.
      * @param maxDistance distance from boundary to shade. setUseWholeShape must be set to false for this parameter to take effect. Distance unit is controlled by setDistanceUnit.
      * @note added in 2.3
      * @see maxDistance
@@ -371,7 +371,7 @@ class CORE_EXPORT QgsShapeburstFillSymbolLayerV2 : public QgsFillSymbolLayerV2
      * @see setDistanceUnit
     */
     void setMaxDistance( double maxDistance ) { mMaxDistance = maxDistance; }
-    /**Returns the maximum distance from the shape's boundary which is shaded. This parameter is only effective if useWholeShape is false.
+    /** Returns the maximum distance from the shape's boundary which is shaded. This parameter is only effective if useWholeShape is false.
      * @returns the maximum distance from the polygon's boundary which is shaded. Distance units are indicated by distanceUnit.
      * @note added in 2.3
      * @see useWholeShape
@@ -380,14 +380,14 @@ class CORE_EXPORT QgsShapeburstFillSymbolLayerV2 : public QgsFillSymbolLayerV2
     */
     double maxDistance() const { return mMaxDistance; }
 
-    /**Sets the unit for the maximum distance to shade inside of the shape from the polygon's boundary.
+    /** Sets the unit for the maximum distance to shade inside of the shape from the polygon's boundary.
      * @param unit distance unit for the maximum distance
      * @note added in 2.3
      * @see setMaxDistance
      * @see distanceUnit
     */
     void setDistanceUnit( QgsSymbolV2::OutputUnit unit ) { mDistanceUnit = unit; }
-    /**Returns the unit for the maximum distance to shade inside of the shape from the polygon's boundary.
+    /** Returns the unit for the maximum distance to shade inside of the shape from the polygon's boundary.
      * @returns distance unit for the maximum distance
      * @note added in 2.3
      * @see maxDistance
@@ -398,7 +398,7 @@ class CORE_EXPORT QgsShapeburstFillSymbolLayerV2 : public QgsFillSymbolLayerV2
     void setDistanceMapUnitScale( const QgsMapUnitScale& scale ) { mDistanceMapUnitScale = scale; }
     const QgsMapUnitScale& distanceMapUnitScale() const { return mDistanceMapUnitScale; }
 
-    /**Sets the color mode to use for the shapeburst fill. Shapeburst can either be drawn using a QgsVectorColorRampV2 color ramp
+    /** Sets the color mode to use for the shapeburst fill. Shapeburst can either be drawn using a QgsVectorColorRampV2 color ramp
      * or by simply specificing a start and end color. setColorType is used to specify which mode to use for the fill.
      * @param colorType color type to use for shapeburst fill
      * @note added in 2.3
@@ -408,7 +408,7 @@ class CORE_EXPORT QgsShapeburstFillSymbolLayerV2 : public QgsFillSymbolLayerV2
      * @see setColorRamp
     */
     void setColorType( ShapeburstColorType colorType ) { mColorType = colorType; }
-    /**Returns the color mode used for the shapeburst fill. Shapeburst can either be drawn using a QgsVectorColorRampV2 color ramp
+    /** Returns the color mode used for the shapeburst fill. Shapeburst can either be drawn using a QgsVectorColorRampV2 color ramp
      * or by simply specificing a start and end color.
      * @returns current color mode used for the shapeburst fill
      * @note added in 2.3
@@ -419,14 +419,14 @@ class CORE_EXPORT QgsShapeburstFillSymbolLayerV2 : public QgsFillSymbolLayerV2
     */
     ShapeburstColorType colorType() const { return mColorType; }
 
-    /**Sets the color ramp used to draw the shapeburst fill. Color ramps are only used if setColorType is set ShapeburstColorType::ColorRamp.
+    /** Sets the color ramp used to draw the shapeburst fill. Color ramps are only used if setColorType is set ShapeburstColorType::ColorRamp.
      * @param ramp color ramp to use for shapeburst fill
      * @note added in 2.3
      * @see setColorType
      * @see colorRamp
     */
     void setColorRamp( QgsVectorColorRampV2* ramp );
-    /**Returns the color ramp used for the shapeburst fill. The color ramp is only used if the colorType is set to ShapeburstColorType::ColorRamp
+    /** Returns the color ramp used for the shapeburst fill. The color ramp is only used if the colorType is set to ShapeburstColorType::ColorRamp
      * @returns a QgsVectorColorRampV2 color ramp
      * @note added in 2.3
      * @see setColorRamp
@@ -434,14 +434,14 @@ class CORE_EXPORT QgsShapeburstFillSymbolLayerV2 : public QgsFillSymbolLayerV2
     */
     QgsVectorColorRampV2* colorRamp() { return mGradientRamp; }
 
-    /**Sets the color for the endpoint of the shapeburst fill. This color is only used if setColorType is set ShapeburstColorType::SimpleTwoColor.
+    /** Sets the color for the endpoint of the shapeburst fill. This color is only used if setColorType is set ShapeburstColorType::SimpleTwoColor.
      * @param color2 QColor to use for endpoint of gradient
      * @note added in 2.3
      * @see setColorType
      * @see color2
     */
-    void setColor2( QColor color2 ) { mColor2 = color2; }
-    /**Returns the color used for the endpoint of the shapeburst fill. This color is only used if the colorType is set to ShapeburstColorType::SimpleTwoColor
+    void setColor2( const QColor& color2 ) { mColor2 = color2; }
+    /** Returns the color used for the endpoint of the shapeburst fill. This color is only used if the colorType is set to ShapeburstColorType::SimpleTwoColor
      * @returns a QColor indicating the color of the endpoint of the gradient
      * @note added in 2.3
      * @see setColor2
@@ -449,28 +449,28 @@ class CORE_EXPORT QgsShapeburstFillSymbolLayerV2 : public QgsFillSymbolLayerV2
     */
     QColor color2() const { return mColor2; }
 
-    /**Sets whether the shapeburst fill should ignore polygon rings when calculating
+    /** Sets whether the shapeburst fill should ignore polygon rings when calculating
      * the buffered shading.
      * @param ignoreRings Set to true if buffers should ignore interior rings for polygons.
      * @note added in 2.3
      * @see ignoreRings
     */
     void setIgnoreRings( bool ignoreRings ) { mIgnoreRings = ignoreRings; }
-    /**Returns whether the shapeburst fill is set to ignore polygon interior rings.
+    /** Returns whether the shapeburst fill is set to ignore polygon interior rings.
      * @returns True if the shapeburst fill will ignore interior rings when calculating buffered shading.
      * @note added in 2.3
      * @see setIgnoreRings
     */
     bool ignoreRings() const { return mIgnoreRings; }
 
-    /**Sets the offset for the shapeburst fill.
+    /** Sets the offset for the shapeburst fill.
      * @param offset QPointF indicating the horizontal/vertical offset amount
      * @note added in 2.3
      * @see offset
      * @see setOffsetUnit
     */
     void setOffset( QPointF offset ) { mOffset = offset; }
-    /**Returns the offset for the shapeburst fill.
+    /** Returns the offset for the shapeburst fill.
      * @returns a QPointF indicating the horizontal/vertical offset amount
      * @note added in 2.3
      * @see setOffset
@@ -478,14 +478,14 @@ class CORE_EXPORT QgsShapeburstFillSymbolLayerV2 : public QgsFillSymbolLayerV2
     */
     QPointF offset() const { return mOffset; }
 
-    /**Sets the units used for the offset for the shapeburst fill.
+    /** Sets the units used for the offset for the shapeburst fill.
      * @param unit units for fill offset
      * @note added in 2.3
      * @see setOffset
      * @see offsetUnit
     */
     void setOffsetUnit( QgsSymbolV2::OutputUnit unit ) { mOffsetUnit = unit; }
-    /**Returns the units used for the offset of the shapeburst fill.
+    /** Returns the units used for the offset of the shapeburst fill.
      * @returns units used for the fill offset
      * @note added in 2.3
      * @see offset
@@ -541,7 +541,7 @@ class CORE_EXPORT QgsShapeburstFillSymbolLayerV2 : public QgsFillSymbolLayerV2
     void dtArrayToQImage( double * array, QImage *im, QgsVectorColorRampV2* ramp, double layerAlpha = 1, bool useWholeShape = true, int maxPixelDistance = 0 );
 };
 
-/**Base class for polygon renderers generating texture images*/
+/** Base class for polygon renderers generating texture images*/
 class CORE_EXPORT QgsImageFillSymbolLayer: public QgsFillSymbolLayerV2
 {
   public:
@@ -567,23 +567,25 @@ class CORE_EXPORT QgsImageFillSymbolLayer: public QgsFillSymbolLayerV2
 
     virtual double estimateMaxBleed() const override;
 
-    virtual double dxfWidth( const QgsDxfExport& e, const QgsSymbolV2RenderContext& context ) const override;
-    virtual QColor dxfColor( const QgsSymbolV2RenderContext& context ) const override;
+    virtual double dxfWidth( const QgsDxfExport& e, QgsSymbolV2RenderContext& context ) const override;
+    virtual QColor dxfColor( QgsSymbolV2RenderContext& context ) const override;
     virtual Qt::PenStyle dxfPenStyle() const override;
 
+    QSet<QString> usedAttributes() const override;
+
   protected:
     QBrush mBrush;
     double mNextAngle; // mAngle / data defined angle
 
-    /**Outline width*/
+    /** Outline width*/
     double mOutlineWidth;
     QgsSymbolV2::OutputUnit mOutlineWidthUnit;
     QgsMapUnitScale mOutlineWidthMapUnitScale;
 
-    /**Custom outline*/
+    /** Custom outline*/
     QgsLineSymbolV2* mOutline;
 
-    virtual void applyDataDefinedSettings( const QgsSymbolV2RenderContext& context ) { Q_UNUSED( context ); }
+    virtual void applyDataDefinedSettings( QgsSymbolV2RenderContext& context ) { Q_UNUSED( context ); }
 };
 
 /** \ingroup core
@@ -619,49 +621,49 @@ class CORE_EXPORT QgsRasterFillSymbolLayer: public QgsImageFillSymbolLayer
     virtual QgsSymbolV2* subSymbol() override { return 0; }
     virtual bool setSubSymbol( QgsSymbolV2* symbol ) override;
 
-    /**Sets the path to the raster image used for the fill.
+    /** Sets the path to the raster image used for the fill.
      * @param imagePath path to image file
      * @see imageFilePath
     */
     void setImageFilePath( const QString& imagePath );
-    /**The path to the raster image used for the fill.
+    /** The path to the raster image used for the fill.
      * @returns path to image file
      * @see setImageFilePath
     */
     QString imageFilePath() const { return mImageFilePath; }
 
-    /**Set the coordinate mode for fill. Controls how the top left corner of the image
+    /** Set the coordinate mode for fill. Controls how the top left corner of the image
      * fill is positioned relative to the feature.
      * @param mode coordinate mode
      * @see coordinateMode
     */
     void setCoordinateMode( const FillCoordinateMode mode );
-    /**Coordinate mode for fill. Controls how the top left corner of the image
+    /** Coordinate mode for fill. Controls how the top left corner of the image
      * fill is positioned relative to the feature.
      * @returns coordinate mode
      * @see setCoordinateMode
     */
     FillCoordinateMode coordinateMode() const { return mCoordinateMode; }
 
-    /**Sets the opacity for the raster image used in the fill.
+    /** Sets the opacity for the raster image used in the fill.
      * @param alpha opacity value between 0 (fully transparent) and 1 (fully opaque)
      * @see alpha
     */
     void setAlpha( const double alpha );
-    /**The opacity for the raster image used in the fill.
+    /** The opacity for the raster image used in the fill.
      * @returns opacity value between 0 (fully transparent) and 1 (fully opaque)
      * @see setAlpha
     */
     double alpha() const { return mAlpha; }
 
-    /**Sets the offset for the fill.
+    /** Sets the offset for the fill.
      * @param offset offset for fill
      * @see offset
      * @see setOffsetUnit
      * @see setOffsetMapUnitScale
     */
     void setOffset( const QPointF& offset ) { mOffset = offset; }
-    /**Returns the offset for the fill.
+    /** Returns the offset for the fill.
      * @returns offset for fill
      * @see setOffset
      * @see offsetUnit
@@ -669,14 +671,14 @@ class CORE_EXPORT QgsRasterFillSymbolLayer: public QgsImageFillSymbolLayer
     */
     QPointF offset() const { return mOffset; }
 
-    /**Sets the units for the fill's offset.
+    /** Sets the units for the fill's offset.
      * @param unit units for offset
      * @see offsetUnit
      * @see setOffset
      * @see setOffsetMapUnitScale
     */
     void setOffsetUnit( const QgsSymbolV2::OutputUnit unit ) { mOffsetUnit = unit; }
-    /**Returns the units for the fill's offset.
+    /** Returns the units for the fill's offset.
      * @returns units for offset
      * @see setOffsetUnit
      * @see offset
@@ -684,14 +686,14 @@ class CORE_EXPORT QgsRasterFillSymbolLayer: public QgsImageFillSymbolLayer
     */
     QgsSymbolV2::OutputUnit offsetUnit() const { return mOffsetUnit; }
 
-    /**Sets the map unit scale for the fill's offset.
+    /** Sets the map unit scale for the fill's offset.
      * @param scale map unit scale for offset
      * @see offsetMapUnitScale
      * @see setOffset
      * @see setOffsetUnit
     */
     void setOffsetMapUnitScale( const QgsMapUnitScale& scale ) { mOffsetMapUnitScale = scale; }
-    /**Returns the map unit scale for the fill's offset.
+    /** Returns the map unit scale for the fill's offset.
      * @returns map unit scale for offset
      * @see setOffsetMapUnitScale
      * @see offset
@@ -699,7 +701,7 @@ class CORE_EXPORT QgsRasterFillSymbolLayer: public QgsImageFillSymbolLayer
     */
     const QgsMapUnitScale& offsetMapUnitScale() const { return mOffsetMapUnitScale; }
 
-    /**Sets the width for scaling the image used in the fill. The image's height will also be
+    /** Sets the width for scaling the image used in the fill. The image's height will also be
      * scaled to maintain the image's aspect ratio.
      * @param width width for scaling the image
      * @see width
@@ -707,7 +709,7 @@ class CORE_EXPORT QgsRasterFillSymbolLayer: public QgsImageFillSymbolLayer
      * @see setWidthMapUnitScale
     */
     void setWidth( const double width ) { mWidth = width; }
-    /**Returns the width used for scaling the image used in the fill. The image's height is
+    /** Returns the width used for scaling the image used in the fill. The image's height is
      * scaled to maintain the image's aspect ratio.
      * @returns width used for scaling the image
      * @see setWidth
@@ -716,14 +718,14 @@ class CORE_EXPORT QgsRasterFillSymbolLayer: public QgsImageFillSymbolLayer
     */
     double width() const { return mWidth; }
 
-    /**Sets the units for the image's width.
+    /** Sets the units for the image's width.
      * @param unit units for width
      * @see widthUnit
      * @see setWidth
      * @see setWidthMapUnitScale
     */
     void setWidthUnit( const QgsSymbolV2::OutputUnit unit ) { mWidthUnit = unit; }
-    /**Returns the units for the image's width.
+    /** Returns the units for the image's width.
      * @returns units for width
      * @see setWidthUnit
      * @see width
@@ -731,14 +733,14 @@ class CORE_EXPORT QgsRasterFillSymbolLayer: public QgsImageFillSymbolLayer
     */
     QgsSymbolV2::OutputUnit widthUnit() const { return mWidthUnit; }
 
-    /**Sets the map unit scale for the image's width.
+    /** Sets the map unit scale for the image's width.
      * @param scale map unit scale for width
      * @see widthMapUnitScale
      * @see setWidth
      * @see setWidthUnit
     */
     void setWidthMapUnitScale( const QgsMapUnitScale& scale ) { mWidthMapUnitScale = scale; }
-    /**Returns the map unit scale for the image's width.
+    /** Returns the map unit scale for the image's width.
      * @returns map unit scale for width
      * @see setWidthMapUnitScale
      * @see width
@@ -748,7 +750,7 @@ class CORE_EXPORT QgsRasterFillSymbolLayer: public QgsImageFillSymbolLayer
 
   protected:
 
-    /**Path to the image file*/
+    /** Path to the image file*/
     QString mImageFilePath;
     FillCoordinateMode mCoordinateMode;
     double mAlpha;
@@ -761,16 +763,16 @@ class CORE_EXPORT QgsRasterFillSymbolLayer: public QgsImageFillSymbolLayer
     QgsSymbolV2::OutputUnit mWidthUnit;
     QgsMapUnitScale mWidthMapUnitScale;
 
-    void applyDataDefinedSettings( const QgsSymbolV2RenderContext& context ) override;
+    void applyDataDefinedSettings( QgsSymbolV2RenderContext& context ) override;
 
   private:
 
-    /**Applies the image pattern to the brush*/
+    /** Applies the image pattern to the brush*/
     void applyPattern( QBrush& brush, const QString& imageFilePath, const double width, const double alpha,
                        const QgsSymbolV2RenderContext& context );
 };
 
-/**A class for svg fill patterns. The class automatically scales the pattern to
+/** A class for svg fill patterns. The class automatically scales the pattern to
    the appropriate pixel dimensions of the output device*/
 class CORE_EXPORT QgsSVGFillSymbolLayer: public QgsImageFillSymbolLayer
 {
@@ -793,7 +795,7 @@ class CORE_EXPORT QgsSVGFillSymbolLayer: public QgsImageFillSymbolLayer
 
     QgsSymbolLayerV2* clone() const override;
 
-    void toSld( QDomDocument &doc, QDomElement &element, QgsStringMap props ) const override;
+    void toSld( QDomDocument &doc, QDomElement &element, const QgsStringMap& props ) const override;
 
     //getters and setters
     void setSvgFilePath( const QString& svgPath );
@@ -801,8 +803,9 @@ class CORE_EXPORT QgsSVGFillSymbolLayer: public QgsImageFillSymbolLayer
     void setPatternWidth( double width ) { mPatternWidth = width;}
     double patternWidth() const { return mPatternWidth; }
 
-    void setSvgFillColor( const QColor& c ) { mSvgFillColor = c; }
-    QColor svgFillColor() const { return mSvgFillColor; }
+    void setSvgFillColor( const QColor& c ) { setColor( c );  }
+    QColor svgFillColor() const { return color(); }
+
     void setSvgOutlineColor( const QColor& c ) { mSvgOutlineColor = c; }
     QColor svgOutlineColor() const { return mSvgOutlineColor; }
     void setSvgOutlineWidth( double w ) { mSvgOutlineWidth = w; }
@@ -827,36 +830,35 @@ class CORE_EXPORT QgsSVGFillSymbolLayer: public QgsImageFillSymbolLayer
     QgsMapUnitScale mapUnitScale() const override;
 
   protected:
-    /**Width of the pattern (in output units)*/
+    /** Width of the pattern (in output units)*/
     double mPatternWidth;
     QgsSymbolV2::OutputUnit mPatternWidthUnit;
     QgsMapUnitScale mPatternWidthMapUnitScale;
 
-    /**SVG data*/
+    /** SVG data*/
     QByteArray mSvgData;
-    /**Path to the svg file (or empty if constructed directly from data)*/
+    /** Path to the svg file (or empty if constructed directly from data)*/
     QString mSvgFilePath;
-    /**SVG view box (to keep the aspect ratio */
+    /** SVG view box (to keep the aspect ratio */
     QRectF mSvgViewBox;
     /** SVG pattern image */
     QImage* mSvgPattern;
 
     //param(fill), param(outline), param(outline-width) are going
     //to be replaced in memory
-    QColor mSvgFillColor;
     QColor mSvgOutlineColor;
     double mSvgOutlineWidth;
     QgsSymbolV2::OutputUnit mSvgOutlineWidthUnit;
     QgsMapUnitScale mSvgOutlineWidthMapUnitScale;
 
-    void applyDataDefinedSettings( const QgsSymbolV2RenderContext& context ) override;
+    void applyDataDefinedSettings( QgsSymbolV2RenderContext& context ) override;
 
   private:
-    /**Helper function that gets the view box from the byte array*/
+    /** Helper function that gets the view box from the byte array*/
     void storeViewBox();
     void setDefaultSvgParams(); //fills mSvgFillColor, mSvgOutlineColor, mSvgOutlineWidth with default values for mSvgFilePath
 
-    /**Applies the svg pattern to the brush*/
+    /** Applies the svg pattern to the brush*/
     void applyPattern( QBrush& brush, const QString& svgFilePath, double patternWidth, QgsSymbolV2::OutputUnit patternWidthUnit, const QColor& svgFillColor, const QColor& svgOutlineColor,
                        double svgOutlineWidth, QgsSymbolV2::OutputUnit svgOutlineWidthUnit, const QgsSymbolV2RenderContext& context, const QgsMapUnitScale& patternWidthMapUnitScale, const QgsMapUnitScale &svgOutlineWidthMapUnitScale );
 };
@@ -880,7 +882,7 @@ class CORE_EXPORT QgsLinePatternFillSymbolLayer: public QgsImageFillSymbolLayer
 
     QgsSymbolLayerV2* clone() const override;
 
-    void toSld( QDomDocument &doc, QDomElement &element, QgsStringMap props ) const override;
+    void toSld( QDomDocument &doc, QDomElement &element, const QgsStringMap& props ) const override;
 
     double estimateMaxBleed() const override;
 
@@ -928,29 +930,29 @@ class CORE_EXPORT QgsLinePatternFillSymbolLayer: public QgsImageFillSymbolLayer
     QSet<QString> usedAttributes() const override;
 
   protected:
-    /**Distance (in mm or map units) between lines*/
+    /** Distance (in mm or map units) between lines*/
     double mDistance;
     QgsSymbolV2::OutputUnit mDistanceUnit;
     QgsMapUnitScale mDistanceMapUnitScale;
-    /**Line width (in mm or map units)*/
+    /** Line width (in mm or map units)*/
     double mLineWidth;
     QgsSymbolV2::OutputUnit mLineWidthUnit;
     QgsMapUnitScale mLineWidthMapUnitScale;
     QColor mColor;
-    /**Vector line angle in degrees (0 = horizontal, counterclockwise)*/
+    /** Vector line angle in degrees (0 = horizontal, counterclockwise)*/
     double mLineAngle;
-    /**Offset perpendicular to line direction*/
+    /** Offset perpendicular to line direction*/
     double mOffset;
     QgsSymbolV2::OutputUnit mOffsetUnit;
     QgsMapUnitScale mOffsetMapUnitScale;
 
-    void applyDataDefinedSettings( const QgsSymbolV2RenderContext& context ) override;
+    void applyDataDefinedSettings( QgsSymbolV2RenderContext& context ) override;
 
   private:
-    /**Applies the svg pattern to the brush*/
+    /** Applies the svg pattern to the brush*/
     void applyPattern( const QgsSymbolV2RenderContext& context, QBrush& brush, double lineAngle, double distance, double lineWidth, const QColor& color );
 
-    /**Fill line*/
+    /** Fill line*/
     QgsLineSymbolV2* mFillLineSymbol;
 };
 
@@ -973,7 +975,7 @@ class CORE_EXPORT QgsPointPatternFillSymbolLayer: public QgsImageFillSymbolLayer
 
     QgsSymbolLayerV2* clone() const override;
 
-    void toSld( QDomDocument &doc, QDomElement &element, QgsStringMap props ) const override;
+    void toSld( QDomDocument &doc, QDomElement &element, const QgsStringMap& props ) const override;
 
     double estimateMaxBleed() const override;
 
@@ -1040,7 +1042,7 @@ class CORE_EXPORT QgsPointPatternFillSymbolLayer: public QgsImageFillSymbolLayer
     QgsSymbolV2::OutputUnit mDisplacementYUnit;
     QgsMapUnitScale mDisplacementYMapUnitScale;
 
-    void applyDataDefinedSettings( const QgsSymbolV2RenderContext& context ) override;
+    void applyDataDefinedSettings( QgsSymbolV2RenderContext& context ) override;
 
   private:
     void applyPattern( const QgsSymbolV2RenderContext& context, QBrush& brush, double distanceX, double distanceY,
@@ -1072,7 +1074,7 @@ class CORE_EXPORT QgsCentroidFillSymbolLayerV2 : public QgsFillSymbolLayerV2
 
     QgsSymbolLayerV2* clone() const override;
 
-    void toSld( QDomDocument &doc, QDomElement &element, QgsStringMap props ) const override;
+    void toSld( QDomDocument &doc, QDomElement &element, const QgsStringMap& props ) const override;
 
     void setColor( const QColor& color ) override;
 
