@@ -52,7 +52,7 @@ class GUI_EXPORT QgsGenericProjectionSelector : public QDialog, private Ui::QgsG
      * Constructor
      */
     QgsGenericProjectionSelector( QWidget *parent = 0,
-                                  Qt::WindowFlags fl = QgisGui::ModalDialogFlags );
+                                  const Qt::WindowFlags& fl = QgisGui::ModalDialogFlags );
 
     //! Destructor
     ~QgsGenericProjectionSelector();
@@ -65,11 +65,11 @@ class GUI_EXPORT QgsGenericProjectionSelector : public QDialog, private Ui::QgsG
     long selectedCrsId();
     QString selectedAuthId();
 
-    void setSelectedCrsName( QString theName );
+    void setSelectedCrsName( const QString& theName );
     void setSelectedCrsId( long theID );
-    void setSelectedAuthId( QString authId );
+    void setSelectedAuthId( const QString& authId );
 
-    void on_buttonBox_helpRequested() { QgsContextHelp::run( metaObject()->className() ); }
+    void on_mButtonBox_helpRequested() { QgsContextHelp::run( metaObject()->className() ); }
 
     /**
      * \brief filters this dialog by the given CRSs
@@ -83,7 +83,7 @@ class GUI_EXPORT QgsGenericProjectionSelector : public QDialog, private Ui::QgsG
      *
      * \warning This function's behaviour is undefined if it is called after the dialog is shown.
      */
-    void setOgcWmsCrsFilter( QSet<QString> crsFilter );
+    void setOgcWmsCrsFilter( const QSet<QString>& crsFilter );
 };
 
 #endif // #ifndef QGSLAYERCRSSELECTOR_H
