@@ -23,6 +23,7 @@ email                : morb at ozemail dot com dot au
 #include "qgis.h"
 
 #include <geos_c.h>
+#include <climits>
 
 #if defined(GEOS_VERSION_MAJOR) && (GEOS_VERSION_MAJOR<3)
 #define GEOSGeometry struct GEOSGeom_t
@@ -33,7 +34,7 @@ email                : morb at ozemail dot com dot au
 #include "qgspoint.h"
 #include "qgscoordinatetransform.h"
 #include "qgsfeature.h"
-
+#include <limits>
 #include <QSet>
 
 class QgsGeometryEngine;
@@ -42,19 +43,19 @@ class QgsMapToPixel;
 class QPainter;
 class QgsPolygonV2;
 
-/** polyline is represented as a vector of points */
+/** Polyline is represented as a vector of points */
 typedef QVector<QgsPoint> QgsPolyline;
 
-/** polygon: first item of the list is outer ring, inner rings (if any) start from second item */
+/** Polygon: first item of the list is outer ring, inner rings (if any) start from second item */
 typedef QVector<QgsPolyline> QgsPolygon;
 
-/** a collection of QgsPoints that share a common collection of attributes */
+/** A collection of QgsPoints that share a common collection of attributes */
 typedef QVector<QgsPoint> QgsMultiPoint;
 
-/** a collection of QgsPolylines that share a common collection of attributes */
+/** A collection of QgsPolylines that share a common collection of attributes */
 typedef QVector<QgsPolyline> QgsMultiPolyline;
 
-/** a collection of QgsPolygons that share a common collection of attributes */
+/** A collection of QgsPolygons that share a common collection of attributes */
 typedef QVector<QgsPolygon> QgsMultiPolygon;
 
 class QgsRectangle;
@@ -78,10 +79,10 @@ class CORE_EXPORT QgsGeometry
     //! Constructor
     QgsGeometry();
 
-    /** copy constructor will prompt a deep copy of the object */
+    /** Copy constructor will prompt a deep copy of the object */
     QgsGeometry( const QgsGeometry & );
 
-    /** assignments will prompt a deep copy of the object
+    /** Assignments will prompt a deep copy of the object
       @note not available in python bindings
       */
     QgsGeometry & operator=( QgsGeometry const & rhs );
@@ -90,7 +91,7 @@ class CORE_EXPORT QgsGeometry
      * geom is transferred.
      * @note added in QGIS 2.10
      */
-    QgsGeometry( QgsAbstractGeometryV2* geom );
+    explicit QgsGeometry( QgsAbstractGeometryV2* geom );
 
     //! Destructor
     ~QgsGeometry();
@@ -99,7 +100,7 @@ class CORE_EXPORT QgsGeometry
      * @note added in QGIS 2.10
      * @see setGeometry
      */
-    const QgsAbstractGeometryV2* geometry() const;
+    QgsAbstractGeometryV2* geometry() const;
 
     /** Sets the underlying geometry store. Ownership of geometry is transferred.
      * @note added in QGIS 2.10
@@ -115,7 +116,7 @@ class CORE_EXPORT QgsGeometry
     bool isEmpty() const;
 
     /** Creates a new geometry from a WKT string */
-    static QgsGeometry* fromWkt( QString wkt );
+    static QgsGeometry* fromWkt( const QString& wkt );
     /** Creates a new geometry from a QgsPoint object*/
     static QgsGeometry* fromPoint( const QgsPoint& point );
     /** Creates a new geometry from a QgsMultiPoint object */
@@ -157,10 +158,11 @@ class CORE_EXPORT QgsGeometry
     size_t wkbSize() const;
 
     /** Returns a geos geometry. QgsGeometry retains ownership of the geometry, so the returned object should not be deleted.
+        @param precision The precision of the grid to which to snap the geometry vertices. If 0, no snapping is performed.
         @note this method was added in version 1.1
         @note not available in python bindings
       */
-    const GEOSGeometry* asGeos() const;
+    const GEOSGeometry* asGeos( double precision = 0 ) const;
 
     /** Returns type of the geometry as a WKB type (point / linestring / polygon etc.)
      * @see type
@@ -300,61 +302,68 @@ class CORE_EXPORT QgsGeometry
      */
     double closestSegmentWithContext( const QgsPoint& point, QgsPoint& minDistPoint, int& afterVertex, double* leftOf = 0, double epsilon = DEFAULT_SEGMENT_EPSILON ) const;
 
-    /**Adds a new ring to this geometry. This makes only sense for polygon and multipolygons.
+    /** Adds a new ring to this geometry. This makes only sense for polygon and multipolygons.
      @return 0 in case of success (ring added), 1 problem with geometry type, 2 ring not closed,
      3 ring is not valid geometry, 4 ring not disjoint with existing rings, 5 no polygon found which contained the ring*/
     int addRing( const QList<QgsPoint>& ring );
 
-    /**Adds a new ring to this geometry. This makes only sense for polygon and multipolygons.
+    /** Adds a new ring to this geometry. This makes only sense for polygon and multipolygons.
      @return 0 in case of success (ring added), 1 problem with geometry type, 2 ring not closed,
      3 ring is not valid geometry, 4 ring not disjoint with existing rings, 5 no polygon found which contained the ring*/
     int addRing( QgsCurveV2* ring );
 
-    /**Adds a new island polygon to a multipolygon feature
-     @return 0 in case of success, 1 if not a multipolygon, 2 if ring is not a valid geometry, 3 if new polygon ring
-     not disjoint with existing polygons of the feature*/
+    /** Adds a new part to a the geometry.
+     * @param points points describing part to add
+     * @param geomType default geometry type to create if no existing geometry
+     * @returns 0 in case of success, 1 if not a multipolygon, 2 if ring is not a valid geometry, 3 if new polygon ring
+     * not disjoint with existing polygons of the feature
+    */
     int addPart( const QList<QgsPoint> &points, QGis::GeometryType geomType = QGis::UnknownGeometry );
 
-    /**Adds a new part to this geometry (takes ownership)
-     @return 0 in case of success, 1 if not a multipolygon, 2 if ring is not a valid geometry, 3 if new polygon ring
-     not disjoint with existing polygons of the feature*/
-    int addPart( QgsAbstractGeometryV2* part );
+    /** Adds a new part to this geometry.
+     * @param part part to add (ownership is transferred)
+     * @param geomType default geometry type to create if no existing geometry
+     * @returns 0 in case of success, 1 if not a multipolygon, 2 if ring is not a valid geometry, 3 if new polygon ring
+     * not disjoint with existing polygons of the feature
+    */
+    int addPart( QgsAbstractGeometryV2* part, QGis::GeometryType geomType = QGis::UnknownGeometry );
 
-    /**Adds a new island polygon to a multipolygon feature
-     @return 0 in case of success, 1 if not a multipolygon, 2 if ring is not a valid geometry, 3 if new polygon ring
-     not disjoint with existing polygons of the feature
-     @note not available in python bindings
+    /** Adds a new island polygon to a multipolygon feature
+     * @param newPart part to add. Ownership is NOT transferred.
+     * @return 0 in case of success, 1 if not a multipolygon, 2 if ring is not a valid geometry, 3 if new polygon ring
+     * not disjoint with existing polygons of the feature
+     * @note not available in python bindings
      */
     int addPart( GEOSGeometry *newPart );
 
-    /**Adds a new island polygon to a multipolygon feature
+    /** Adds a new island polygon to a multipolygon feature
      @return 0 in case of success, 1 if not a multipolygon, 2 if ring is not a valid geometry, 3 if new polygon ring
      not disjoint with existing polygons of the feature
      @note available in python bindings as addPartGeometry (added in 2.2)
      */
     int addPart( const QgsGeometry *newPart );
 
-    /**Translate this geometry by dx, dy
+    /** Translate this geometry by dx, dy
      @return 0 in case of success*/
     int translate( double dx, double dy );
 
-    /**Transform this geometry as described by CoordinateTransform ct
+    /** Transform this geometry as described by CoordinateTransform ct
      @return 0 in case of success*/
     int transform( const QgsCoordinateTransform& ct );
 
-    /**Transform this geometry as described by QTransform ct
+    /** Transform this geometry as described by QTransform ct
      @note added in 2.8
      @return 0 in case of success*/
     int transform( const QTransform& ct );
 
-    /**Rotate this geometry around the Z axis
+    /** Rotate this geometry around the Z axis
          @note added in 2.8
          @param rotation clockwise rotation in degrees
          @param center rotation center
          @return 0 in case of success*/
     int rotate( double rotation, const QgsPoint& center );
 
-    /**Splits this geometry according to a given line.
+    /** Splits this geometry according to a given line.
     @param splitLine the line that splits the geometry
     @param[out] newGeometries list of new geometries that have been created with the split
     @param topological true if topological editing is enabled
@@ -365,17 +374,17 @@ class CORE_EXPORT QgsGeometry
                        bool topological,
                        QList<QgsPoint> &topologyTestPoints );
 
-    /**Replaces a part of this geometry with another line
+    /** Replaces a part of this geometry with another line
       @return 0 in case of success
       @note: this function was added in version 1.3*/
     int reshapeGeometry( const QList<QgsPoint>& reshapeWithLine );
 
-    /**Changes this geometry such that it does not intersect the other geometry
+    /** Changes this geometry such that it does not intersect the other geometry
        @param other geometry that should not be intersect
        @return 0 in case of success*/
     int makeDifference( const QgsGeometry* other );
 
-    /**Returns the bounding box of this feature*/
+    /** Returns the bounding box of this feature*/
     QgsRectangle boundingBox() const;
 
     /** Test for intersection with a rectangle (uses GEOS) */
@@ -522,13 +531,13 @@ class CORE_EXPORT QgsGeometry
      @note added in version 1.1 */
     QList<QgsGeometry*> asGeometryCollection() const;
 
-    /**Return contents of the geometry as a QPointF if wkbType is WKBPoint,
+    /** Return contents of the geometry as a QPointF if wkbType is WKBPoint,
     * otherwise returns a null QPointF.
     * @note added in QGIS 2.7
     */
     QPointF asQPointF() const;
 
-    /**Return contents of the geometry as a QPolygonF. If geometry is a linestring,
+    /** Return contents of the geometry as a QPolygonF. If geometry is a linestring,
     * then the result will be an open QPolygonF. If the geometry is a polygon,
     * then the result will be a closed QPolygonF of the geometry's exterior ring.
     * @note added in QGIS 2.7
@@ -556,6 +565,17 @@ class CORE_EXPORT QgsGeometry
      */
     bool convertToMultiType();
 
+    /**
+     * Converts multi type geometry into single type geometry
+     * e.g. a multipolygon into a polygon geometry. Only the first part of the
+     * multi geometry will be retained.
+     * If it is already a single part geometry, it will return true and
+     * not change the geometry.
+     *
+     * @return true in case of success and false else
+     */
+    bool convertToSingleType();
+
     /** Modifies geometry to avoid intersections with the layers specified in project properties
      *  @return 0 in case of success,
      *          1 if geometry is not of polygon type,
@@ -564,7 +584,7 @@ class CORE_EXPORT QgsGeometry
      *  @param ignoreFeatures possibility to give a list of features where intersections should be ignored (not available in python bindings)
      *  @note added in 1.5
      */
-    int avoidIntersections( QMap<QgsVectorLayer*, QSet<QgsFeatureId> > ignoreFeatures = ( QMap<QgsVectorLayer*, QSet<QgsFeatureId> >() ) );
+    int avoidIntersections( const QMap<QgsVectorLayer*, QSet<QgsFeatureId> >& ignoreFeatures = ( QMap<QgsVectorLayer*, QSet<QgsFeatureId> >() ) );
 
     class Error
     {
@@ -573,8 +593,8 @@ class CORE_EXPORT QgsGeometry
         bool hasLocation;
       public:
         Error() : message( "none" ), hasLocation( false ) {}
-        Error( QString m ) : message( m ), hasLocation( false ) {}
-        Error( QString m, QgsPoint p ) : message( m ), location( p ), hasLocation( true ) {}
+        explicit Error( const QString& m ) : message( m ), hasLocation( false ) {}
+        Error( const QString& m, const QgsPoint& p ) : message( m ), location( p ), hasLocation( true ) {}
 
         QString what() { return message; }
         QgsPoint where() { return location; }
@@ -587,7 +607,7 @@ class CORE_EXPORT QgsGeometry
      **/
     void validateGeometry( QList<Error> &errors );
 
-    /** compute the unary union on a list of geometries. May be faster than an iterative union on a set of geometries.
+    /** Compute the unary union on a list of geometries. May be faster than an iterative union on a set of geometries.
         @param geometryList a list of QgsGeometry* as input
         @returns the new computed QgsGeometry, or null
     */
@@ -642,19 +662,19 @@ class CORE_EXPORT QgsGeometry
      */
     int vertexNrFromVertexId( const QgsVertexId& i ) const;
 
-    /** return GEOS context handle
+    /** Return GEOS context handle
      * @note added in 2.6
      * @note not available in Python
      */
     static GEOSContextHandle_t getGEOSHandler();
 
-    /**Construct geometry from a QPointF
+    /** Construct geometry from a QPointF
     * @param point source QPointF
     * @note added in QGIS 2.7
     */
     static QgsGeometry* fromQPointF( const QPointF& point );
 
-    /**Construct geometry from a QPolygonF. If the polygon is closed than
+    /** Construct geometry from a QPolygonF. If the polygon is closed than
     * the resultant geometry will be a polygon, if it is open than the
     * geometry will be a polyline.
     * @param polygon source QPolygonF
@@ -684,7 +704,7 @@ class CORE_EXPORT QgsGeometry
      * points are equal within the specified tolerance
      * @note added in QGIS 2.9
      */
-    static bool compare( const QgsPolyline& p1, const QgsPolyline& p2, double epsilon = 4 * DBL_EPSILON );
+    static bool compare( const QgsPolyline& p1, const QgsPolyline& p2, double epsilon = 4 * std::numeric_limits<double>::epsilon() );
 
     /** Compares two polygons for equality within a specified tolerance.
      * @param p1 first polygon
@@ -694,7 +714,7 @@ class CORE_EXPORT QgsGeometry
      * number of points and all points are equal within the specified tolerance
      * @note added in QGIS 2.9
      */
-    static bool compare( const QgsPolygon& p1, const QgsPolygon& p2, double epsilon = 4 * DBL_EPSILON );
+    static bool compare( const QgsPolygon& p1, const QgsPolygon& p2, double epsilon = 4 * std::numeric_limits<double>::epsilon() );
 
     /** Compares two multipolygons for equality within a specified tolerance.
      * @param p1 first multipolygon
@@ -705,9 +725,9 @@ class CORE_EXPORT QgsGeometry
      * tolerance
      * @note added in QGIS 2.9
      */
-    static bool compare( const QgsMultiPolygon& p1, const QgsMultiPolygon& p2, double epsilon = 4 * DBL_EPSILON );
+    static bool compare( const QgsMultiPolygon& p1, const QgsMultiPolygon& p2, double epsilon = 4 * std::numeric_limits<double>::epsilon() );
 
-    /**Smooths a geometry by rounding off corners using the Chaikin algorithm. This operation
+    /** Smooths a geometry by rounding off corners using the Chaikin algorithm. This operation
     * roughly doubles the number of vertices in a geometry.
     * @param iterations number of smoothing iterations to run. More iterations results
     * in a smoother geometry
@@ -718,15 +738,27 @@ class CORE_EXPORT QgsGeometry
     */
     QgsGeometry* smooth( const unsigned int iterations = 1, const double offset = 0.25 ) const;
 
-    /**Smooths a polygon using the Chaikin algorithm*/
+    /** Smooths a polygon using the Chaikin algorithm*/
     QgsPolygon smoothPolygon( const QgsPolygon &polygon, const unsigned int iterations = 1, const double offset = 0.25 ) const;
-    /**Smooths a polyline using the Chaikin algorithm*/
+    /** Smooths a polyline using the Chaikin algorithm*/
     QgsPolyline smoothLine( const QgsPolyline &polyline, const unsigned int iterations = 1, const double offset = 0.25 ) const;
 
     /** Creates and returns a new geometry engine
      */
     static QgsGeometryEngine* createGeometryEngine( const QgsAbstractGeometryV2* geometry );
 
+    /** Upgrades a point list from QgsPoint to QgsPointV2
+     * @param input list of QgsPoint objects to be upgraded
+     * @param output destination for list of points converted to QgsPointV2
+     */
+    static void convertPointList( const QList<QgsPoint>& input, QList<QgsPointV2>& output );
+
+    /** Downgrades a point list from QgsPointV2 to QgsPoint
+     * @param input list of QgsPointV2 objects to be downgraded
+     * @param output destination for list of points converted to QgsPoint
+     */
+    static void convertPointList( const QList<QgsPointV2>& input, QList<QgsPoint>& output );
+
   private:
 
     QgsGeometryPrivate* d; //implicitely shared data pointer
@@ -734,17 +766,14 @@ class CORE_EXPORT QgsGeometry
     void detach( bool cloneGeom = true ); //make sure mGeometry only referenced from this instance
     void removeWkbGeos();
 
-    //convert point list from v1 to v2
-    static void convertPointList( const QList<QgsPoint>& input, QList<QgsPointV2>& output );
-    static void convertPointList( const QList<QgsPointV2>& input, QList<QgsPoint>& output );
     static void convertToPolyline( const QList<QgsPointV2>& input, QgsPolyline& output );
     static void convertPolygon( const QgsPolygonV2& input, QgsPolygon& output );
 
-    /** try to convert the geometry to a point */
+    /** Try to convert the geometry to a point */
     QgsGeometry* convertToPoint( bool destMultipart ) const;
-    /** try to convert the geometry to a line */
+    /** Try to convert the geometry to a line */
     QgsGeometry* convertToLine( bool destMultipart ) const;
-    /** try to convert the geometry to a polygon */
+    /** Try to convert the geometry to a polygon */
     QgsGeometry* convertToPolygon( bool destMultipart ) const;
 }; // class QgsGeometry
 
