@@ -45,7 +45,7 @@ class GUI_EXPORT QgsGraduatedSymbolRendererV2Model : public QAbstractItemModel
 
     QgsRendererRangeV2 rendererRange( const QModelIndex &index );
     void addClass( QgsSymbolV2* symbol );
-    void addClass( QgsRendererRangeV2 range );
+    void addClass( const QgsRendererRangeV2& range );
     void deleteRows( QList<int> rows );
     void removeAllRows();
     void sort( int column, Qt::SortOrder order = Qt::AscendingOrder ) override;
@@ -64,7 +64,7 @@ class GUI_EXPORT QgsGraduatedSymbolRendererV2Model : public QAbstractItemModel
 class QgsGraduatedSymbolRendererV2ViewStyle: public QProxyStyle
 {
   public:
-    QgsGraduatedSymbolRendererV2ViewStyle( QStyle* style = 0 );
+    explicit QgsGraduatedSymbolRendererV2ViewStyle( QStyle* style = 0 );
 
     void drawPrimitive( PrimitiveElement element, const QStyleOption * option, QPainter * painter, const QWidget * widget = 0 ) const override;
 };
@@ -83,7 +83,7 @@ class GUI_EXPORT QgsGraduatedSymbolRendererV2Widget : public QgsRendererV2Widget
 
   public slots:
     void changeGraduatedSymbol();
-    void graduatedColumnChanged( QString field );
+    void graduatedColumnChanged( const QString& field );
     void classifyGraduated();
     void reapplyColorRamp();
     void reapplySizes();
@@ -91,17 +91,16 @@ class GUI_EXPORT QgsGraduatedSymbolRendererV2Widget : public QgsRendererV2Widget
     void rangesClicked( const QModelIndex & idx );
     void changeCurrentValue( QStandardItem * item );
 
-    /**Adds a class manually to the classification*/
+    /** Adds a class manually to the classification*/
     void addClass();
-    /**Removes currently selected classes */
+    /** Removes currently selected classes */
     void deleteClasses();
-    /**Removes all classes from the classification*/
+    /** Removes all classes from the classification*/
     void deleteAllClasses();
-    /**Toggle the link between classes boundaries */
+    /** Toggle the link between classes boundaries */
     void toggleBoundariesLink( bool linked );
 
-    void rotationFieldChanged( QString fldName );
-    void sizeScaleFieldChanged( QString fldName );
+    void sizeScaleFieldChanged( const QString& fldName );
     void scaleMethodChanged( QgsSymbolV2::ScaleMethod scaleMethod );
     void labelFormatChanged();
 
@@ -143,8 +142,6 @@ class GUI_EXPORT QgsGraduatedSymbolRendererV2Widget : public QgsRendererV2Widget
 
     int mRowSelected;
 
-    QgsRendererV2DataDefinedMenus* mDataDefinedMenus;
-
     QgsGraduatedSymbolRendererV2Model* mModel;
 
     QgsRangeList mCopyBuffer;
