@@ -78,8 +78,7 @@ class GUI_EXPORT QgsLegendInterface : public QObject
     //! Check if a layer is visible
     virtual bool isLayerVisible( QgsMapLayer * ml ) = 0;
 
-    /** Add action for layers in the legend
-     */
+    /** Add action for layers in the legend */
     virtual void addLegendLayerAction( QAction* action, QString menu, QString id,
                                        QgsMapLayer::LayerType type, bool allLayers ) = 0;
 
@@ -122,11 +121,11 @@ class GUI_EXPORT QgsLegendInterface : public QObject
 
     //! Add a new group
     //! a parent group can be given to nest the new group in it
-    virtual int addGroup( QString name, bool expand = true, QTreeWidgetItem* parent = 0 ) = 0;
+    virtual int addGroup( const QString& name, bool expand = true, QTreeWidgetItem* parent = 0 ) = 0;
 
     //! Add a new group
     //! a parent group index has to be given to nest the new group in it
-    virtual int addGroup( QString name, bool expand, int parentIndex ) = 0;
+    virtual int addGroup( const QString& name, bool expand, int parentIndex ) = 0;
 
     //! Remove group on index
     virtual void removeGroup( int groupIndex ) = 0;
@@ -147,7 +146,6 @@ class GUI_EXPORT QgsLegendInterface : public QObject
     virtual void setLayerVisible( QgsMapLayer * ml, bool visible ) = 0;
 
     //! Refresh layer symbology
-
     virtual void refreshLayerSymbology( QgsMapLayer *ml ) = 0;
 };
 
