@@ -18,12 +18,11 @@
 #ifndef QGSMAPCANVASSNAPPER_H
 #define QGSMAPCANVASSNAPPER_H
 
-#include "qgssnapper.h"
 #include <QList>
+#include "qgssnapper.h"
 
 class QgsMapCanvas;
 class QPoint;
-class QgsSnapper;
 
 /** \ingroup gui
  * This class reads the snapping properties from the current project and
@@ -34,7 +33,7 @@ class QgsSnapper;
 class GUI_EXPORT QgsMapCanvasSnapper
 {
   public:
-    /**Constructor
+    /** Constructor
      @param canvas the map canvas to snap to*/
     QgsMapCanvasSnapper( QgsMapCanvas* canvas );
 
@@ -42,7 +41,7 @@ class GUI_EXPORT QgsMapCanvasSnapper
 
     ~QgsMapCanvasSnapper();
 
-    /**Does a snap to the current layer. Uses snap mode
+    /** Does a snap to the current layer. Uses snap mode
        QgsSnapper::SnapWithResultsForSamePosition if topological editing is enabled
        and QgsSnapper::SnapWithOneResult_BY_SEGMENT if not. As this method is usually used to
        find vertices/segments for editing operations, it uses the search radius for vertex
@@ -53,7 +52,7 @@ class GUI_EXPORT QgsMapCanvasSnapper
        @param snappingTol snapping tolerance. -1 means that the search radius for vertex edits is taken
        @param excludePoints a list with (map coordinate) points that should be excluded in the snapping result. Useful e.g. for vertex moves where a vertex should not be snapped to its original position*/
     int snapToCurrentLayer( const QPoint& p, QList<QgsSnappingResult>& results, QgsSnapper::SnappingType snap_to, double snappingTol = -1, const QList<QgsPoint>& excludePoints = QList<QgsPoint>() );
-    /**Snaps to the background layers. This method is useful to align the features of the
+    /** Snaps to the background layers. This method is useful to align the features of the
        edited layers to those of other layers (as described in the project properties).
        Uses snap mode QgsSnapper::SnapWithOneResult. Therefore, only the
        closest result is returned.
@@ -62,13 +61,14 @@ class GUI_EXPORT QgsMapCanvasSnapper
        @param excludePoints a list with (map coordinate) points that should be excluded in the snapping result. Useful e.g. for vertex moves where a vertex should not be snapped to its original position
        @return 0 in case of success*/
     int snapToBackgroundLayers( const QPoint& p, QList<QgsSnappingResult>& results, const QList<QgsPoint>& excludePoints = QList<QgsPoint>() );
+    int snapToBackgroundLayers( const QgsPoint& point, QList<QgsSnappingResult>& results, const QList<QgsPoint>& excludePoints = QList<QgsPoint>() );
 
     void setMapCanvas( QgsMapCanvas* canvas );
 
   private:
-    /**Pointer to the map canvas*/
+    /** Pointer to the map canvas*/
     QgsMapCanvas* mMapCanvas;
-    /**The object which does the snapping operations*/
+    /** The object which does the snapping operations*/
     QgsSnapper* mSnapper;
 };
 
