@@ -44,10 +44,10 @@ class CORE_EXPORT QgsMapLayerRegistry : public QObject
     ~QgsMapLayerRegistry();
 
     //! Retrieve a pointer to a loaded layer by id
-    QgsMapLayer *mapLayer( QString theLayerId );
+    QgsMapLayer *mapLayer( const QString& theLayerId );
 
     //! Retrieve a pointer to a loaded layer by name
-    QList<QgsMapLayer *> mapLayersByName( QString layerName );
+    QList<QgsMapLayer *> mapLayersByName( const QString& layerName );
 
     //! Retrieve the mapLayers collection (mainly intended for use by projection)
     const QMap<QString, QgsMapLayer*> & mapLayers();
@@ -74,7 +74,7 @@ class CORE_EXPORT QgsMapLayerRegistry : public QObject
      * @note As a side-effect QgsProject is made dirty.
      * @note takeOwner not available in python binding - always takes ownership
      */
-    QList<QgsMapLayer *> addMapLayers( QList<QgsMapLayer *> theMapLayers,
+    QList<QgsMapLayer *> addMapLayers( const QList<QgsMapLayer*>& theMapLayers,
                                        bool addToLegend = true,
                                        bool takeOwnership = true );
 
@@ -118,7 +118,7 @@ class CORE_EXPORT QgsMapLayerRegistry : public QObject
      *
      * @note As a side-effect QgsProject is made dirty.
      */
-    void removeMapLayers( QStringList theLayerIds );
+    void removeMapLayers( const QStringList& theLayerIds );
 
     /**
      * @brief
@@ -231,7 +231,7 @@ class CORE_EXPORT QgsMapLayerRegistry : public QObject
 
   protected:
 #if 0
-    /** debugging member
+    /** Debugging member
         invoked when a connect() is made to this object
     */
     void connectNotify( const char * signal ) override;
