@@ -29,6 +29,7 @@
 
 #include "qgsgeometrycache.h"
 
+class QgsLabelingEngineV2;
 class QgsLabelingResults;
 class QgsMapLayerRenderer;
 class QgsMapRendererCache;
@@ -126,6 +127,13 @@ class CORE_EXPORT QgsMapRendererJob : public QObject
     //! Find out how log it took to finish the job (in miliseconds)
     int renderingTime() const { return mRenderingTime; }
 
+    /**
+     * Return map settings with which this job was started.
+     * @return A QgsMapSettings instance with render settings
+     * @note added in 2.8
+     */
+    const QgsMapSettings& mapSettings() const;
+
   signals:
 
     //! emitted when asynchronous rendering is finished (or canceled).
@@ -142,7 +150,7 @@ class CORE_EXPORT QgsMapRendererJob : public QObject
     static bool reprojectToLayerExtent( const QgsCoordinateTransform* ct, bool layerCrsGeographic, QgsRectangle& extent, QgsRectangle& r2 );
 
     //! @note not available in python bindings
-    LayerRenderJobs prepareJobs( QPainter* painter, QgsPalLabeling* labelingEngine );
+    LayerRenderJobs prepareJobs( QPainter* painter, QgsPalLabeling* labelingEngine, QgsLabelingEngineV2* labelingEngine2 );
 
     //! @note not available in python bindings
     void cleanupJobs( LayerRenderJobs& jobs );
@@ -151,7 +159,7 @@ class CORE_EXPORT QgsMapRendererJob : public QObject
 
     bool needTemporaryImage( QgsMapLayer* ml );
 
-    static void drawLabeling( const QgsMapSettings& settings, QgsRenderContext& renderContext, QgsPalLabeling* labelingEngine, QPainter* painter );
+    static void drawLabeling( const QgsMapSettings& settings, QgsRenderContext& renderContext, QgsPalLabeling* labelingEngine, QgsLabelingEngineV2* labelingEngine2, QPainter* painter );
     static void drawOldLabeling( const QgsMapSettings& settings, QgsRenderContext& renderContext );
     static void drawNewLabeling( const QgsMapSettings& settings, QgsRenderContext& renderContext, QgsPalLabeling* labelingEngine );
 
