@@ -12,19 +12,29 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-/* $Id: qgsmaptool.h 13187 2010-03-28 22:14:44Z jef $ */
 
 #ifndef QGSMAPTOOL_H
 #define QGSMAPTOOL_H
 
+#include "qgsconfig.h"
+#include "qgsmessagebar.h"
+#include "qgspointv2.h"
+#include "qgsmapmouseevent.h"
+
 #include <QCursor>
 #include <QString>
 #include <QObject>
 
+#ifdef HAVE_TOUCH
+#include <QGestureEvent>
+#endif
+
 class QgsMapLayer;
 class QgsMapCanvas;
+class QgsRenderContext;
 class QKeyEvent;
 class QMouseEvent;
+class QWheelEvent;
 class QgsPoint;
 class QgsRectangle;
 class QPoint;
@@ -39,32 +49,43 @@ class QAbstractButton;
  */
 class GUI_EXPORT QgsMapTool : public QObject
 {
+
+    Q_OBJECT
+
   public:
 
     //! virtual destructor
     virtual ~QgsMapTool();
 
     //! Mouse move event for overriding. Default implementation does nothing.
-    virtual void canvasMoveEvent( QMouseEvent * e );
+    virtual void canvasMoveEvent( QgsMapMouseEvent* e );
 
     //! Mouse double click event for overriding. Default implementation does nothing.
-    virtual void canvasDoubleClickEvent( QMouseEvent * e );
+    virtual void canvasDoubleClickEvent( QgsMapMouseEvent* e );
 
     //! Mouse press event for overriding. Default implementation does nothing.
-    virtual void canvasPressEvent( QMouseEvent * e );
+    virtual void canvasPressEvent( QgsMapMouseEvent* e );
 
     //! Mouse release event for overriding. Default implementation does nothing.
-    virtual void canvasReleaseEvent( QMouseEvent * e );
+    virtual void canvasReleaseEvent( QgsMapMouseEvent* e );
+
+    //! Mouse wheel event for overriding. Default implementation does nothing.
+    virtual void wheelEvent( QWheelEvent* e );
 
     //! Key event for overriding. Default implementation does nothing.
     virtual void keyPressEvent( QKeyEvent* e );
 
     //! Key event for overriding. Default implementation does nothing.
-    //! Added in version 1.1
     virtual void keyReleaseEvent( QKeyEvent* e );
 
+#ifdef HAVE_TOUCH
+    //! gesture event for overriding. Default implementation does nothing.
+    virtual bool gestureEvent( QGestureEvent* e );
+#endif
+
     //! Called when rendering has finished. Default implementation does nothing.
-    virtual void renderComplete();
+    //! @deprecated since 2.4 - not called anymore - map tools must not directly depend on rendering progress
+    Q_DECL_DEPRECATED virtual void renderComplete();
 
 
     /** Use this to associate a QAction to this maptool. Then when the setMapTool
@@ -83,6 +104,8 @@ class GUI_EXPORT QgsMapTool : public QObject
     /** Return associated button with map tool or NULL if no button is associated */
     QAbstractButton* button();
 
+    /** Set a user defined cursor */
+    virtual void setCursor( const QCursor& cursor );
 
     /** Check whether this MapTool performs a zoom or pan operation.
      * If it does, we will be able to perform the zoom  and then
@@ -103,6 +126,43 @@ class GUI_EXPORT QgsMapTool : public QObject
     //! returns pointer to the tool's map canvas
     QgsMapCanvas* canvas();
 
+    //! Emit map tool changed with the old tool
+    //! @note added in 2.3
+    QString toolName() { return mToolName; }
+
+    /** Get search radius in mm. Used by identify, tip etc.
+     *  The values is currently set in identify tool options (move somewhere else?)
+     *  and defaults to QGis::DEFAULT_SEARCH_RADIUS_MM.
+     *  @note added in 2.3 */
+    static double searchRadiusMM();
+
+    /** Get search radius in map units for given context. Used by identify, tip etc.
+     *  The values is calculated from searchRadiusMM().
+     *  @note added in 2.3 */
+    static double searchRadiusMU( const QgsRenderContext& context );
+
+    /** Get search radius in map units for given canvas. Used by identify, tip etc.
+     *  The values is calculated from searchRadiusMM().
+     *  @note added in 2.3 */
+    static double searchRadiusMU( QgsMapCanvas * canvas );
+
+  signals:
+    //! emit a message
+    void messageEmitted( QString message, QgsMessageBar::MessageLevel = QgsMessageBar::INFO );
+
+    //! emit signal to clear previous message
+    void messageDiscarded();
+
+    //! signal emitted once the map tool is activated
+    void activated();
+
+    //! signal emitted once the map tool is deactivated
+    void deactivated();
+
+  private slots:
+    //! clear pointer when action is destroyed
+    void actionDestroyed();
+
   protected:
 
     //! constructor takes map canvas as a parameter
@@ -114,12 +174,15 @@ class GUI_EXPORT QgsMapTool : public QObject
     //! transformation from screen coordinates to layer's coordinates
     QgsPoint toLayerCoordinates( QgsMapLayer* layer, const QPoint& point );
 
-    //! trasformation from map coordinates to layer's coordinates
+    //! transformation from map coordinates to layer's coordinates
     QgsPoint toLayerCoordinates( QgsMapLayer* layer, const QgsPoint& point );
 
     //!transformation from layer's coordinates to map coordinates (which is different in case reprojection is used)
     QgsPoint toMapCoordinates( QgsMapLayer* layer, const QgsPoint& point );
 
+    //!transformation from layer's coordinates to map coordinates (which is different in case reprojection is used)
+    QgsPointV2 toMapCoordinates( QgsMapLayer* layer, const QgsPointV2 &point );
+
     //! trnasformation of the rect from map coordinates to layer's coordinates
     QgsRectangle toLayerCoordinates( QgsMapLayer* layer, const QgsRectangle& rect );
 
@@ -140,6 +203,8 @@ class GUI_EXPORT QgsMapTool : public QObject
     //! which will be used to set that action as active
     QAbstractButton* mButton;
 
+    //! translated name of the map tool
+    QString mToolName;
 };
 
 #endif
