@@ -31,20 +31,20 @@ class CORE_EXPORT QgsPluginLayerType
 {
   public:
 
-    QgsPluginLayerType( QString name );
+    QgsPluginLayerType( const QString& name );
     virtual ~QgsPluginLayerType();
 
     QString name();
 
-    /** return new layer of this type. Return NULL on error */
+    /** Return new layer of this type. Return NULL on error */
     virtual QgsPluginLayer* createLayer();
 
-    /** return new layer of this type, using layer URI (specific to this plugin layer type). Return NULL on error.
+    /** Return new layer of this type, using layer URI (specific to this plugin layer type). Return NULL on error.
      * @note added in 2.10
      */
     virtual QgsPluginLayer* createLayer( const QString& uri );
 
-    /** show plugin layer properties dialog. Return false if the dialog cannot be shown. */
+    /** Show plugin layer properties dialog. Return false if the dialog cannot be shown. */
     virtual bool showLayerProperties( QgsPluginLayer* layer );
 
   protected:
@@ -60,37 +60,37 @@ class CORE_EXPORT QgsPluginLayerRegistry
 {
   public:
 
-    /** means of accessing canonical single instance  */
+    /** Means of accessing canonical single instance  */
     static QgsPluginLayerRegistry* instance();
 
     ~QgsPluginLayerRegistry();
 
-    /** list all known layer types
+    /** List all known layer types
      *  \note added in v2.1 */
     QStringList pluginLayerTypes();
 
-    /** add plugin layer type (take ownership) and return true on success */
+    /** Add plugin layer type (take ownership) and return true on success */
     bool addPluginLayerType( QgsPluginLayerType* pluginLayerType );
 
-    /** remove plugin layer type and return true on success */
-    bool removePluginLayerType( QString typeName );
+    /** Remove plugin layer type and return true on success */
+    bool removePluginLayerType( const QString& typeName );
 
-    /** return plugin layer type metadata or NULL if doesn't exist */
-    QgsPluginLayerType* pluginLayerType( QString typeName );
+    /** Return plugin layer type metadata or NULL if doesn't exist */
+    QgsPluginLayerType* pluginLayerType( const QString& typeName );
 
-    /** return new layer if corresponding plugin has been found, else return NULL.
+    /** Return new layer if corresponding plugin has been found, else return NULL.
      * @note optional param uri added in 2.10
      */
-    QgsPluginLayer* createLayer( QString typeName, const QString& uri = QString() );
+    QgsPluginLayer* createLayer( const QString& typeName, const QString& uri = QString() );
 
   private:
 
     typedef QMap<QString, QgsPluginLayerType*> PluginLayerTypes;
 
-    /** private since instance() creates it */
+    /** Private since instance() creates it */
     QgsPluginLayerRegistry();
 
-    /** pointer to canonical Singleton object */
+    /** Pointer to canonical Singleton object */
     static QgsPluginLayerRegistry* _instance;
 
     PluginLayerTypes mPluginLayerTypes;
