@@ -22,7 +22,6 @@
  * perform upgrades to a more recent version
  */
 
-/* $Id$ */
 
 #ifndef QGSPROJECTFILETRANSFORM_H
 #define QGSPROJECTFILETRANSFORM_H
@@ -32,31 +31,34 @@
 #include <vector>
 #include "qgsprojectversion.h"
 
-class QgsProjectFileTransform
+class QgsRasterLayer;
+
+class CORE_EXPORT QgsProjectFileTransform
 {
   public:
     //Default constructor
     //QgsProjectfiletransform() {}
     ~QgsProjectFileTransform() {}
 
-    /*! Create an instance from a Dom and a supplied version
+    /** Create an instance from a Dom and a supplied version
      * @param domDocument The Dom document to use as content
      * @param version Version number
      */
     QgsProjectFileTransform( QDomDocument & domDocument,
-                             QgsProjectVersion version )
+                             const QgsProjectVersion& version )
     {
       mDom = domDocument;
       mCurrentVersion = version;
     }
 
 
-    bool updateRevision( QgsProjectVersion version );
+    bool updateRevision( const QgsProjectVersion& version );
 
-    /*! Prints the contents via QgsDebugMsg()
+    /** Prints the contents via QgsDebugMsg()
      */
     void dump();
 
+    static void convertRasterProperties( QDomDocument& doc, QDomNode& parentNode, QDomElement& rasterPropertiesElem, QgsRasterLayer* rlayer );
 
   private:
 
@@ -82,6 +84,13 @@ class QgsProjectFileTransform
     void transform0110to1000();
     void transform1100to1200();
     void transform1400to1500();
+    void transform1800to1900();
+    void transform2200to2300();
+
+    //helper functions
+    static int rasterBandNumber( const QDomElement &rasterPropertiesElem, const QString &bandName, QgsRasterLayer *rlayer );
+    static void transformContrastEnhancement( QDomDocument &doc, const QDomElement &rasterproperties, QDomElement &rendererElem );
+    static void transformRasterTransparency( QDomDocument& doc, const QDomElement& orig, QDomElement& rendererElem );
 };
 
 
