@@ -25,13 +25,11 @@ class QResizeEvent;
  * @see QgsGenericProjectionSelector.
   @author Tim Sutton
   */
-class GUI_EXPORT QgsProjectionSelector: public QWidget, private Ui::QgsProjectionSelectorBase
+class GUI_EXPORT QgsProjectionSelector : public QWidget, private Ui::QgsProjectionSelectorBase
 {
     Q_OBJECT
   public:
-    QgsProjectionSelector( QWidget* parent,
-                           const char * name = "",
-                           Qt::WFlags fl = 0 );
+    QgsProjectionSelector( QWidget* parent, const char *name = "", const Qt::WindowFlags& fl = 0 );
 
     ~QgsProjectionSelector();
 
@@ -44,7 +42,7 @@ class GUI_EXPORT QgsProjectionSelector: public QWidget, private Ui::QgsProjectio
      *
      * \todo Should this be public?
      */
-    void loadUserCrsList( QSet<QString> * crsFilter = 0 );
+    void loadUserCrsList( QSet<QString> *crsFilter = 0 );
 
     /**
      * \brief Populate the proj tree view with system projection names...
@@ -55,8 +53,7 @@ class GUI_EXPORT QgsProjectionSelector: public QWidget, private Ui::QgsProjectio
      *
      * \todo Should this be public?
      */
-    void loadCrsList( QSet<QString> * crsFilter = 0 );
-
+    void loadCrsList( QSet<QString> *crsFilter = 0 );
 
     /*!
      * \brief Make the string safe for use in SQL statements.
@@ -67,30 +64,19 @@ class GUI_EXPORT QgsProjectionSelector: public QWidget, private Ui::QgsProjectio
      * \arg const QString in The input string to make safe.
      * \return The string made safe for SQL statements.
      */
-    const QString sqlSafeString( const QString theSQL );
-
-    //! Gets the current EpsgCrsId-style projection identifier
-    // @deprecated there are other authorities - use selectedAuthId()
-    Q_DECL_DEPRECATED long selectedEpsg();
-
-    //! Gets the current InternalCrsId-style projection identifier
-    long selectedSrsid();
+    const QString sqlSafeString( const QString& theSQL );
 
     //! Gets the current authority-style projection identifier
     QString selectedAuthId();
 
   public slots:
-    void setSelectedCrsName( QString theCRSName );
+    void setSelectedCrsName( const QString& theCRSName );
 
     QString selectedName();
 
     void setSelectedCrsId( long theCRSID );
 
-    void setSelectedAuthId( QString authId );
-
-    //! Get the selected coordinate system
-    // @deprecated there are other authorities - so not always defined
-    Q_DECL_DEPRECATED void setSelectedEpsg( long epsg );
+    void setSelectedAuthId( const QString& authId );
 
     QString selectedProj4String();
 
@@ -112,18 +98,21 @@ class GUI_EXPORT QgsProjectionSelector: public QWidget, private Ui::QgsProjectio
      *
      * \warning This function's behaviour is undefined if it is called after the widget is shown.
      */
-    void setOgcWmsCrsFilter( QSet<QString> crsFilter );
-
-    void on_pbnFind_clicked();
-    void on_lstRecent_currentItemChanged( QTreeWidgetItem *, QTreeWidgetItem * );
+    void setOgcWmsCrsFilter( const QSet<QString>& crsFilter );
+    void on_lstCoordinateSystems_currentItemChanged( QTreeWidgetItem *current, QTreeWidgetItem *prev );
+    void on_lstRecent_currentItemChanged( QTreeWidgetItem *current, QTreeWidgetItem *prev );
     void on_cbxHideDeprecated_stateChanged();
+    void on_leSearch_textChanged( const QString & );
+
+    //! mark selected projection for push to front
+    void pushProjectionToFront();
 
   protected:
     /** Used to ensure the projection list view is actually populated */
-    void showEvent( QShowEvent * theEvent );
+    void showEvent( QShowEvent * theEvent ) override;
 
     /** Used to manage column sizes */
-    void resizeEvent( QResizeEvent * theEvent );
+    void resizeEvent( QResizeEvent * theEvent ) override;
 
   private:
     /**
@@ -149,17 +138,17 @@ class GUI_EXPORT QgsProjectionSelector: public QWidget, private Ui::QgsProjectio
      *          does not scroll the list to the selection if the widget is not visible.
      *          Therefore you will typically want to use this in a showEvent().
      */
-    void applySelection();
+    void applySelection( int column = NONE, QString value = QString::null );
 
     /**
        * \brief gets an arbitrary sqlite3 expression from the selection
        *
        * \param e The sqlite3 expression (typically "srid" or "sridid")
        */
-    QString getSelectedExpression( QString e );
+    QString getSelectedExpression( const QString& e );
 
     /** Show the user a warning if the srs database could not be found */
-    void showDBMissingWarning( const QString theFileName );
+    void showDBMissingWarning( const QString& theFileName );
     // List view nodes for the tree view of projections
     //! User defined projections node
     QTreeWidgetItem *mUserProjList;
@@ -176,7 +165,7 @@ class GUI_EXPORT QgsProjectionSelector: public QWidget, private Ui::QgsProjectio
     /**
      * Utility method used in conjunction with name based searching tool
      */
-    long getLargestCRSIDMatch( QString theSql );
+    long getLargestCRSIDMatch( const QString& theSql );
 
     //! add recently used CRS
     void insertRecent( long theCrsId );
@@ -187,26 +176,15 @@ class GUI_EXPORT QgsProjectionSelector: public QWidget, private Ui::QgsProjectio
     //! Has the User Projection List been populated?
     bool mUserProjListDone;
 
+
     //! Has the Recent Projection List been populated?
     bool mRecentProjListDone;
 
-    //! Is there a pending selection to be made by CRS Name?
-    bool mCRSNameSelectionPending;
+    enum columns { NAME_COLUMN, AUTHID_COLUMN, QGIS_CRS_ID_COLUMN, NONE };
+    int mSearchColumn;
+    QString mSearchValue;
 
-    //! Is there a pending selection to be made by CRS ID?
-    bool mCRSIDSelectionPending;
-
-    //! Is there a pending selection to be made by Authority ID?
-    bool mAuthIDSelectionPending;
-
-    //! The CRS Name that wants to be selected on this widget
-    QString mCRSNameSelection;
-
-    //! The CRS ID that wants to be selected on this widget
-    long mCRSIDSelection;
-
-    //! The Authority ID that wants to be selected on this widget
-    QString mAuthIDSelection;
+    bool mPushProjectionToFront;
 
     //! The set of OGC WMS CRSs that want to be applied to this widget
     QSet<QString> mCrsFilter;
@@ -218,11 +196,6 @@ class GUI_EXPORT QgsProjectionSelector: public QWidget, private Ui::QgsProjectio
     void hideDeprecated( QTreeWidgetItem *item );
 
   private slots:
-    /**private handler for when user selects a cs
-     *it will cause wktSelected and sridSelected events to be spawned
-     */
-    void coordinateSystemSelected( QTreeWidgetItem* );
-
     //! get list of authorities
     QStringList authorities();
 
@@ -232,6 +205,9 @@ class GUI_EXPORT QgsProjectionSelector: public QWidget, private Ui::QgsProjectio
     void refresh();
     //! Let listeners know if find has focus so they can adjust the default button
     void searchBoxHasFocus( bool );
+    //! Notify others that the widget is now fully initialized, including deferred selection of projection
+    //! @note added in 2.4
+    void initialized();
 };
 
 #endif
