@@ -146,16 +146,16 @@ class CORE_EXPORT QgsRasterLayer : public QgsMapLayer
 {
     Q_OBJECT
   public:
-    /**  \brief Default cumulative cut lower limit */
+    /** \brief Default cumulative cut lower limit */
     static const double CUMULATIVE_CUT_LOWER;
 
-    /**  \brief Default cumulative cut upper limit */
+    /** \brief Default cumulative cut upper limit */
     static const double CUMULATIVE_CUT_UPPER;
 
-    /**  \brief Default sample size (number of pixels) for estimated statistics/histogram calculation */
+    /** \brief Default sample size (number of pixels) for estimated statistics/histogram calculation */
     static const double SAMPLE_SIZE;
 
-    /**  \brief Constructor. Provider is not set. */
+    /** \brief Constructor. Provider is not set. */
     QgsRasterLayer();
 
     /** \brief This is the constructor for the RasterLayer class.
@@ -183,7 +183,7 @@ class CORE_EXPORT QgsRasterLayer : public QgsMapLayer
     //as the previous constructor will be called with the literal for providerKey
     //implicitly converted to a bool.
     //for QGIS 3.0, make either constructor explicit or alter the signatures
-    /**  \brief [ data provider interface ] Constructor in provider mode */
+    /** \brief [ data provider interface ] Constructor in provider mode */
     QgsRasterLayer( const QString &uri,
                     const QString &baseName,
                     const QString &providerKey,
@@ -222,17 +222,17 @@ class CORE_EXPORT QgsRasterLayer : public QgsMapLayer
     /** Return time stamp for given file name */
     static QDateTime lastModified( const QString &  name );
 
-    /**  [ data provider interface ] Set the data provider */
+    /** [ data provider interface ] Set the data provider */
     void setDataProvider( const QString & provider );
 
     /** \brief  Accessor for raster layer type (which is a read only property) */
     LayerType rasterType() { return mRasterType; }
 
-    /**Set raster renderer. Takes ownership of the renderer object*/
+    /** Set raster renderer. Takes ownership of the renderer object*/
     void setRenderer( QgsRasterRenderer* theRenderer );
     QgsRasterRenderer* renderer() const { return mPipe.renderer(); }
 
-    /**Set raster resample filter. Takes ownership of the resample filter object*/
+    /** Set raster resample filter. Takes ownership of the resample filter object*/
     QgsRasterResampleFilter * resampleFilter() const { return mPipe.resampleFilter(); }
 
     QgsBrightnessContrastFilter * brightnessFilter() const { return mPipe.brightnessFilter(); }
@@ -261,7 +261,7 @@ class CORE_EXPORT QgsRasterLayer : public QgsMapLayer
      */
     const QgsRasterDataProvider* dataProvider() const;
 
-    /**Synchronises with changes in the datasource */
+    /** Synchronises with changes in the datasource */
     virtual void reload() override;
 
     /** Return new instance of QgsMapLayerRenderer that will be used for rendering of given context
@@ -277,7 +277,7 @@ class CORE_EXPORT QgsRasterLayer : public QgsMapLayer
                QgsRasterViewPort * myRasterViewPort,
                const QgsMapToPixel* theQgsMapToPixel = 0 );
 
-    /**Returns a list with classification items (Text and color) */
+    /** Returns a list with classification items (Text and color) */
     QgsLegendColorList legendSymbologyItems() const;
 
     /** \brief Obtain GDAL Metadata for this layer */
@@ -286,7 +286,7 @@ class CORE_EXPORT QgsRasterLayer : public QgsMapLayer
     /** \brief Get an 100x100 pixmap of the color palette. If the layer has no palette a white pixmap will be returned */
     QPixmap paletteAsPixmap( int theBandNumber = 1 );
 
-    /**  \brief [ data provider interface ] Which provider is being used for this Raster Layer? */
+    /** \brief [ data provider interface ] Which provider is being used for this Raster Layer? */
     QString providerType() const;
 
     /** \brief Returns the number of raster units per each raster pixel. In a world file, this is normally the first row (without the sign) */
@@ -303,7 +303,7 @@ class CORE_EXPORT QgsRasterLayer : public QgsMapLayer
 
     void setContrastEnhancement( QgsContrastEnhancement::ContrastEnhancementAlgorithm theAlgorithm,
                                  QgsRaster::ContrastEnhancementLimits theLimits = QgsRaster::ContrastEnhancementMinMax,
-                                 QgsRectangle theExtent = QgsRectangle(),
+                                 const QgsRectangle& theExtent = QgsRectangle(),
                                  int theSampleSize = SAMPLE_SIZE,
                                  bool theGenerateLookupTableFlag = true );
 
@@ -315,7 +315,7 @@ class CORE_EXPORT QgsRasterLayer : public QgsMapLayer
      */
     Q_DECL_DEPRECATED void setDrawingStyle( const QString & theDrawingStyleQString );
 
-    /**  \brief [ data provider interface ] A wrapper function to emit a progress update signal */
+    /** \brief [ data provider interface ] A wrapper function to emit a progress update signal */
     void showProgress( int theValue );
 
     /** \brief Returns the sublayers of this layer - Useful for providers that manage their own layers, such as WMS */
@@ -323,11 +323,11 @@ class CORE_EXPORT QgsRasterLayer : public QgsMapLayer
 
     /** \brief Draws a preview of the rasterlayer into a pixmap
     @note - use previewAsImage() for rendering with QGIS>=2.4 */
-    Q_DECL_DEPRECATED QPixmap previewAsPixmap( QSize size, QColor bgColor = Qt::white );
+    Q_DECL_DEPRECATED QPixmap previewAsPixmap( const QSize& size, const QColor& bgColor = Qt::white );
 
     /** \brief Draws a preview of the rasterlayer into a QImage
      @note added in 2.4 */
-    QImage previewAsImage( QSize size, QColor bgColor = Qt::white,
+    QImage previewAsImage( const QSize& size, const QColor& bgColor = Qt::white,
                            QImage::Format format = QImage::Format_ARGB32_Premultiplied );
 
     /**
@@ -341,7 +341,7 @@ class CORE_EXPORT QgsRasterLayer : public QgsMapLayer
     /**
      * Set the visibility of the given sublayer name
      */
-    virtual void setSubLayerVisibility( QString name, bool vis ) override;
+    virtual void setSubLayerVisibility( const QString& name, bool vis ) override;
 
     /** Time stamp of data source in the moment when data/metadata were loaded by provider */
     virtual QDateTime timestamp() const override { return mDataProvider->timestamp() ; }
@@ -353,7 +353,7 @@ class CORE_EXPORT QgsRasterLayer : public QgsMapLayer
     Q_DECL_DEPRECATED void updateProgress( int, int );
 
     /** \brief receive progress signal from provider */
-    void onProgress( int, double, QString );
+    void onProgress( int, double, const QString& );
 
   signals:
     /** \brief Signal for notifying listeners of long running processes */
@@ -382,7 +382,7 @@ class CORE_EXPORT QgsRasterLayer : public QgsMapLayer
     /** \brief Update the layer if it is outdated */
     bool update();
 
-    /**Sets corresponding renderer for style*/
+    /** Sets corresponding renderer for style*/
     void setRendererForDrawingStyle( const QgsRaster::DrawingStyle &  theDrawingStyle );
 
     /** \brief  Constant defining flag for XML and a constant that signals property not used */
@@ -392,12 +392,12 @@ class CORE_EXPORT QgsRasterLayer : public QgsMapLayer
     /** Pointer to data provider */
     QgsRasterDataProvider* mDataProvider;
 
-    /**  [ data provider interface ] Timestamp, the last modified time of the data source when the layer was created */
+    /** [ data provider interface ] Timestamp, the last modified time of the data source when the layer was created */
     QDateTime mLastModified;
 
     QgsRasterViewPort mLastViewPort;
 
-    /**  [ data provider interface ] Data provider key */
+    /** [ data provider interface ] Data provider key */
     QString mProviderKey;
 
     LayerType mRasterType;
