@@ -41,6 +41,9 @@ class GUI_EXPORT QgsStyleV2ManagerDialog : public QDialog, private Ui::QgsStyleV
     void addItem();
     void editItem();
     void removeItem();
+    void exportItemsSVG();
+    void exportItemsPNG();
+    void exportSelectedItemsImages( const QString& dir, const QString& format, const QSize& size );
     void exportItems();
     void importItems();
 
@@ -70,7 +73,7 @@ class GUI_EXPORT QgsStyleV2ManagerDialog : public QDialog, private Ui::QgsStyleV
     void regrouped( QStandardItem* );
 
     //! filter the symbols based on input search term
-    void filterSymbols( QString );
+    void filterSymbols( const QString& );
 
     //! Listen to tag changes
     void tagsChanged();
@@ -97,13 +100,13 @@ class GUI_EXPORT QgsStyleV2ManagerDialog : public QDialog, private Ui::QgsStyleV
     //! build the groups tree
     void buildGroupTree( QStandardItem* &parent );
     //! to set symbols checked when in editing mode
-    void setSymbolsChecked( QStringList );
+    void setSymbolsChecked( const QStringList& );
 
     //! populate list view with symbols of the current type with the given names
-    void populateSymbols( QStringList symbolNames, bool checkable = false );
+    void populateSymbols( const QStringList& symbolNames, bool checkable = false );
 
     //! populate list view with color ramps
-    void populateColorRamps( QStringList colorRamps, bool checkable = false );
+    void populateColorRamps( const QStringList& colorRamps, bool checkable = false );
 
     int currentItemType();
     QString currentItemName();
@@ -127,7 +130,7 @@ class GUI_EXPORT QgsStyleV2ManagerDialog : public QDialog, private Ui::QgsStyleV
     void enableItemsForGroupingMode( bool );
 
     //! Event filter to capture tagsLineEdit out of focus
-    bool eventFilter( QObject*, QEvent* );
+    bool eventFilter( QObject*, QEvent* ) override;
 
     //! sets the text of the item with bold font
     void setBold( QStandardItem* );
