@@ -46,41 +46,41 @@ class CORE_EXPORT QgsSymbolLayerV2Utils
 {
   public:
 
-    static QString encodeColor( QColor color );
-    static QColor decodeColor( QString str );
+    static QString encodeColor( const QColor& color );
+    static QColor decodeColor( const QString& str );
 
     static QString encodeSldAlpha( int alpha );
-    static int decodeSldAlpha( QString str );
+    static int decodeSldAlpha( const QString& str );
 
     static QString encodeSldFontStyle( QFont::Style style );
-    static QFont::Style decodeSldFontStyle( QString str );
+    static QFont::Style decodeSldFontStyle( const QString& str );
 
     static QString encodeSldFontWeight( int weight );
-    static int decodeSldFontWeight( QString str );
+    static int decodeSldFontWeight( const QString& str );
 
     static QString encodePenStyle( Qt::PenStyle style );
-    static Qt::PenStyle decodePenStyle( QString str );
+    static Qt::PenStyle decodePenStyle( const QString& str );
 
     static QString encodePenJoinStyle( Qt::PenJoinStyle style );
-    static Qt::PenJoinStyle decodePenJoinStyle( QString str );
+    static Qt::PenJoinStyle decodePenJoinStyle( const QString& str );
 
     static QString encodePenCapStyle( Qt::PenCapStyle style );
-    static Qt::PenCapStyle decodePenCapStyle( QString str );
+    static Qt::PenCapStyle decodePenCapStyle( const QString& str );
 
     static QString encodeSldLineJoinStyle( Qt::PenJoinStyle style );
-    static Qt::PenJoinStyle decodeSldLineJoinStyle( QString str );
+    static Qt::PenJoinStyle decodeSldLineJoinStyle( const QString& str );
 
     static QString encodeSldLineCapStyle( Qt::PenCapStyle style );
-    static Qt::PenCapStyle decodeSldLineCapStyle( QString str );
+    static Qt::PenCapStyle decodeSldLineCapStyle( const QString& str );
 
     static QString encodeBrushStyle( Qt::BrushStyle style );
-    static Qt::BrushStyle decodeBrushStyle( QString str );
+    static Qt::BrushStyle decodeBrushStyle( const QString& str );
 
     static QString encodeSldBrushStyle( Qt::BrushStyle style );
-    static Qt::BrushStyle decodeSldBrushStyle( QString str );
+    static Qt::BrushStyle decodeSldBrushStyle( const QString& str );
 
     static QString encodePoint( QPointF point );
-    static QPointF decodePoint( QString str );
+    static QPointF decodePoint( const QString& str );
 
     static QString encodeMapUnitScale( const QgsMapUnitScale& mapUnitScale );
     static QgsMapUnitScale decodeMapUnitScale( const QString& str );
@@ -92,13 +92,13 @@ class CORE_EXPORT QgsSymbolLayerV2Utils
     static QVector<qreal> decodeSldRealVector( const QString& s );
 
     static QString encodeOutputUnit( QgsSymbolV2::OutputUnit unit );
-    static QgsSymbolV2::OutputUnit decodeOutputUnit( QString str );
+    static QgsSymbolV2::OutputUnit decodeOutputUnit( const QString& str );
 
     static QString encodeSldUom( QgsSymbolV2::OutputUnit unit, double *scaleFactor );
-    static QgsSymbolV2::OutputUnit decodeSldUom( QString str, double *scaleFactor );
+    static QgsSymbolV2::OutputUnit decodeSldUom( const QString& str, double *scaleFactor );
 
     static QString encodeScaleMethod( QgsSymbolV2::ScaleMethod scaleMethod );
-    static QgsSymbolV2::ScaleMethod decodeScaleMethod( QString str );
+    static QgsSymbolV2::ScaleMethod decodeScaleMethod( const QString& str );
 
     static QPainter::CompositionMode decodeBlendMode( const QString& s );
 
@@ -122,16 +122,16 @@ class CORE_EXPORT QgsSymbolLayerV2Utils
     static QPixmap symbolPreviewPixmap( QgsSymbolV2* symbol, QSize size, QgsRenderContext* customContext = 0 );
     static QPixmap colorRampPreviewPixmap( QgsVectorColorRampV2* ramp, QSize size );
 
-    /**Returns the maximum estimated bleed for the symbol */
+    /** Returns the maximum estimated bleed for the symbol */
     static double estimateMaxSymbolBleed( QgsSymbolV2* symbol );
 
-    /**Attempts to load a symbol from a DOM element
+    /** Attempts to load a symbol from a DOM element
      * @param element DOM element representing symbol
      * @returns decoded symbol, if possible
      */
     static QgsSymbolV2* loadSymbol( const QDomElement& element );
 
-    /**Attempts to load a symbol from a DOM element and cast it to a particular symbol
+    /** Attempts to load a symbol from a DOM element and cast it to a particular symbol
      * type.
      * @param element DOM element representing symbol
      * @returns decoded symbol cast to specified type, if possible
@@ -155,7 +155,13 @@ class CORE_EXPORT QgsSymbolLayerV2Utils
     }
 
     static QgsSymbolLayerV2* loadSymbolLayer( QDomElement& element );
-    static QDomElement saveSymbol( QString symbolName, QgsSymbolV2* symbol, QDomDocument& doc );
+    static QDomElement saveSymbol( const QString& symbolName, QgsSymbolV2* symbol, QDomDocument& doc );
+
+    /** Returns a string representing the symbol. Can be used to test for equality
+     * between symbols.
+     * @note added in QGIS 2.12
+     */
+    static QString symbolProperties( QgsSymbolV2* symbol );
 
     static bool createSymbolLayerV2ListFromSld( QDomElement& element, QGis::GeometryType geomType, QgsSymbolLayerV2List &layers );
 
@@ -176,13 +182,13 @@ class CORE_EXPORT QgsSymbolLayerV2Utils
     static bool needSvgFill( QDomElement &element );
 
     static void fillToSld( QDomDocument &doc, QDomElement &element,
-                           Qt::BrushStyle brushStyle, QColor color = QColor() );
+                           Qt::BrushStyle brushStyle, const QColor& color = QColor() );
     static bool fillFromSld( QDomElement &element,
                              Qt::BrushStyle &brushStyle, QColor &color );
 
     //! @note not available in python bindings
     static void lineToSld( QDomDocument &doc, QDomElement &element,
-                           Qt::PenStyle penStyle, QColor color, double width = -1,
+                           Qt::PenStyle penStyle, const QColor& color, double width = -1,
                            const Qt::PenJoinStyle *penJoinStyle = 0, const Qt::PenCapStyle *penCapStyle = 0,
                            const QVector<qreal> *customDashPattern = 0, double dashOffset = 0.0 );
     static bool lineFromSld( QDomElement &element,
@@ -191,82 +197,84 @@ class CORE_EXPORT QgsSymbolLayerV2Utils
                              QVector<qreal> *customDashPattern = 0, double *dashOffset = 0 );
 
     static void externalGraphicToSld( QDomDocument &doc, QDomElement &element,
-                                      QString path, QString mime,
-                                      QColor color, double size = -1 );
+                                      const QString& path, const QString& mime,
+                                      const QColor& color, double size = -1 );
     static bool externalGraphicFromSld( QDomElement &element,
                                         QString &path, QString &mime,
                                         QColor &color, double &size );
 
     /** @deprecated Use wellKnownMarkerToSld( QDomDocument &doc, QDomElement &element, QString name, QColor color, QColor borderColor, Qt::PenStyle borderStyle, double borderWidth, double size ) instead */
     Q_DECL_DEPRECATED static void wellKnownMarkerToSld( QDomDocument &doc, QDomElement &element,
-        QString name, QColor color, QColor borderColor = QColor(),
+        const QString& name, const QColor& color, const QColor& borderColor = QColor(),
         double borderWidth = -1, double size = -1 );
     static void wellKnownMarkerToSld( QDomDocument &doc, QDomElement &element,
-                                      QString name, QColor color, QColor borderColor, Qt::PenStyle borderStyle,
+                                      const QString& name, const QColor& color, const QColor& borderColor, Qt::PenStyle borderStyle,
                                       double borderWidth = -1, double size = -1 );
     /** @deprecated Use wellKnownMarkerFromSld( QDomElement &element, QString &name, QColor &color, QColor &borderColor, Qt::PenStyle &borderStyle, double &borderWidth, double &size ) instead */
     Q_DECL_DEPRECATED static bool wellKnownMarkerFromSld( QDomElement &element,
         QString &name, QColor &color, QColor &borderColor,
         double &borderWidth, double &size );
+
+    //! @note available in python as wellKnownMarkerFromSld2
     static bool wellKnownMarkerFromSld( QDomElement &element,
                                         QString &name, QColor &color, QColor &borderColor, Qt::PenStyle &borderStyle,
                                         double &borderWidth, double &size );
 
     static void externalMarkerToSld( QDomDocument &doc, QDomElement &element,
-                                     QString path, QString format, int *markIndex = 0,
-                                     QColor color = QColor(), double size = -1 );
+                                     const QString& path, const QString& format, int *markIndex = 0,
+                                     const QColor& color = QColor(), double size = -1 );
     static bool externalMarkerFromSld( QDomElement &element,
                                        QString &path, QString &format, int &markIndex,
                                        QColor &color, double &size );
 
 
-    static void labelTextToSld( QDomDocument &doc, QDomElement &element, QString label,
-                                QFont font, QColor color = QColor(), double size = -1 );
+    static void labelTextToSld( QDomDocument &doc, QDomElement &element, const QString& label,
+                                const QFont &font, const QColor& color = QColor(), double size = -1 );
 
-    /**Create ogr feature style string for pen */
+    /** Create ogr feature style string for pen */
     static QString ogrFeatureStylePen( double width, double mmScaleFactor, double mapUnitsScaleFactor, const QColor& c,
                                        Qt::PenJoinStyle joinStyle = Qt::MiterJoin,
                                        Qt::PenCapStyle capStyle = Qt::FlatCap,
                                        double offset = 0.0,
                                        const QVector<qreal>* dashPattern = 0 );
-    /**Create ogr feature style string for brush
+    /** Create ogr feature style string for brush
      @param fillColr fill color*/
     static QString ogrFeatureStyleBrush( const QColor& fillColr );
 
-    static void createRotationElement( QDomDocument &doc, QDomElement &element, QString rotationFunc );
+    static void createRotationElement( QDomDocument &doc, QDomElement &element, const QString& rotationFunc );
     static bool rotationFromSldElement( QDomElement &element, QString &rotationFunc );
 
-    static void createOpacityElement( QDomDocument &doc, QDomElement &element, QString alphaFunc );
+    static void createOpacityElement( QDomDocument &doc, QDomElement &element, const QString& alphaFunc );
     static bool opacityFromSldElement( QDomElement &element, QString &alphaFunc );
 
     static void createDisplacementElement( QDomDocument &doc, QDomElement &element, QPointF offset );
     static bool displacementFromSldElement( QDomElement &element, QPointF &offset );
 
-    static void createOnlineResourceElement( QDomDocument &doc, QDomElement &element, QString path, QString format );
+    static void createOnlineResourceElement( QDomDocument &doc, QDomElement &element, const QString& path, const QString& format );
     static bool onlineResourceFromSldElement( QDomElement &element, QString &path, QString &format );
 
-    static void createGeometryElement( QDomDocument &doc, QDomElement &element, QString geomFunc );
+    static void createGeometryElement( QDomDocument &doc, QDomElement &element, const QString& geomFunc );
     static bool geometryFromSldElement( QDomElement &element, QString &geomFunc );
 
-    static bool createFunctionElement( QDomDocument &doc, QDomElement &element, QString function );
+    static bool createFunctionElement( QDomDocument &doc, QDomElement &element, const QString& function );
     static bool functionFromSldElement( QDomElement &element, QString &function );
 
-    static QDomElement createSvgParameterElement( QDomDocument &doc, QString name, QString value );
+    static QDomElement createSvgParameterElement( QDomDocument &doc, const QString& name, const QString& value );
     static QgsStringMap getSvgParameterList( QDomElement &element );
 
-    static QDomElement createVendorOptionElement( QDomDocument &doc, QString name, QString value );
+    static QDomElement createVendorOptionElement( QDomDocument &doc, const QString& name, const QString& value );
     static QgsStringMap getVendorOptionList( QDomElement &element );
 
     static QgsStringMap parseProperties( QDomElement& element );
     static void saveProperties( QgsStringMap props, QDomDocument& doc, QDomElement& element );
 
     static QgsSymbolV2Map loadSymbols( QDomElement& element );
-    static QDomElement saveSymbols( QgsSymbolV2Map& symbols, QString tagName, QDomDocument& doc );
+    static QDomElement saveSymbols( QgsSymbolV2Map& symbols, const QString& tagName, QDomDocument& doc );
 
     static void clearSymbolMap( QgsSymbolV2Map& symbols );
 
     static QgsVectorColorRampV2* loadColorRamp( QDomElement& element );
-    static QDomElement saveColorRamp( QString name, QgsVectorColorRampV2* ramp, QDomDocument& doc );
+    static QDomElement saveColorRamp( const QString& name, QgsVectorColorRampV2* ramp, QDomDocument& doc );
 
     /**
      * Returns a friendly display name for a color
@@ -283,7 +291,7 @@ class CORE_EXPORT QgsSymbolLayerV2Utils
      * @returns list of parsed colors
      * @note added in 2.5
      */
-    static QList< QColor > parseColorList( const QString colorStr );
+    static QList< QColor > parseColorList( const QString& colorStr );
 
     /**
      * Creates mime data from a color. Sets both the mime data's color data, and the
@@ -320,7 +328,7 @@ class CORE_EXPORT QgsSymbolLayerV2Utils
      * @returns mime data containing encoded colors
      * @note added in 2.5
      */
-    static QMimeData* colorListToMimeData( const QgsNamedColorList colorList, const bool allFormats = true );
+    static QMimeData* colorListToMimeData( const QgsNamedColorList& colorList, const bool allFormats = true );
 
     /**
      * Exports colors to a gpl GIMP palette file
@@ -330,7 +338,7 @@ class CORE_EXPORT QgsSymbolLayerV2Utils
      * @returns true if export was successful
      * @see importColorsFromGpl
     */
-    static bool saveColorsToGpl( QFile &file, const QString paletteName, QgsNamedColorList colors );
+    static bool saveColorsToGpl( QFile &file, const QString& paletteName, const QgsNamedColorList& colors );
 
     /**
      * Imports colors from a gpl GIMP palette file
@@ -350,7 +358,7 @@ class CORE_EXPORT QgsSymbolLayerV2Utils
      * @returns parsed color
      * @note added in 2.3
      */
-    static QColor parseColor( QString colorStr, bool strictEval = false );
+    static QColor parseColor( const QString& colorStr, bool strictEval = false );
 
     /**
      * Attempts to parse a string as a color using a variety of common formats, including hex
@@ -361,16 +369,39 @@ class CORE_EXPORT QgsSymbolLayerV2Utils
      * @returns parsed color
      * @note added in 2.3
      */
-    static QColor parseColorWithAlpha( const QString colorStr, bool &containsAlpha, bool strictEval = false );
+    static QColor parseColorWithAlpha( const QString& colorStr, bool &containsAlpha, bool strictEval = false );
 
-    /**Returns the line width scale factor depending on the unit and the paint device*/
+    /** Returns the line width scale factor depending on the unit and the paint device.
+     * Consider using convertToPainterUnits() instead, as convertToPainterUnits() respects the size limits specified by the scale
+     * parameter.
+     * @param c render context
+     * @param u units to convert from
+     * @param scale map unit scale, specifying limits for the map units to convert from
+     * @see convertToPainterUnits()
+    */
     static double lineWidthScaleFactor( const QgsRenderContext& c, QgsSymbolV2::OutputUnit u, const QgsMapUnitScale& scale = QgsMapUnitScale() );
-    /**Returns scale factor painter units -> pixel dimensions*/
+
+    /** Converts a size from the specied units to painter units. The conversion respects the limits
+     * specified by the optional scale parameter.
+     * @param c render context
+     * @param size size to convert
+     * @param unit units for specified size
+     * @param scale map unit scale
+     * @note added in QGIS 2.12
+     * @see lineWidthScaleFactor
+     */
+    static double convertToPainterUnits( const QgsRenderContext&c, double size, QgsSymbolV2::OutputUnit unit, const QgsMapUnitScale& scale = QgsMapUnitScale() );
+
+    /** Returns scale factor painter units -> pixel dimensions*/
     static double pixelSizeScaleFactor( const QgsRenderContext& c, QgsSymbolV2::OutputUnit u, const QgsMapUnitScale& scale = QgsMapUnitScale() );
-    /**Creates a render context for a pixel based device*/
+
+    /** Returns scale factor painter units -> map units*/
+    static double mapUnitScaleFactor( const QgsRenderContext& c, QgsSymbolV2::OutputUnit u, const QgsMapUnitScale& scale = QgsMapUnitScale() );
+
+    /** Creates a render context for a pixel based device*/
     static QgsRenderContext createRenderContext( QPainter* p );
 
-    /**Multiplies opacity of image pixel values with a (global) transparency value*/
+    /** Multiplies opacity of image pixel values with a (global) transparency value*/
     static void multiplyImageOpacity( QImage* image, qreal alpha );
 
     /** Blurs an image in place, e.g. creating Qt-independent drop shadows */
@@ -381,16 +412,16 @@ class CORE_EXPORT QgsSymbolLayerV2Utils
      */
     static void premultiplyColor( QColor& rgb, int alpha );
 
-    /**Sorts the passed list in requested order*/
+    /** Sorts the passed list in requested order*/
     static void sortVariantList( QList<QVariant>& list, Qt::SortOrder order );
-    /**Returns a point on the line from startPoint to directionPoint that is a certain distance away from the starting point*/
+    /** Returns a point on the line from startPoint to directionPoint that is a certain distance away from the starting point*/
     static QPointF pointOnLineWithDistance( const QPointF& startPoint, const QPointF& directionPoint, double distance );
 
     //! Return a list of all available svg files
     static QStringList listSvgFiles();
 
     //! Return a list of svg files at the specified directory
-    static QStringList listSvgFilesAt( QString directory );
+    static QStringList listSvgFilesAt( const QString& directory );
 
     /** Get symbol's path from its name.
      *  If the name is not absolute path the file is searched in SVG paths specified
@@ -438,7 +469,7 @@ class CORE_EXPORT QgsSymbolLayerV2Utils
 class QPolygonF;
 
 //! @deprecated since 2.4 - calculate line shifted by a specified distance
-QList<QPolygonF> offsetLine( QPolygonF polyline, double dist );
+QList<QPolygonF> offsetLine( const QPolygonF& polyline, double dist );
 //! calculate geometry shifted by a specified distance
 QList<QPolygonF> offsetLine( QPolygonF polyline, double dist, QGis::GeometryType geometryType );
 
