@@ -49,27 +49,36 @@ class CORE_EXPORT QgsSymbolV2
 {
   public:
 
+    /**
+     * The unit of the output
+     */
     enum OutputUnit
     {
-      MM = 0,
-      MapUnit,
-      Mixed, //mixed units in symbol layers
-      Pixel
+      MM = 0,  //!< The output shall be in millimeters
+      MapUnit, //!< The output shall be in map unitx
+      Mixed,   //!< Mixed units in symbol layers
+      Pixel    //!< The output shall be in pixels
     };
 
     typedef QList<OutputUnit> OutputUnitList;
 
+    /**
+     * Type of the symbol
+     */
     enum SymbolType
     {
-      Marker,
-      Line,
-      Fill
+      Marker, //!< Marker symbol
+      Line,   //!< Line symbol
+      Fill    //!< Fill symbol
     };
 
+    /**
+     * Scale method
+     */
     enum ScaleMethod
     {
-      ScaleArea,
-      ScaleDiameter
+      ScaleArea,     //!< Calculate scale by the area
+      ScaleDiameter  //!< Calculate scale by the diameter
     };
 
     enum RenderHint
@@ -87,7 +96,7 @@ class CORE_EXPORT QgsSymbolV2
 
     // symbol layers handling
 
-    /**Returns list of symbol layers contained in the symbol.
+    /** Returns list of symbol layers contained in the symbol.
      * @returns symbol layers list
      * @note added in QGIS 2.7
      * @see symbolLayer
@@ -95,7 +104,7 @@ class CORE_EXPORT QgsSymbolV2
      */
     QgsSymbolLayerV2List symbolLayers() { return mLayers; }
 
-    /**Returns a specific symbol layers contained in the symbol.
+    /** Returns a specific symbol layers contained in the symbol.
      * @param layer layer number
      * @returns corresponding symbol layer
      * @note added in QGIS 2.7
@@ -104,7 +113,7 @@ class CORE_EXPORT QgsSymbolV2
      */
     QgsSymbolLayerV2* symbolLayer( int layer );
 
-    /**Returns total number of symbol layers contained in the symbol.
+    /** Returns total number of symbol layers contained in the symbol.
      * @returns count of symbol layers
      * @note added in QGIS 2.7
      * @see symbolLayers
@@ -112,16 +121,32 @@ class CORE_EXPORT QgsSymbolV2
      */
     int symbolLayerCount() { return mLayers.count(); }
 
-    //! insert symbol layer to specified index
+    /**
+     * Insert symbol layer to specified index
+     * Ownership will be transferred.
+     * @param index The index at which the layer should be added
+     * @param layer The symbol layer to add
+     * @return True if the layer is added, False if the index or the layer is bad
+     */
     bool insertSymbolLayer( int index, QgsSymbolLayerV2* layer );
 
-    //! append symbol layer at the end of the list
+    /**
+     * Append symbol layer at the end of the list
+     * Ownership will be transferred.
+     * @param layer The layer to add
+     * @return True if the layer is added, False if the layer is bad
+     */
     bool appendSymbolLayer( QgsSymbolLayerV2* layer );
 
     //! delete symbol layer at specified index
     bool deleteSymbolLayer( int index );
 
-    //! remove symbol layer from the list and return pointer to it
+    /**
+     * Remove symbol layer from the list and return pointer to it.
+     * Ownership is handed to the caller.
+     * @param index The index of the layer to remove
+     * @return A pointer to the removed layer
+     */
     QgsSymbolLayerV2* takeSymbolLayer( int index );
 
     //! delete layer at specified index and set a new one
@@ -138,9 +163,17 @@ class CORE_EXPORT QgsSymbolV2
     //! @note customContext parameter added in 2.6
     void drawPreviewIcon( QPainter* painter, QSize size, QgsRenderContext* customContext = 0 );
 
+    //! export symbol as image format. PNG and SVG supported
+    void exportImage( const QString& path, const QString& format, const QSize& size );
+
+    //! Generate symbol as image
     QImage asImage( QSize size, QgsRenderContext* customContext = 0 );
 
-    QImage bigSymbolPreviewImage();
+    /** Returns a large (roughly 100x100 pixel) preview image for the symbol.
+     * @param expressionContext optional expression context, for evaluation of
+     * data defined symbol properties
+     */
+    QImage bigSymbolPreviewImage( QgsExpressionContext* expressionContext = 0 );
 
     QString dump() const;
 
@@ -162,7 +195,7 @@ class CORE_EXPORT QgsSymbolV2
     void setRenderHints( int hints ) { mRenderHints = hints; }
     int renderHints() const { return mRenderHints; }
 
-    /**Sets whether features drawn by the symbol should be clipped to the render context's
+    /** Sets whether features drawn by the symbol should be clipped to the render context's
      * extent. If this option is enabled then features which are partially outside the extent
      * will be clipped. This speeds up rendering of the feature, but may have undesirable
      * side effects for certain symbol types.
@@ -172,7 +205,7 @@ class CORE_EXPORT QgsSymbolV2
      */
     void setClipFeaturesToExtent( bool clipFeaturesToExtent ) { mClipFeaturesToExtent = clipFeaturesToExtent; }
 
-    /**Returns whether features drawn by the symbol will be clipped to the render context's
+    /** Returns whether features drawn by the symbol will be clipped to the render context's
      * extent. If this option is enabled then features which are partially outside the extent
      * will be clipped. This speeds up rendering of the feature, but may have undesirable
      * side effects for certain symbol types.
@@ -180,16 +213,21 @@ class CORE_EXPORT QgsSymbolV2
      * @note added in QGIS 2.9
      * @see setClipFeaturesToExtent
      */
-    double clipFeaturesToExtent() const { return mClipFeaturesToExtent; }
+    bool clipFeaturesToExtent() const { return mClipFeaturesToExtent; }
 
     QSet<QString> usedAttributes() const;
 
+    /** Returns whether the symbol utilises any data defined properties.
+     * @note added in QGIS 2.12
+     */
+    bool hasDataDefinedProperties() const;
+
     //! @note the layer will be NULL after stopRender
     void setLayer( const QgsVectorLayer* layer ) { mLayer = layer; }
     const QgsVectorLayer* layer() const { return mLayer; }
 
   protected:
-    QgsSymbolV2( SymbolType type, QgsSymbolLayerV2List layers ); // can't be instantiated
+    QgsSymbolV2( SymbolType type, const QgsSymbolLayerV2List& layers ); // can't be instantiated
 
     QgsSymbolLayerV2List cloneLayers() const;
 
@@ -200,7 +238,7 @@ class CORE_EXPORT QgsSymbolV2
     SymbolType mType;
     QgsSymbolLayerV2List mLayers;
 
-    /**Symbol opacity (in the range 0 - 1)*/
+    /** Symbol opacity (in the range 0 - 1)*/
     qreal mAlpha;
 
     int mRenderHints;
@@ -221,6 +259,13 @@ class CORE_EXPORT QgsSymbolV2RenderContext
     QgsRenderContext& renderContext() { return mRenderContext; }
     const QgsRenderContext& renderContext() const { return mRenderContext; }
 
+    /** Sets the original value variable value for data defined symbology
+     * @param value value for original value variable. This usually represents the symbol property value
+     * before any data defined overrides have been applied.
+     * @note added in QGIS 2.12
+     */
+    void setOriginalValueVariable( const QVariant& value );
+
     QgsSymbolV2::OutputUnit outputUnit() const { return mOutputUnit; }
     void setOutputUnit( QgsSymbolV2::OutputUnit u ) { mOutputUnit = u; }
 
@@ -279,7 +324,7 @@ class CORE_EXPORT QgsMarkerSymbolV2 : public QgsSymbolV2
     */
     static QgsMarkerSymbolV2* createSimple( const QgsStringMap& properties );
 
-    QgsMarkerSymbolV2( QgsSymbolLayerV2List layers = QgsSymbolLayerV2List() );
+    QgsMarkerSymbolV2( const QgsSymbolLayerV2List& layers = QgsSymbolLayerV2List() );
 
     void setAngle( double angle );
     double angle() const;
@@ -348,7 +393,7 @@ class CORE_EXPORT QgsLineSymbolV2 : public QgsSymbolV2
     */
     static QgsLineSymbolV2* createSimple( const QgsStringMap& properties );
 
-    QgsLineSymbolV2( QgsSymbolLayerV2List layers = QgsSymbolLayerV2List() );
+    QgsLineSymbolV2( const QgsSymbolLayerV2List& layers = QgsSymbolLayerV2List() );
 
     void setWidth( double width );
     double width() const;
@@ -388,7 +433,7 @@ class CORE_EXPORT QgsFillSymbolV2 : public QgsSymbolV2
     */
     static QgsFillSymbolV2* createSimple( const QgsStringMap& properties );
 
-    QgsFillSymbolV2( QgsSymbolLayerV2List layers = QgsSymbolLayerV2List() );
+    QgsFillSymbolV2( const QgsSymbolLayerV2List& layers = QgsSymbolLayerV2List() );
     void setAngle( double angle );
     void renderPolygon( const QPolygonF& points, QList<QPolygonF>* rings, const QgsFeature* f, QgsRenderContext& context, int layer = -1, bool selected = false );
 
@@ -397,9 +442,9 @@ class CORE_EXPORT QgsFillSymbolV2 : public QgsSymbolV2
   private:
 
     void renderPolygonUsingLayer( QgsSymbolLayerV2* layer, const QPolygonF &points, QList<QPolygonF> *rings, QgsSymbolV2RenderContext &context );
-    /**Calculates the bounds of a polygon including rings*/
+    /** Calculates the bounds of a polygon including rings*/
     QRectF polygonBounds( const QPolygonF &points, const QList<QPolygonF> *rings ) const;
-    /**Translates the rings in a polygon by a set distance*/
+    /** Translates the rings in a polygon by a set distance*/
     QList<QPolygonF>* translateRings( const QList<QPolygonF> *rings, double dx, double dy ) const;
 };
 
