@@ -28,10 +28,12 @@ class CORE_EXPORT QgsVectorColorRampV2
 
     virtual ~QgsVectorColorRampV2() {}
 
-    // Number of defined colors
+    /** Returns number of defined colors, or -1 if undefined
+     */
     virtual int count() const = 0;
 
-    // Relative value (0,1) of color at index
+    /** Returns relative value between [0,1] of color at specified index
+     */
     virtual double value( int index ) const = 0;
 
     virtual QColor color( double value ) const = 0;
@@ -59,10 +61,10 @@ typedef QList<QgsGradientStop> QgsGradientStopsList;
 class CORE_EXPORT QgsVectorGradientColorRampV2 : public QgsVectorColorRampV2
 {
   public:
-    QgsVectorGradientColorRampV2( QColor color1 = DEFAULT_GRADIENT_COLOR1,
-                                  QColor color2 = DEFAULT_GRADIENT_COLOR2,
+    QgsVectorGradientColorRampV2( const QColor& color1 = DEFAULT_GRADIENT_COLOR1,
+                                  const QColor& color2 = DEFAULT_GRADIENT_COLOR2,
                                   bool discrete = false,
-                                  QgsGradientStopsList stops = QgsGradientStopsList() );
+                                  const QgsGradientStopsList& stops = QgsGradientStopsList() );
 
     static QgsVectorColorRampV2* create( const QgsStringMap& properties = QgsStringMap() );
 
@@ -80,8 +82,8 @@ class CORE_EXPORT QgsVectorGradientColorRampV2 : public QgsVectorColorRampV2
 
     QColor color1() const { return mColor1; }
     QColor color2() const { return mColor2; }
-    void setColor1( QColor color ) { mColor1 = color; }
-    void setColor2( QColor color ) { mColor2 = color; }
+    void setColor1( const QColor& color ) { mColor1 = color; }
+    void setColor2( const QColor& color ) { mColor2 = color; }
 
     bool isDiscrete() const { return mDiscrete; }
     void setDiscrete( bool discrete ) { mDiscrete = discrete; }
@@ -93,7 +95,7 @@ class CORE_EXPORT QgsVectorGradientColorRampV2 : public QgsVectorColorRampV2
     QgsStringMap info() const { return mInfo; }
     void setInfo( const QgsStringMap& info ) { mInfo = info; }
 
-    /**copy color ramp stops to a QGradient
+    /** Copy color ramp stops to a QGradient
     * @note added in 2.1 */
     void addStopsToGradient( QGradient* gradient, double alpha = 1 );
 
@@ -132,7 +134,7 @@ class CORE_EXPORT QgsVectorRandomColorRampV2 : public QgsVectorColorRampV2
 
     virtual QgsStringMap properties() const override;
 
-    /** get a list of random colors
+    /** Get a list of random colors
     * @note added in 2.4 */
     static QList<QColor> randomColors( int count,
                                        int hueMax = DEFAULT_RANDOM_HUE_MAX, int hueMin = DEFAULT_RANDOM_HUE_MIN,
@@ -202,7 +204,7 @@ class CORE_EXPORT QgsRandomColorsV2: public QgsVectorColorRampV2
 class CORE_EXPORT QgsVectorColorBrewerColorRampV2 : public QgsVectorColorRampV2
 {
   public:
-    QgsVectorColorBrewerColorRampV2( QString schemeName = DEFAULT_COLORBREWER_SCHEMENAME,
+    QgsVectorColorBrewerColorRampV2( const QString& schemeName = DEFAULT_COLORBREWER_SCHEMENAME,
                                      int colors = DEFAULT_COLORBREWER_COLORS );
 
     static QgsVectorColorRampV2* create( const QgsStringMap& properties = QgsStringMap() );
@@ -221,11 +223,11 @@ class CORE_EXPORT QgsVectorColorBrewerColorRampV2 : public QgsVectorColorRampV2
     virtual int count() const override { return mColors; }
     int colors() const { return mColors; }
 
-    void setSchemeName( QString schemeName ) { mSchemeName = schemeName; loadPalette(); }
+    void setSchemeName( const QString& schemeName ) { mSchemeName = schemeName; loadPalette(); }
     void setColors( int colors ) { mColors = colors; loadPalette(); }
 
     static QStringList listSchemeNames();
-    static QList<int> listSchemeVariants( QString schemeName );
+    static QList<int> listSchemeVariants( const QString& schemeName );
 
   protected:
 
@@ -243,11 +245,11 @@ class CORE_EXPORT QgsVectorColorBrewerColorRampV2 : public QgsVectorColorRampV2
 class CORE_EXPORT QgsCptCityColorRampV2 : public QgsVectorGradientColorRampV2
 {
   public:
-    QgsCptCityColorRampV2( QString schemeName = DEFAULT_CPTCITY_SCHEMENAME,
-                           QString variantName = DEFAULT_CPTCITY_VARIANTNAME,
+    QgsCptCityColorRampV2( const QString& schemeName = DEFAULT_CPTCITY_SCHEMENAME,
+                           const QString& variantName = DEFAULT_CPTCITY_VARIANTNAME,
                            bool doLoadFile = true );
-    QgsCptCityColorRampV2( QString schemeName, QStringList variantList,
-                           QString variantName = QString(), bool doLoadFile = true );
+    QgsCptCityColorRampV2( const QString& schemeName, const QStringList& variantList,
+                           const QString& variantName = QString(), bool doLoadFile = true );
 
     static QgsVectorColorRampV2* create( const QgsStringMap& properties = QgsStringMap() );
 
@@ -264,10 +266,10 @@ class CORE_EXPORT QgsCptCityColorRampV2 : public QgsVectorGradientColorRampV2
     QStringList variantList() const { return mVariantList; }
 
     /* lazy loading - have to call loadPalette() explicitly */
-    void setSchemeName( QString schemeName ) { mSchemeName = schemeName; mFileLoaded = false; }
-    void setVariantName( QString variantName ) { mVariantName = variantName; mFileLoaded = false; }
-    void setVariantList( QStringList variantList ) { mVariantList = variantList; }
-    void setName( QString schemeName, QString variantName = "", QStringList variantList = QStringList() )
+    void setSchemeName( const QString& schemeName ) { mSchemeName = schemeName; mFileLoaded = false; }
+    void setVariantName( const QString& variantName ) { mVariantName = variantName; mFileLoaded = false; }
+    void setVariantList( const QStringList& variantList ) { mVariantList = variantList; }
+    void setName( const QString& schemeName, const QString& variantName = "", const QStringList& variantList = QStringList() )
     { mSchemeName = schemeName; mVariantName = variantName; mVariantList = variantList; mFileLoaded = false; }
 
     void loadPalette() { loadFile(); }
