@@ -34,6 +34,7 @@ typedef QSet<int> QgsAttributeIds;
 typedef QHash<int, QString> QgsAttrPalIndexNameHash;
 
 class QgsFeatureIterator;
+class QgsTransaction;
 
 #include "qgsfeaturerequest.h"
 
@@ -49,6 +50,8 @@ class CORE_EXPORT QgsVectorDataProvider : public QgsDataProvider
 {
     Q_OBJECT
 
+    friend class QgsTransaction;
+
   public:
 
     // If you add to this, please also add to capabilitiesString()
@@ -57,25 +60,25 @@ class CORE_EXPORT QgsVectorDataProvider : public QgsDataProvider
      */
     enum Capability
     {
-      /** provider has no capabilities */
+      /** Provider has no capabilities */
       NoCapabilities =                     0,
-      /** allows adding features */
+      /** Allows adding features */
       AddFeatures =                        1,
-      /** allows deletion of features */
+      /** Allows deletion of features */
       DeleteFeatures =               1 <<  1,
-      /** allows modification of attribute values */
+      /** Allows modification of attribute values */
       ChangeAttributeValues =        1 <<  2,
-      /** allows addition of new attributes (fields) */
+      /** Allows addition of new attributes (fields) */
       AddAttributes =                1 <<  3,
-      /** allows deletion of attributes (fields) */
+      /** Allows deletion of attributes (fields) */
       DeleteAttributes =             1 <<  4,
       /** DEPRECATED - do not use */
       SaveAsShapefile =              1 <<  5,
-      /** allows creation of spatial index */
+      /** Allows creation of spatial index */
       CreateSpatialIndex =           1 <<  6,
-      /** fast access to features using their ID */
+      /** Fast access to features using their ID */
       SelectAtId =                   1 <<  7,
-      /** allows modifications of geometries */
+      /** Allows modifications of geometries */
       ChangeGeometries =             1 <<  8,
       /** DEPRECATED - do not use */
       SelectGeometryAtId =           1 <<  9,
@@ -84,15 +87,19 @@ class CORE_EXPORT QgsVectorDataProvider : public QgsDataProvider
       /** DEPRECATED - do not use */
       SequentialSelectGeometryAtId = 1 << 11,
       CreateAttributeIndex =         1 << 12,
-      /** allows user to select encoding */
+      /** Allows user to select encoding */
       SelectEncoding =               1 << 13,
-      /** supports simplification of geometries on provider side according to a distance tolerance */
+      /** Supports simplification of geometries on provider side according to a distance tolerance */
       SimplifyGeometries =           1 << 14,
-      /** supports topological simplification of geometries on provider side according to a distance tolerance */
+      /** Supports topological simplification of geometries on provider side according to a distance tolerance */
       SimplifyGeometriesWithTopologicalValidation = 1 << 15,
+      /** Supports transactions*/
+      TransactionSupport = 1 << 16,
+      /** Supports circular geometry types (circularstring, compoundcurve, curvepolygon)*/
+      CircularGeometries = 1 << 17
     };
 
-    /** bitmask of all provider's editing capabilities */
+    /** Bitmask of all provider's editing capabilities */
     const static int EditingCapabilities = AddFeatures | DeleteFeatures |
                                            ChangeAttributeValues | ChangeGeometries | AddAttributes | DeleteAttributes;
 
@@ -100,7 +107,7 @@ class CORE_EXPORT QgsVectorDataProvider : public QgsDataProvider
      * Constructor of the vector provider
      * @param uri  uniform resource locator (URI) for a dataset
      */
-    QgsVectorDataProvider( QString uri = QString() );
+    QgsVectorDataProvider( const QString& uri = QString() );
 
     /**
      * Destructor
@@ -252,7 +259,7 @@ class CORE_EXPORT QgsVectorDataProvider : public QgsDataProvider
      */
     virtual bool createSpatialIndex();
 
-    /**Create an attribute index on the datasource*/
+    /** Create an attribute index on the datasource*/
     virtual bool createAttributeIndex( int field );
 
     /** Returns a bitmask containing the supported capabilities
@@ -309,8 +316,8 @@ class CORE_EXPORT QgsVectorDataProvider : public QgsDataProvider
 
     struct NativeType
     {
-      NativeType( QString typeDesc, QString typeName, QVariant::Type type, int minLen = 0, int maxLen = 0, int minPrec = 0, int maxPrec = 0 ) :
-          mTypeDesc( typeDesc ), mTypeName( typeName ), mType( type ), mMinLen( minLen ), mMaxLen( maxLen ), mMinPrec( minPrec ), mMaxPrec( maxPrec ) {};
+      NativeType( const QString& typeDesc, const QString& typeName, QVariant::Type type, int minLen = 0, int maxLen = 0, int minPrec = 0, int maxPrec = 0 ) :
+          mTypeDesc( typeDesc ), mTypeName( typeName ), mType( type ), mMinLen( minLen ), mMaxLen( maxLen ), mMinPrec( minPrec ), mMaxPrec( maxPrec ) {}
 
       QString mTypeDesc;
       QString mTypeName;
@@ -326,9 +333,10 @@ class CORE_EXPORT QgsVectorDataProvider : public QgsDataProvider
      */
     const QList< NativeType > &nativeTypes() const;
 
-    /** Returns true if the provider is strict about the type of inserted features
-          (e.g. no multipolygon in a polygon layer)
-          */
+    /**
+     * Returns true if the provider is strict about the type of inserted features
+     * (e.g. no multipolygon in a polygon layer)
+     */
     virtual bool doesStrictFeatureTypeCheck() const { return true;}
 
     /** Returns a list of available encodings */
@@ -356,7 +364,21 @@ class CORE_EXPORT QgsVectorDataProvider : public QgsDataProvider
      */
     virtual bool isSaveAndLoadStyleToDBSupported() { return false; }
 
-    static QVariant convertValue( QVariant::Type type, QString value );
+    static QVariant convertValue( QVariant::Type type, const QString& value );
+
+    /**
+     * Returns the transaction this data provider is included in, if any.
+     */
+    virtual QgsTransaction* transaction() const { return 0; }
+
+    /**
+     * Forces a reload of the underlying datasource if the provider implements this
+     * method.
+     * In particular on the OGR provider, a pooled connection will be invalidated.
+     * This forces QGIS to reopen a file or connection.
+     * This can be required if the underlying file is replaced.
+     */
+    virtual void forceReload() {}
 
   protected:
     void clearMinMaxCache();
@@ -368,32 +390,31 @@ class CORE_EXPORT QgsVectorDataProvider : public QgsDataProvider
     /** Encoding */
     QTextCodec* mEncoding;
 
-    /** should provider fetch also features that don't have geometry? */
-    bool mFetchFeaturesWithoutGeom;
-
-    /** True if geometry should be added to the features in nextFeature calls*/
-    bool mFetchGeom;
-
     /** List of attribute indices to fetch with nextFeature calls*/
     QgsAttributeList mAttributesToFetch;
 
     /** The names of the providers native types*/
     QList< NativeType > mNativeTypes;
 
-    void pushError( QString msg );
+    void pushError( const QString& msg );
 
     /** Old-style mapping of index to name for QgsPalLabeling fix */
     QgsAttrPalIndexNameHash mAttrPalIndexName;
 
   private:
-    /** old notation **/
+    /** Old notation **/
     QMap<QString, QVariant::Type> mOldTypeList;
 
-    /** list of errors */
+    /** List of errors */
     QStringList mErrors;
 
     static QStringList smEncodings;
 
+    /**
+     * Includes this data provider in the specified transaction. Ownership of transaction is not transferred.
+     */
+    virtual void setTransaction( QgsTransaction* /*transaction*/ ) {}
+
 };
 
 
