@@ -18,9 +18,13 @@ email                : lrssvtml (at) gmail (dot) com
  ***************************************************************************/
 Some portions of code were taken from https://code.google.com/p/pydee/
 """
+import os
 
-from PyQt4.QtCore import Qt, QTimer, QSettings, QCoreApplication, QSize, QByteArray, QFileInfo, SIGNAL
-from PyQt4.QtGui import QDockWidget, QToolBar, QToolButton, QWidget, QSplitter, QTreeWidget, QAction, QFileDialog, QCheckBox, QSizePolicy, QMenu, QGridLayout, QApplication
+from PyQt4.QtCore import Qt, QTimer, QSettings, QCoreApplication, QSize, QByteArray, QFileInfo, SIGNAL, QUrl, QDir
+from PyQt4.QtGui import QDockWidget, QToolBar, QToolButton, QWidget,\
+    QSplitter, QTreeWidget, QAction, QFileDialog, QCheckBox, QSizePolicy, QMenu, QGridLayout, QApplication, \
+    QDesktopServices
+from PyQt4.QtGui import QVBoxLayout
 from PyQt4 import pyqtconfig
 from qgis.utils import iface
 from console_sci import ShellScintilla
@@ -34,37 +38,42 @@ import sys
 
 _console = None
 
+
 def show_console():
-  """ called from QGIS to open the console """
-  global _console
-  if _console is None:
-    parent = iface.mainWindow() if iface else None
-    _console = PythonConsole( parent )
-    _console.show() # force show even if it was restored as hidden
-    # set focus to the console so the user can start typing
-    # defer the set focus event so it works also whether the console not visible yet
-    QTimer.singleShot(0, _console.activate)
-  else:
-    _console.setVisible(not _console.isVisible())
-    # set focus to the console so the user can start typing
-    if _console.isVisible():
-      _console.activate()
-  ## Shows help on first launch of the console
-  settings = QSettings()
-  if settings.value('pythonConsole/contextHelpOnFirstLaunch', True, type=bool):
-      QgsContextHelp.run( "PythonConsole" )
-      settings.setValue('pythonConsole/contextHelpOnFirstLaunch', False)
+    """ called from QGIS to open the console """
+    global _console
+    if _console is None:
+        parent = iface.mainWindow() if iface else None
+        _console = PythonConsole(parent)
+        _console.show() # force show even if it was restored as hidden
+        # set focus to the console so the user can start typing
+        # defer the set focus event so it works also whether the console not visible yet
+        QTimer.singleShot(0, _console.activate)
+    else:
+        _console.setVisible(not _console.isVisible())
+        # set focus to the console so the user can start typing
+        if _console.isVisible():
+            _console.activate()
+    ## Shows help on first launch of the console
+    settings = QSettings()
+    if settings.value('pythonConsole/contextHelpOnFirstLaunch', True, type=bool):
+        QgsContextHelp.run("PythonConsole")
+        settings.setValue('pythonConsole/contextHelpOnFirstLaunch', False)
 
 _old_stdout = sys.stdout
 _console_output = None
 
 # hook for python console so all output will be redirected
 # and then shown in console
+
+
 def console_displayhook(obj):
     global _console_output
     _console_output = obj
 
+
 class PythonConsole(QDockWidget):
+
     def __init__(self, parent=None):
         QDockWidget.__init__(self, parent)
         self.setObjectName("PythonConsole")
@@ -72,8 +81,8 @@ class PythonConsole(QDockWidget):
         #self.setAllowedAreas(Qt.BottomDockWidgetArea)
 
         self.console = PythonConsoleWidget(self)
-        self.setWidget( self.console )
-        self.setFocusProxy( self.console )
+        self.setWidget(self.console)
+        self.setFocusProxy(self.console)
 
         # try to restore position from stored main window state
         if iface and not iface.mainWindow().restoreDockWidget(self):
@@ -88,7 +97,9 @@ class PythonConsole(QDockWidget):
         self.console.saveSettingsConsole()
         QWidget.closeEvent(self, event)
 
+
 class PythonConsoleWidget(QWidget):
+
     def __init__(self, parent=None):
         QWidget.__init__(self, parent)
         self.setWindowTitle(QCoreApplication.translate("PythonConsole", "Python Console"))
@@ -106,12 +117,19 @@ class PythonConsoleWidget(QWidget):
         self.splitterEditor.setOrientation(Qt.Horizontal)
         self.splitterEditor.setHandleWidth(6)
         self.splitterEditor.setChildrenCollapsible(True)
+
+        self.shellOutWidget = QWidget(self)
+        self.shellOutWidget.setLayout(QVBoxLayout())
+        self.shellOutWidget.layout().setContentsMargins(0, 0, 0, 0)
+        self.shellOutWidget.layout().addWidget(self.shellOut)
+
         self.splitter = QSplitter(self.splitterEditor)
         self.splitter.setOrientation(Qt.Vertical)
         self.splitter.setHandleWidth(3)
         self.splitter.setChildrenCollapsible(False)
-        self.splitter.addWidget(self.shellOut)
+        self.splitter.addWidget(self.shellOutWidget)
         self.splitter.addWidget(self.shell)
+
         #self.splitterEditor.addWidget(self.tabEditorWidget)
 
         self.splitterObj = QSplitter(self.splitterEditor)
@@ -130,7 +148,6 @@ class PythonConsoleWidget(QWidget):
         self.listClassMethod.setColumnHidden(1, True)
         self.listClassMethod.setAlternatingRowColors(True)
 
-
         #self.splitterEditor.addWidget(self.widgetEditor)
         #self.splitterObj.addWidget(self.listClassMethod)
         #self.splitterObj.addWidget(self.widgetEditor)
@@ -160,6 +177,16 @@ class PythonConsoleWidget(QWidget):
         self.openFileButton.setIconVisibleInMenu(True)
         self.openFileButton.setToolTip(openFileBt)
         self.openFileButton.setText(openFileBt)
+
+        openExtEditorBt = QCoreApplication.translate("PythonConsole", "Open in external editor")
+        self.openInEditorButton = QAction(self)
+        self.openInEditorButton.setCheckable(False)
+        self.openInEditorButton.setEnabled(True)
+        self.openInEditorButton.setIcon(QgsApplication.getThemeIcon("console/iconShowEditorConsole.png"))
+        self.openInEditorButton.setMenuRole(QAction.PreferencesRole)
+        self.openInEditorButton.setIconVisibleInMenu(True)
+        self.openInEditorButton.setToolTip(openExtEditorBt)
+        self.openInEditorButton.setText(openExtEditorBt)
         ## Action for Save File
         saveFileBt = QCoreApplication.translate("PythonConsole", "Save")
         self.saveFileButton = QAction(self)
@@ -361,9 +388,8 @@ class PythonConsoleWidget(QWidget):
         self.toolBar.setContextMenuPolicy(Qt.DefaultContextMenu)
         self.toolBar.setLayoutDirection(Qt.LeftToRight)
         self.toolBar.setIconSize(QSize(16, 16))
-        self.toolBar.setOrientation(Qt.Vertical)
-        self.toolBar.setMovable(True)
-        self.toolBar.setFloatable(True)
+        self.toolBar.setMovable(False)
+        self.toolBar.setFloatable(False)
         self.toolBar.addAction(self.clearButton)
         self.toolBar.addAction(self.actionClass)
         self.toolBar.addAction(self.runButton)
@@ -374,21 +400,21 @@ class PythonConsoleWidget(QWidget):
         self.toolBar.addAction(self.helpButton)
 
         self.toolBarEditor = QToolBar()
-        # self.toolBarEditor.setStyleSheet('QToolBar{background-color: rgb(%s, %s, %s' % tuple(bkgrcolor) + ');\
-        #                                   border-right: 1px solid rgb(%s, %s, %s' % tuple(bordercl) + ');}')
         self.toolBarEditor.setEnabled(False)
         self.toolBarEditor.setFocusPolicy(Qt.NoFocus)
         self.toolBarEditor.setContextMenuPolicy(Qt.DefaultContextMenu)
         self.toolBarEditor.setLayoutDirection(Qt.LeftToRight)
         self.toolBarEditor.setIconSize(QSize(16, 16))
-        self.toolBarEditor.setOrientation(Qt.Vertical)
-        self.toolBarEditor.setMovable(True)
-        self.toolBarEditor.setFloatable(True)
+        self.toolBarEditor.setMovable(False)
+        self.toolBarEditor.setFloatable(False)
         self.toolBarEditor.addAction(self.openFileButton)
+        self.toolBarEditor.addAction(self.openInEditorButton)
         self.toolBarEditor.addSeparator()
         self.toolBarEditor.addAction(self.saveFileButton)
         self.toolBarEditor.addAction(self.saveAsFileButton)
         self.toolBarEditor.addSeparator()
+        self.toolBarEditor.addAction(self.runScriptEditorButton)
+        self.toolBarEditor.addSeparator()
         self.toolBarEditor.addAction(self.findTextButton)
         self.toolBarEditor.addSeparator()
         self.toolBarEditor.addAction(self.cutEditorButton)
@@ -399,8 +425,6 @@ class PythonConsoleWidget(QWidget):
         self.toolBarEditor.addAction(self.uncommentEditorButton)
         self.toolBarEditor.addSeparator()
         self.toolBarEditor.addAction(self.objectListButton)
-        self.toolBarEditor.addSeparator()
-        self.toolBarEditor.addAction(self.runScriptEditorButton)
 
         ## Menu Import Class
         self.classMenu = QMenu()
@@ -442,21 +466,15 @@ class PythonConsoleWidget(QWidget):
         self.mainLayout.addWidget(self.widgetButton, 0, 0, 1, 1)
         self.mainLayout.addWidget(self.splitterEditor, 0, 1, 1, 1)
 
+        self.shellOutWidget.layout().insertWidget(0, self.toolBar)
+
         self.layoutEditor = QGridLayout(self.widgetEditor)
         self.layoutEditor.setMargin(0)
         self.layoutEditor.setSpacing(0)
-        self.layoutEditor.addWidget(self.widgetButtonEditor, 0, 0, 2, 1)
-        self.layoutEditor.addWidget(self.tabEditorWidget, 0, 1, 1, 1)
-        self.layoutEditor.addWidget(self.widgetFind, 1, 1, 1, 1)
-
-        self.toolBarLayout = QGridLayout(self.widgetButton)
-        self.toolBarLayout.setMargin(0)
-        self.toolBarLayout.setSpacing(0)
-        self.toolBarLayout.addWidget(self.toolBar)
-        self.toolBarEditorLayout = QGridLayout(self.widgetButtonEditor)
-        self.toolBarEditorLayout.setMargin(0)
-        self.toolBarEditorLayout.setSpacing(0)
-        self.toolBarEditorLayout.addWidget(self.toolBarEditor)
+        self.layoutEditor.addWidget(self.toolBarEditor, 0, 1, 1, 1)
+        self.layoutEditor.addWidget(self.widgetButtonEditor, 1, 0, 2, 1)
+        self.layoutEditor.addWidget(self.tabEditorWidget, 1, 1, 1, 1)
+        self.layoutEditor.addWidget(self.widgetFind, 2, 1, 1, 1)
 
         ## Layout for the find widget
         self.layoutFind = QGridLayout(self.widgetFind)
@@ -465,9 +483,9 @@ class PythonConsoleWidget(QWidget):
         placeHolderTxt = QCoreApplication.translate("PythonConsole", "Enter text to find...")
 
         if pyqtconfig.Configuration().qt_version >= 0x40700:
-          self.lineEditFind.setPlaceholderText(placeHolderTxt)
+            self.lineEditFind.setPlaceholderText(placeHolderTxt)
         else:
-          self.lineEditFind.setToolTip(placeHolderTxt)
+            self.lineEditFind.setToolTip(placeHolderTxt)
         self.findNextButton = QToolButton()
         self.findNextButton.setEnabled(False)
         toolTipfindNext = QCoreApplication.translate("PythonConsole", "Find Next")
@@ -521,6 +539,7 @@ class PythonConsoleWidget(QWidget):
         self.loadQtGuiButton.triggered.connect(self.qtGui)
         self.runButton.triggered.connect(self.shell.entered)
         self.openFileButton.triggered.connect(self.openScriptFile)
+        self.openInEditorButton.triggered.connect(self.openScriptFileExtEditor)
         self.saveFileButton.triggered.connect(self.saveScriptFile)
         self.saveAsFileButton.triggered.connect(self.saveAsScriptFile)
         self.helpButton.triggered.connect(self.openHelp)
@@ -566,13 +585,13 @@ class PythonConsoleWidget(QWidget):
         tabEditor.goToLine(objName, linenr)
 
     def processing(self):
-       self.shell.commandConsole('processing')
+        self.shell.commandConsole('processing')
 
     def qtCore(self):
-       self.shell.commandConsole('qtCore')
+        self.shell.commandConsole('qtCore')
 
     def qtGui(self):
-       self.shell.commandConsole('qtGui')
+        self.shell.commandConsole('qtGui')
 
     def toggleEditor(self, checked):
         self.splitterObj.show() if checked else self.splitterObj.hide()
@@ -604,8 +623,17 @@ class PythonConsoleWidget(QWidget):
     def uncommentCode(self):
         self.tabEditorWidget.currentWidget().newEditor.commentEditorCode(False)
 
+    def openScriptFileExtEditor(self):
+        tabWidget = self.tabEditorWidget.currentWidget()
+        path = tabWidget.path
+        import subprocess
+        try:
+            subprocess.Popen([os.environ['EDITOR'], path])
+        except KeyError:
+            QDesktopServices.openUrl(QUrl.fromLocalFile(path))
+
     def openScriptFile(self):
-        lastDirPath = self.settings.value("pythonConsole/lastDirPath", "")
+        lastDirPath = self.settings.value("pythonConsole/lastDirPath", QDir.home())
         openFileTr = QCoreApplication.translate("PythonConsole", "Open File")
         fileList = QFileDialog.getOpenFileNames(
             self, openFileTr, lastDirPath, "Script file (*.py)")
@@ -628,7 +656,7 @@ class PythonConsoleWidget(QWidget):
         tabWidget = self.tabEditorWidget.currentWidget()
         try:
             tabWidget.save()
-        except (IOError, OSError), error:
+        except (IOError, OSError) as error:
             msgText = QCoreApplication.translate('PythonConsole',
                                                  'The file <b>{0}</b> could not be saved. Error: {1}').format(tabWidget.path,
                                                                                                               error.strerror)
@@ -639,19 +667,21 @@ class PythonConsoleWidget(QWidget):
         if not index:
             index = self.tabEditorWidget.currentIndex()
         if not tabWidget.path:
-            pathFileName = self.tabEditorWidget.tabText(index) + '.py'
+            fileName = self.tabEditorWidget.tabText(index) + '.py'
+            folder = self.settings.value("pythonConsole/lastDirPath", QDir.home())
+            pathFileName = os.path.join(folder, fileName)
             fileNone = True
         else:
             pathFileName = tabWidget.path
             fileNone = False
         saveAsFileTr = QCoreApplication.translate("PythonConsole", "Save File As")
         filename = QFileDialog.getSaveFileName(self,
-                        saveAsFileTr,
-                        pathFileName, "Script file (*.py)")
+                                               saveAsFileTr,
+                                               pathFileName, "Script file (*.py)")
         if filename:
             try:
                 tabWidget.save(filename)
-            except (IOError, OSError), error:
+            except (IOError, OSError) as error:
                 msgText = QCoreApplication.translate('PythonConsole',
                                                      'The file <b>{0}</b> could not be saved. Error: {1}').format(tabWidget.path,
                                                                                                                   error.strerror)
@@ -666,7 +696,7 @@ class PythonConsoleWidget(QWidget):
                 self.updateTabListScript(pathFileName, action='remove')
 
     def openHelp(self):
-        QgsContextHelp.run( "PythonConsole" )
+        QgsContextHelp.run("PythonConsole")
 
     def openSettings(self):
         if optionsDialog(self).exec_():
