@@ -2,7 +2,7 @@
 /***************************************************************************
 Name                 : GdalTools
 Description          : Integrate gdal tools into qgis
-Date                 : 17/Sep/09 
+Date                 : 17/Sep/09
 copyright            : (C) 2009 by Lorenzo Masini and Giuseppe Sucameli (Faunalia)
 email                : lorenxo86@gmail.com - brush.tyler@gmail.com
  ***************************************************************************/
@@ -17,18 +17,9 @@ email                : lorenxo86@gmail.com - brush.tyler@gmail.com
  ***************************************************************************/
  This script initializes the plugin, making it known to QGIS.
 """
-def name(): 
-  return "GdalTools" 
-def description():
-  return "Integrate gdal tools into qgis"
-def version(): 
-  return "Version 1.2.26" 
-def qgisMinimumVersion():
-  return "1.0"
-def icon():
-  return "icons/raster-info.png"
-def classFactory(iface): 
-  # load GdalTools class from file GdalTools
-  from GdalTools import GdalTools 
-  return GdalTools(iface)
 
+
+def classFactory(iface):
+    # load GdalTools class from file GdalTools
+    from GdalTools import GdalTools
+    return GdalTools(iface)
