@@ -41,6 +41,7 @@ def classFactory():
 
 
 class PostGisDBConnector(DBConnector):
+
     def __init__(self, uri):
         DBConnector.__init__(self, uri)
 
@@ -52,8 +53,8 @@ class PostGisDBConnector(DBConnector):
 
         try:
             self.connection = psycopg2.connect(self._connectionInfo().encode('utf-8'))
-        except self.connection_error_types(), e:
-            err = str(e)
+        except self.connection_error_types() as e:
+            err = unicode(e)
             uri = self.uri()
             conninfo = uri.connectionInfo()
 
@@ -71,11 +72,11 @@ class PostGisDBConnector(DBConnector):
                 try:
                     self.connection = psycopg2.connect(uri.connectionInfo().encode('utf-8'))
                     QgsCredentials.instance().put(conninfo, username, password)
-                except self.connection_error_types(), e:
+                except self.connection_error_types() as e:
                     if i == 2:
                         raise ConnectionError(e)
 
-                    err = str(e)
+                    err = unicode(e)
 
         self.connection.set_isolation_level(psycopg2.extensions.ISOLATION_LEVEL_AUTOCOMMIT)
 
@@ -176,7 +177,7 @@ class PostGisDBConnector(DBConnector):
     def hasTableColumnEditingSupport(self):
         return True
 
-    def hasCreateSpatialViewSupport( self ):
+    def hasCreateSpatialViewSupport(self):
         return True
 
     def fieldTypes(self):
@@ -188,7 +189,6 @@ class PostGisDBConnector(DBConnector):
             "date", "time", "timestamp"  # date/time
         ]
 
-
     def getDatabasePrivileges(self):
         """ db privileges: (can create schemas, can create temp. tables) """
         sql = u"SELECT has_database_privilege(current_database(), 'CREATE'), has_database_privilege(current_database(), 'TEMP')"
@@ -223,7 +223,6 @@ class PostGisDBConnector(DBConnector):
         self._close_cursor(c)
         return res
 
-
     def getSchemas(self):
         """ get list of schemas in tuples: (oid, name, owner, perms) """
         sql = u"SELECT oid, nspname, pg_get_userbyid(nspowner), nspacl, pg_catalog.obj_description(oid) FROM pg_namespace WHERE nspname !~ '^pg_' AND nspname != 'information_schema' ORDER BY nspname"
@@ -289,7 +288,6 @@ class PostGisDBConnector(DBConnector):
 
         return sorted(items, cmp=lambda x, y: cmp((x[2], x[1]), (y[2], y[1])))
 
-
     def getVectorTables(self, schema=None):
         """ get list of table with a geometry column
                 it returns:
@@ -326,7 +324,6 @@ class PostGisDBConnector(DBConnector):
                                                 CASE WHEN geo.type IS NOT NULL THEN geo.type ELSE textin(regtypeout(att.atttypid::regtype)) END,
                                                 geo.coord_dimension, geo.srid"""
 
-
         # discovery of all tables and whether they contain a geometry column
         sql = u"""SELECT
                                                 cla.relname, nsp.nspname, cla.relkind = 'v' OR cla.relkind = 'm',
@@ -399,7 +396,6 @@ class PostGisDBConnector(DBConnector):
                                                 rast.out_db,
                                                 rast.srid"""
 
-
         # discovery of all tables and whether they contain a raster column
         sql = u"""SELECT
                                                 cla.relname, nsp.nspname, cla.relkind = 'v' OR cla.relkind = 'm',
@@ -432,7 +428,6 @@ class PostGisDBConnector(DBConnector):
 
         return items
 
-
     def getTableRowCount(self, table):
         c = self._execute(None, u"SELECT COUNT(*) FROM %s" % self.quoteId(table))
         res = self._fetchone(c)[0]
@@ -485,7 +480,6 @@ class PostGisDBConnector(DBConnector):
         self._close_cursor(c)
         return res
 
-
     def getTableConstraints(self, table):
 
         schema, tablename = self.getSchemaTableName(table)
@@ -503,7 +497,6 @@ class PostGisDBConnector(DBConnector):
         self._close_cursor(c)
         return res
 
-
     def getTableTriggers(self, table):
 
         schema, tablename = self.getSchemaTableName(table)
@@ -536,7 +529,6 @@ class PostGisDBConnector(DBConnector):
         sql = u"DROP TRIGGER %s ON %s" % (self.quoteId(trigger), self.quoteId(table))
         self._execute_and_commit(sql)
 
-
     def getTableRules(self, table):
 
         schema, tablename = self.getSchemaTableName(table)
@@ -555,10 +547,9 @@ class PostGisDBConnector(DBConnector):
         sql = u"DROP RULE %s ON %s" % (self.quoteId(rule), self.quoteId(table))
         self._execute_and_commit(sql)
 
-
     def getTableExtent(self, table, geom):
         """ find out table extent """
-        subquery = u"SELECT st_extent(%s) AS extent FROM %s" % ( self.quoteId(geom), self.quoteId(table) )
+        subquery = u"SELECT st_extent(%s) AS extent FROM %s" % (self.quoteId(geom), self.quoteId(table))
         sql = u"SELECT st_xmin(extent), st_ymin(extent), st_xmax(extent), st_ymax(extent) FROM (%s) AS subquery" % subquery
 
         c = self._execute(None, sql)
@@ -580,13 +571,12 @@ class PostGisDBConnector(DBConnector):
 
         try:
             c = self._execute(None, sql)
-        except DbError, e:  # no statistics for the current table
+        except DbError as e:  # no statistics for the current table
             return
         res = self._fetchone(c)
         self._close_cursor(c)
         return res
 
-
     def getViewDefinition(self, view):
         """ returns definition of the view """
 
@@ -609,7 +599,7 @@ class PostGisDBConnector(DBConnector):
 
         try:
             c = self._execute(None, "SELECT srtext FROM spatial_ref_sys WHERE srid = '%d'" % srid)
-        except DbError, e:
+        except DbError as e:
             return
         sr = self._fetchone(c)
         self._close_cursor(c)
@@ -623,7 +613,6 @@ class PostGisDBConnector(DBConnector):
             srtext = regex.cap(1)
         return srtext
 
-
     def isVectorTable(self, table):
         if self.has_geometry_columns and self.has_geometry_columns_access:
             schema, tablename = self.getSchemaTableName(table)
@@ -650,7 +639,6 @@ class PostGisDBConnector(DBConnector):
 
         return False
 
-
     def createTable(self, table, field_defs, pkey):
         """ create ordinary table
                         'fields' is array containing field definitions
@@ -681,7 +669,6 @@ class PostGisDBConnector(DBConnector):
             sql = u"DROP TABLE %s" % self.quoteId(table)
         self._execute_and_commit(sql)
 
-
     def emptyTable(self, table):
         """ delete all rows from table """
         sql = u"TRUNCATE %s" % self.quoteId(table)
@@ -789,7 +776,6 @@ class PostGisDBConnector(DBConnector):
         sql = u"ALTER SCHEMA %s RENAME TO %s" % (self.quoteId(schema), self.quoteId(new_schema))
         self._execute_and_commit(sql)
 
-
     def runVacuum(self):
         """ run vacuum on the db """
         self._execute_and_commit("VACUUM")
@@ -810,7 +796,7 @@ class PostGisDBConnector(DBConnector):
         if self.isGeometryColumn(table, column):
             # use postgis function to delete geometry column correctly
             schema, tablename = self.getSchemaTableName(table)
-            schema_part = u"%s, " % self._quote_str(schema) if schema else ""
+            schema_part = u"%s, " % self._quote_unicode(schema) if schema else ""
             sql = u"SELECT DropGeometryColumn(%s%s, %s)" % (
                 schema_part, self.quoteString(tablename), self.quoteString(column))
         else:
@@ -874,7 +860,6 @@ class PostGisDBConnector(DBConnector):
                 If default=None or an empty string drop default value """
         return self.updateTableColumn(table, column, None, None, None, default)
 
-
     def isGeometryColumn(self, table, column):
 
         schema, tablename = self.getSchemaTableName(table)
@@ -899,7 +884,6 @@ class PostGisDBConnector(DBConnector):
     def deleteGeometryColumn(self, table, geom_column):
         return self.deleteTableColumn(table, geom_column)
 
-
     def addTableUniqueConstraint(self, table, column):
         """ add a unique constraint to a table """
         sql = u"ALTER TABLE %s ADD UNIQUE (%s)" % (self.quoteId(table), self.quoteId(column))
@@ -915,7 +899,6 @@ class PostGisDBConnector(DBConnector):
         sql = u"ALTER TABLE %s ADD PRIMARY KEY (%s)" % (self.quoteId(table), self.quoteId(column))
         self._execute_and_commit(sql)
 
-
     def createTableIndex(self, table, name, column):
         """ create index on one column using default options """
         sql = u"CREATE INDEX %s ON %s (%s)" % (self.quoteId(name), self.quoteId(table), self.quoteId(column))
@@ -937,7 +920,6 @@ class PostGisDBConnector(DBConnector):
         idx_name = self.quoteId(u"sidx_%s_%s" % (tablename, geom_column))
         return self.dropTableIndex(table, idx_name)
 
-
     def execution_error_types(self):
         return psycopg2.Error, psycopg2.ProgrammingError, psycopg2.Warning
 
@@ -998,4 +980,3 @@ UNION SELECT attname FROM pg_attribute WHERE attnum > 0"""
         from .sql_dictionary import getQueryBuilderDictionary
 
         return getQueryBuilderDictionary()
-
