@@ -36,7 +36,9 @@ import ftools_utils
 from ui_frmVectorGrid import Ui_Dialog
 import math
 
+
 class Dialog(QDialog, Ui_Dialog):
+
     def __init__(self, iface):
         QDialog.__init__(self, iface.mainWindow())
         self.iface = iface
@@ -54,22 +56,22 @@ class Dialog(QDialog, Ui_Dialog):
         self.yMax.setValidator(QDoubleValidator(self.yMax))
         self.populateLayers()
 
-    def populateLayers( self ):
+    def populateLayers(self):
         self.inShape.clear()
         layermap = QgsMapLayerRegistry.instance().mapLayers()
         for name, layer in layermap.iteritems():
-            self.inShape.addItem( unicode( layer.name() ) )
+            self.inShape.addItem(unicode(layer.name()))
             if layer == self.iface.activeLayer():
-                self.inShape.setCurrentIndex( self.inShape.count() -1 )
+                self.inShape.setCurrentIndex(self.inShape.count() - 1)
 
     def offset(self, value):
         if self.chkLock.isChecked():
             self.spnY.setValue(value)
 
-    def updateLayer( self ):
+    def updateLayer(self):
         mLayerName = self.inShape.currentText()
         if not mLayerName == "":
-            mLayer = ftools_utils.getMapLayerByName( unicode( mLayerName ) )
+            mLayer = ftools_utils.getMapLayerByName(unicode(mLayerName))
             # get layer extents
             boundBox = mLayer.extent()
             # if "align extents and resolution..." button is checked
@@ -77,49 +79,49 @@ class Dialog(QDialog, Ui_Dialog):
                 if not mLayer.type() == QgsMapLayer.RasterLayer:
                     QMessageBox.information(self, self.tr("Vector grid"), self.tr("Please select a raster layer"))
                 else:
-                    dx = math.fabs(boundBox.xMaximum()-boundBox.xMinimum()) / mLayer.width()
-                    dy = math.fabs(boundBox.yMaximum()-boundBox.yMinimum()) / mLayer.height()
+                    dx = math.fabs(boundBox.xMaximum() - boundBox.xMinimum()) / mLayer.width()
+                    dy = math.fabs(boundBox.yMaximum() - boundBox.yMinimum()) / mLayer.height()
                     self.spnX.setValue(dx)
                     self.spnY.setValue(dy)
-            self.updateExtents( boundBox )
+            self.updateExtents(boundBox)
 
-    def updateCanvas( self ):
+    def updateCanvas(self):
         canvas = self.iface.mapCanvas()
         boundBox = canvas.extent()
         # if "align extents and resolution..." button is checked
         if self.chkAlign.isChecked():
             mLayerName = self.inShape.currentText()
             if not mLayerName == "":
-                mLayer = ftools_utils.getMapLayerByName( unicode( mLayerName ) )
+                mLayer = ftools_utils.getMapLayerByName(unicode(mLayerName))
                 if not mLayer.type() == QgsMapLayer.RasterLayer:
                     QMessageBox.information(self, self.tr("Vector grid"), self.tr("Please select a raster layer"))
                 else:
                     # get extents and pixel size
                     boundBox2 = mLayer.extent()
-                    dx = math.fabs(boundBox2.xMaximum()-boundBox2.xMinimum()) / mLayer.width()
-                    dy = math.fabs(boundBox2.yMaximum()-boundBox2.yMinimum()) / mLayer.height()
+                    dx = math.fabs(boundBox2.xMaximum() - boundBox2.xMinimum()) / mLayer.width()
+                    dy = math.fabs(boundBox2.yMaximum() - boundBox2.yMinimum()) / mLayer.height()
                     # get pixels from the raster that are closest to the desired extent
-                    newXMin = self.getClosestPixel( boundBox2.xMinimum(), boundBox.xMinimum(), dx, True )
-                    newXMax = self.getClosestPixel( boundBox2.xMaximum(), boundBox.xMaximum(), dx, False )
-                    newYMin = self.getClosestPixel( boundBox2.yMinimum(), boundBox.yMinimum(), dy, True )
-                    newYMax = self.getClosestPixel( boundBox2.yMaximum(), boundBox.yMaximum(), dy, False )
+                    newXMin = self.getClosestPixel(boundBox2.xMinimum(), boundBox.xMinimum(), dx, True)
+                    newXMax = self.getClosestPixel(boundBox2.xMaximum(), boundBox.xMaximum(), dx, False)
+                    newYMin = self.getClosestPixel(boundBox2.yMinimum(), boundBox.yMinimum(), dy, True)
+                    newYMax = self.getClosestPixel(boundBox2.yMaximum(), boundBox.yMaximum(), dy, False)
                     # apply new values if found all min/max
                     if newXMin is not None and newXMax is not None and newYMin is not None and newYMax is not None:
-                        boundBox.set( newXMin, newYMin, newXMax, newYMax )
+                        boundBox.set(newXMin, newYMin, newXMax, newYMax)
                         self.spnX.setValue(dx)
                         self.spnY.setValue(dy)
                     else:
                         QMessageBox.information(self, self.tr("Vector grid"), self.tr("Unable to compute extents aligned on selected raster layer"))
-        self.updateExtents( boundBox )
+        self.updateExtents(boundBox)
 
-    def updateExtents( self, boundBox ):
-        self.xMin.setText( unicode( boundBox.xMinimum() ) )
-        self.yMin.setText( unicode( boundBox.yMinimum() ) )
-        self.xMax.setText( unicode( boundBox.xMaximum() ) )
-        self.yMax.setText( unicode( boundBox.yMaximum() ) )
+    def updateExtents(self, boundBox):
+        self.xMin.setText(unicode(boundBox.xMinimum()))
+        self.yMin.setText(unicode(boundBox.yMinimum()))
+        self.xMax.setText(unicode(boundBox.xMaximum()))
+        self.yMax.setText(unicode(boundBox.yMaximum()))
 
     def accept(self):
-        self.buttonOk.setEnabled( False )
+        self.buttonOk.setEnabled(False)
         if self.xMin.text() == "" or self.xMax.text() == "" or self.yMin.text() == "" or self.yMax.text() == "":
             QMessageBox.information(self, self.tr("Vector grid"), self.tr("Please specify valid extent coordinates"))
         elif self.outShape.text() == "":
@@ -127,33 +129,33 @@ class Dialog(QDialog, Ui_Dialog):
         else:
             try:
                 boundBox = QgsRectangle(
-                    float( self.xMin.text() ),
-                    float( self.yMin.text() ),
-                    float( self.xMax.text() ),
-                    float( self.yMax.text() ) )
+                    float(self.xMin.text()),
+                    float(self.yMin.text()),
+                    float(self.xMax.text()),
+                    float(self.yMax.text()))
             except:
                 QMessageBox.information(self, self.tr("Vector grid"), self.tr("Invalid extent coordinates entered"))
             xSpace = self.spnX.value()
             ySpace = self.spnY.value()
             if self.rdoPolygons.isChecked():
-              polygon = True
+                polygon = True
             else:
-              polygon = False
+                polygon = False
             self.outShape.clear()
             QApplication.setOverrideCursor(Qt.WaitCursor)
-            self.compute( boundBox, xSpace, ySpace, polygon )
+            self.compute(boundBox, xSpace, ySpace, polygon)
             QApplication.restoreOverrideCursor()
             if self.addToCanvasCheck.isChecked():
                 addCanvasCheck = ftools_utils.addShapeToCanvas(unicode(self.shapefileName))
                 if not addCanvasCheck:
-                    QMessageBox.warning( self, self.tr("Generate Vector Grid"), self.tr( "Error loading output shapefile:\n%s" ) % ( unicode( self.shapefileName ) ))
+                    QMessageBox.warning(self, self.tr("Generate Vector Grid"), self.tr("Error loading output shapefile:\n%s") % (unicode(self.shapefileName)))
                 self.populateLayers()
             else:
-                QMessageBox.information(self, self.tr("Generate Vector Grid"),self.tr("Created output shapefile:\n%s" ) % ( unicode( self.shapefileName )))
-        self.progressBar.setValue( 0 )
-        self.buttonOk.setEnabled( True )
+                QMessageBox.information(self, self.tr("Generate Vector Grid"), self.tr("Created output shapefile:\n%s") % (unicode(self.shapefileName)))
+        self.progressBar.setValue(0)
+        self.buttonOk.setEnabled(True)
 
-    def compute( self, bound, xOffset, yOffset, polygon ):
+    def compute(self, bound, xOffset, yOffset, polygon):
         crs = None
         layer = ftools_utils.getMapLayerByName(unicode(self.inShape.currentText()))
 
@@ -161,20 +163,21 @@ class Dialog(QDialog, Ui_Dialog):
             bound = self.initRotation(bound)
 
         if layer is None:
-          crs = self.iface.mapCanvas().mapRenderer().destinationCrs()
+            crs = self.iface.mapCanvas().mapRenderer().destinationCrs()
         else:
-          crs = layer.crs()
-        if not crs.isValid(): crs = None
+            crs = layer.crs()
+        if not crs.isValid():
+            crs = None
 
         fields = QgsFields()
-        fields.append( QgsField("ID", QVariant.Int) )
+        fields.append(QgsField("ID", QVariant.Int))
         fieldCount = 1
 
         if polygon:
-            fields.append( QgsField("X_MIN", QVariant.Double) )
-            fields.append( QgsField("X_MAX", QVariant.Double) )
-            fields.append( QgsField("Y_MIN", QVariant.Double) )
-            fields.append( QgsField("Y_MAX", QVariant.Double) )
+            fields.append(QgsField("X_MIN", QVariant.Double))
+            fields.append(QgsField("X_MAX", QVariant.Double))
+            fields.append(QgsField("Y_MIN", QVariant.Double))
+            fields.append(QgsField("Y_MAX", QVariant.Double))
             fieldCount = 5
             check = QFile(self.shapefileName)
             if check.exists():
@@ -182,7 +185,7 @@ class Dialog(QDialog, Ui_Dialog):
                     return
             writer = QgsVectorFileWriter(self.shapefileName, self.encoding, fields, QGis.WKBPolygon, crs)
         else:
-            fields.append( QgsField("COORD", QVariant.Double) )
+            fields.append(QgsField("COORD", QVariant.Double))
             fieldCount = 2
             check = QFile(self.shapefileName)
             if check.exists():
@@ -194,7 +197,7 @@ class Dialog(QDialog, Ui_Dialog):
         outFeat.setFields(fields)
         outGeom = QgsGeometry()
         idVar = 0
-        self.progressBar.setValue( 0 )
+        self.progressBar.setValue(0)
         if not polygon:
             # counters for progressbar - update every 5%
             count = 0
@@ -217,10 +220,10 @@ class Dialog(QDialog, Ui_Dialog):
                 y = y - yOffset
                 idVar = idVar + 1
                 count += 1
-                if int( math.fmod( count, count_update ) ) == 0:
-                    prog = int( count / count_max * 50 )
-                    self.progressBar.setValue( prog )
-            self.progressBar.setValue( 50 )
+                if int(math.fmod(count, count_update)) == 0:
+                    prog = int(count / count_max * 50)
+                    self.progressBar.setValue(prog)
+            self.progressBar.setValue(50)
             # counters for progressbar - update every 5%
             count = 0
             count_max = (bound.xMaximum() - bound.xMinimum()) / xOffset
@@ -242,9 +245,9 @@ class Dialog(QDialog, Ui_Dialog):
                 x = x + xOffset
                 idVar = idVar + 1
                 count += 1
-                if int( math.fmod( count, count_update ) ) == 0:
-                    prog = 50 + int( count / count_max * 50 )
-                    self.progressBar.setValue( prog )
+                if int(math.fmod(count, count_update)) == 0:
+                    prog = 50 + int(count / count_max * 50)
+                    self.progressBar.setValue(prog)
         else:
             # counters for progressbar - update every 5%
             count = 0
@@ -280,41 +283,41 @@ class Dialog(QDialog, Ui_Dialog):
                     x = x + xOffset
                 y = y - yOffset
                 count += 1
-                if int( math.fmod( count, count_update ) ) == 0:
-                    prog = int( count / count_max * 100 )
+                if int(math.fmod(count, count_update)) == 0:
+                    prog = int(count / count_max * 100)
 
-        self.progressBar.setValue( 100 )
+        self.progressBar.setValue(100)
         del writer
 
-    def initRotation(self,  boundBox):
+    def initRotation(self, boundBox):
         # calculate rotation parameters..interpreted from affine transformation plugin
 
         anchorPoint = boundBox.center()
         # We convert the angle from degree to radiant
-        rad = self.angle.value()  * math.pi / 180.0
+        rad = self.angle.value() * math.pi / 180.0
 
         a = math.cos(rad)
-        b = -1 * math.sin( rad )
-        c = anchorPoint.x() - math.cos( rad ) * anchorPoint.x() + math.sin( rad ) * anchorPoint.y()
-        d = math.sin( rad )
-        e = math.cos( rad )
-        f = anchorPoint.y() - math.sin( rad ) * anchorPoint.x() - math.cos( rad ) * anchorPoint.y()
+        b = -1 * math.sin(rad)
+        c = anchorPoint.x() - math.cos(rad) * anchorPoint.x() + math.sin(rad) * anchorPoint.y()
+        d = math.sin(rad)
+        e = math.cos(rad)
+        f = anchorPoint.y() - math.sin(rad) * anchorPoint.x() - math.cos(rad) * anchorPoint.y()
 
-        self.rotationParams = (a,b,c,d,e,f)
+        self.rotationParams = (a, b, c, d, e, f)
 
         # Rotate the bounding box to set a new extent
-        ptMin = QgsPoint(boundBox.xMinimum(),  boundBox.yMinimum())
-        ptMax = QgsPoint(boundBox.xMaximum(),  boundBox.yMaximum())
+        ptMin = QgsPoint(boundBox.xMinimum(), boundBox.yMinimum())
+        ptMax = QgsPoint(boundBox.xMaximum(), boundBox.yMaximum())
 
         self.rotatePoint(ptMin)
         self.rotatePoint(ptMax)
 
-        newBoundBox = QgsRectangle(ptMin,  ptMax)
+        newBoundBox = QgsRectangle(ptMin, ptMax)
         newBoundBox.combineExtentWith(boundBox)
 
         return newBoundBox
 
-    def rotatePoint(self,  point):
+    def rotatePoint(self, point):
         x = self.rotationParams[0] * point.x() + self.rotationParams[1] * point.y() + self.rotationParams[2]
         y = self.rotationParams[3] * point.x() + self.rotationParams[4] * point.y() + self.rotationParams[5]
         point.setX(x)
@@ -322,24 +325,24 @@ class Dialog(QDialog, Ui_Dialog):
 
     def outFile(self):
         self.outShape.clear()
-        ( self.shapefileName, self.encoding ) = ftools_utils.saveDialog( self )
+        (self.shapefileName, self.encoding) = ftools_utils.saveDialog(self)
         if self.shapefileName is None or self.encoding is None:
             return
-        self.outShape.setText( self.shapefileName )
+        self.outShape.setText(self.shapefileName)
 
     def chkAlignToggled(self):
         if self.chkAlign.isChecked():
-            self.spnX.setEnabled( False )
-            self.lblX.setEnabled( False )
-            self.spnY.setEnabled( False )
-            self.lblY.setEnabled( False )
+            self.spnX.setEnabled(False)
+            self.lblX.setEnabled(False)
+            self.spnY.setEnabled(False)
+            self.lblY.setEnabled(False)
         else:
-            self.spnX.setEnabled( True )
-            self.lblX.setEnabled( True )
-            self.spnY.setEnabled( not self.chkLock.isChecked() )
-            self.lblY.setEnabled( not self.chkLock.isChecked() )
+            self.spnX.setEnabled(True)
+            self.lblX.setEnabled(True)
+            self.spnY.setEnabled(not self.chkLock.isChecked())
+            self.lblY.setEnabled(not self.chkLock.isChecked())
 
-    def getClosestPixel(self, startVal, targetVal, step, isMin ):
+    def getClosestPixel(self, startVal, targetVal, step, isMin):
         foundVal = None
         tmpVal = startVal
         # find pixels covering the extent - slighlyt inneficient b/c loop on all elements before xMin
