@@ -44,23 +44,23 @@ class ClipByExtent(GdalAlgorithm):
     EXTRA = 'EXTRA'
 
     def defineCharacteristics(self):
-        self.name = 'Clip raster by extent'
-        self.group = '[GDAL] Extraction'
+        self.name, self.i18n_name = self.trAlgorithm('Clip raster by extent')
+        self.group, self.i18n_group = self.trAlgorithm('[GDAL] Extraction')
         self.addParameter(ParameterRaster(
             self.INPUT, self.tr('Input layer'), False))
         self.addParameter(ParameterString(self.NO_DATA,
-            self.tr("Nodata value, leave blank to take the nodata value from input"),
-            ''))
+                                          self.tr("Nodata value, leave blank to take the nodata value from input"),
+                                          ''))
         self.addParameter(ParameterExtent(self.PROJWIN, self.tr('Clipping extent')))
         self.addParameter(ParameterString(self.EXTRA,
-            self.tr('Additional creation parameters'), '', optional=True))
+                                          self.tr('Additional creation parameters'), '', optional=True))
         self.addOutput(OutputRaster(self.OUTPUT, self.tr('Clipped (extent)')))
 
     def getConsoleCommands(self):
         out = self.getOutputValue(self.OUTPUT)
-        noData = str(self.getParameterValue(self.NO_DATA))
-        projwin = str(self.getParameterValue(self.PROJWIN))
-        extra = str(self.getParameterValue(self.EXTRA))
+        noData = unicode(self.getParameterValue(self.NO_DATA))
+        projwin = unicode(self.getParameterValue(self.PROJWIN))
+        extra = unicode(self.getParameterValue(self.EXTRA))
 
         arguments = []
         arguments.append('-of')
@@ -85,4 +85,4 @@ class ClipByExtent(GdalAlgorithm):
         return ['gdal_translate', GdalUtils.escapeAndJoin(arguments)]
 
     def commandName(self):
-        return "gdal_translate"
\ No newline at end of file
+        return "gdal_translate"
