@@ -50,29 +50,29 @@ class ClipByMask(GdalAlgorithm):
     EXTRA = 'EXTRA'
 
     def defineCharacteristics(self):
-        self.name = 'Clip raster by mask layer'
-        self.group = '[GDAL] Extraction'
+        self.name, self.i18n_name = self.trAlgorithm('Clip raster by mask layer')
+        self.group, self.i18n_group = self.trAlgorithm('[GDAL] Extraction')
         self.addParameter(ParameterRaster(self.INPUT, self.tr('Input layer'), False))
         self.addParameter(ParameterVector(self.MASK, self.tr('Mask layer'),
                           [ParameterVector.VECTOR_TYPE_POLYGON]))
         self.addParameter(ParameterString(self.NO_DATA,
-            self.tr("Nodata value, leave blank to take the nodata value from input"),
-            '-9999'))
+                                          self.tr("Nodata value, leave blank to take the nodata value from input"),
+                                          '-9999'))
         self.addParameter(ParameterBoolean(self.ALPHA_BAND,
-            self.tr('Create and output alpha band'), False))
+                                           self.tr('Create and output alpha band'), False))
         self.addParameter(ParameterBoolean(self.KEEP_RESOLUTION,
-            self.tr('Keep resolution of output raster'), False))
+                                           self.tr('Keep resolution of output raster'), False))
         self.addParameter(ParameterString(self.EXTRA,
-            self.tr('Additional creation parameters'), '', optional=True))
+                                          self.tr('Additional creation parameters'), '', optional=True))
         self.addOutput(OutputRaster(self.OUTPUT, self.tr('Clipped (mask)')))
 
     def getConsoleCommands(self):
         out = self.getOutputValue(self.OUTPUT)
         mask = self.getParameterValue(self.MASK)
-        noData = str(self.getParameterValue(self.NO_DATA))
+        noData = unicode(self.getParameterValue(self.NO_DATA))
         addAlphaBand = self.getParameterValue(self.ALPHA_BAND)
         keepResolution = self.getParameterValue(self.KEEP_RESOLUTION)
-        extra = str(self.getParameterValue(self.EXTRA))
+        extra = unicode(self.getParameterValue(self.EXTRA))
 
         arguments = []
         arguments.append('-q')
@@ -87,8 +87,8 @@ class ClipByMask(GdalAlgorithm):
             geoTransform = r.GetGeoTransform()
             r = None
             arguments.append('-tr')
-            arguments.append(str(geoTransform[1]))
-            arguments.append(str(geoTransform[5]))
+            arguments.append(unicode(geoTransform[1]))
+            arguments.append(unicode(geoTransform[5]))
             arguments.append('-tap')
 
         arguments.append('-cutline')
