@@ -89,6 +89,7 @@ pluginPath = os.path.normpath(os.path.join(
 
 
 class GdalOgrAlgorithmProvider(AlgorithmProvider):
+
     """This provider incorporates GDAL-based algorithms into the
     Processing framework.
 
@@ -130,18 +131,18 @@ class GdalOgrAlgorithmProvider(AlgorithmProvider):
         # extending GeoAlgorithm directly (those that execute GDAL
         # using the console)
         self.preloadedAlgs = [nearblack(), information(), warp(), translate(),
-            rgb2pct(), pct2rgb(), merge(), buildvrt(), polygonize(), gdaladdo(),
-            ClipByExtent(), ClipByMask(), contour(), rasterize(), proximity(),
-            sieve(), fillnodata(), ExtractProjection(), gdal2xyz(),
-            hillshade(), slope(), aspect(), tri(), tpi(), roughness(),
-            ColorRelief(), GridInvDist(), GridAverage(), GridNearest(),
-            GridDataMetrics(), gdaltindex(), gdalcalc(), rasterize_over(),
-            # ----- OGR tools -----
-            OgrInfo(), Ogr2Ogr(), Ogr2OgrClip(), Ogr2OgrClipExtent(),
-            Ogr2OgrToPostGis(), Ogr2OgrToPostGisList(), Ogr2OgrPointsOnLines(),
-            Ogr2OgrBuffer(), Ogr2OgrDissolve(), Ogr2OgrOneSideBuffer(),
-            Ogr2OgrTableToPostGisList(), OgrSql(),
-        ]
+                              rgb2pct(), pct2rgb(), merge(), buildvrt(), polygonize(), gdaladdo(),
+                              ClipByExtent(), ClipByMask(), contour(), rasterize(), proximity(),
+                              sieve(), fillnodata(), ExtractProjection(), gdal2xyz(),
+                              hillshade(), slope(), aspect(), tri(), tpi(), roughness(),
+                              ColorRelief(), GridInvDist(), GridAverage(), GridNearest(),
+                              GridDataMetrics(), gdaltindex(), gdalcalc(), rasterize_over(),
+                              # ----- OGR tools -----
+                              OgrInfo(), Ogr2Ogr(), Ogr2OgrClip(), Ogr2OgrClipExtent(),
+                              Ogr2OgrToPostGis(), Ogr2OgrToPostGisList(), Ogr2OgrPointsOnLines(),
+                              Ogr2OgrBuffer(), Ogr2OgrDissolve(), Ogr2OgrOneSideBuffer(),
+                              Ogr2OgrTableToPostGisList(), OgrSql(),
+                              ]
 
         # And then we add those that are created as python scripts
         folder = self.scriptsFolder()
@@ -150,10 +151,10 @@ class GdalOgrAlgorithmProvider(AlgorithmProvider):
                 if descriptionFile.endswith('py'):
                     try:
                         fullpath = os.path.join(self.scriptsFolder(),
-                                descriptionFile)
+                                                descriptionFile)
                         alg = GdalScriptAlgorithm(fullpath)
                         self.preloadedAlgs.append(alg)
-                    except WrongScriptException, e:
+                    except WrongScriptException as e:
                         ProcessingLog.addToLog(ProcessingLog.LOG_ERROR, e.msg)
 
     def getSupportedOutputRasterLayerExtensions(self):
