@@ -49,20 +49,20 @@ class aspect(GdalAlgorithm):
     #    return QIcon(filepath)
 
     def defineCharacteristics(self):
-        self.name = 'Aspect'
-        self.group = '[GDAL] Analysis'
+        self.name, self.i18n_name = self.trAlgorithm('Aspect')
+        self.group, self.i18n_group = self.trAlgorithm('[GDAL] Analysis')
         self.addParameter(ParameterRaster(self.INPUT, self.tr('Input layer')))
         self.addParameter(ParameterNumber(
             self.BAND, self.tr('Band number'), 1, 99, 1))
         self.addParameter(ParameterBoolean(
             self.COMPUTE_EDGES, self.tr('Compute edges'), False))
         self.addParameter(ParameterBoolean(self.ZEVENBERGEN,
-            self.tr("Use Zevenbergen&Thorne formula (instead of the Horn's one)"),
-            False))
+                                           self.tr("Use Zevenbergen&Thorne formula (instead of the Horn's one)"),
+                                           False))
         self.addParameter(ParameterBoolean(self.TRIG_ANGLE,
-            self.tr('Return trigonometric angle (instead of azimuth)'), False))
+                                           self.tr('Return trigonometric angle (instead of azimuth)'), False))
         self.addParameter(ParameterBoolean(self.ZERO_FLAT,
-            self.tr('Return 0 for flat (instead of -9999)'), False))
+                                           self.tr('Return 0 for flat (instead of -9999)'), False))
 
         self.addOutput(OutputRaster(self.OUTPUT, 'Aspect'))
 
@@ -76,7 +76,7 @@ class aspect(GdalAlgorithm):
         arguments.append(GdalUtils.getFormatShortNameFromFilename(output))
 
         arguments.append('-b')
-        arguments.append(str(self.getParameterValue(self.BAND)))
+        arguments.append(unicode(self.getParameterValue(self.BAND)))
 
         if self.getParameterValue(self.COMPUTE_EDGES):
             arguments.append('-compute_edges')
@@ -92,4 +92,3 @@ class aspect(GdalAlgorithm):
             arguments.append('-zero_for_flat')
 
         return ['gdaldem', GdalUtils.escapeAndJoin(arguments)]
-    
