@@ -40,11 +40,11 @@ class ExtractProjection(GdalAlgorithm):
     PRJ_FILE = 'PRJ_FILE'
 
     def defineCharacteristics(self):
-        self.name = 'Extract projection'
-        self.group = '[GDAL] Projections'
+        self.name, self.i18n_name = self.trAlgorithm('Extract projection')
+        self.group, self.i18n_group = self.trAlgorithm('[GDAL] Projections')
         self.addParameter(ParameterRaster(self.INPUT, self.tr('Input file')))
         self.addParameter(ParameterBoolean(self.PRJ_FILE,
-            self.tr('Create also .prj file'), False))
+                                           self.tr('Create also .prj file'), False))
 
     def getConsoleCommands(self):
         return ""
