@@ -96,15 +96,15 @@ class Ogr2Ogr(OgrAlgorithm):
     OPTIONS = 'OPTIONS'
 
     def defineCharacteristics(self):
-        self.name = 'Convert format'
-        self.group = '[OGR] Conversion'
+        self.name, self.i18n_name = self.trAlgorithm('Convert format')
+        self.group, self.i18n_group = self.trAlgorithm('[OGR] Conversion')
 
         self.addParameter(ParameterVector(self.INPUT_LAYER,
-            self.tr('Input layer'), [ParameterVector.VECTOR_TYPE_ANY], False))
+                                          self.tr('Input layer'), [ParameterVector.VECTOR_TYPE_ANY], False))
         self.addParameter(ParameterSelection(self.FORMAT,
-            self.tr('Destination Format'), FORMATS))
+                                             self.tr('Destination Format'), FORMATS))
         self.addParameter(ParameterString(self.OPTIONS,
-            self.tr('Creation options'), '', optional=True))
+                                          self.tr('Creation options'), '', optional=True))
 
         self.addOutput(OutputVector(self.OUTPUT_LAYER, self.tr('Converted')))
 
@@ -148,4 +148,4 @@ class Ogr2Ogr(OgrAlgorithm):
         return commands
 
     def commandName(self):
-        return "ogr2ogr"
\ No newline at end of file
+        return "ogr2ogr"
