@@ -35,6 +35,7 @@ from processing.tools.system import isWindows
 from processing.algs.gdal.OgrAlgorithm import OgrAlgorithm
 from processing.algs.gdal.GdalUtils import GdalUtils
 
+
 class Ogr2OgrClipExtent(OgrAlgorithm):
 
     OUTPUT_LAYER = 'OUTPUT_LAYER'
@@ -43,15 +44,15 @@ class Ogr2OgrClipExtent(OgrAlgorithm):
     OPTIONS = 'OPTIONS'
 
     def defineCharacteristics(self):
-        self.name = 'Clip vectors by extent'
-        self.group = '[OGR] Geoprocessing'
+        self.name, self.i18n_name = self.trAlgorithm('Clip vectors by extent')
+        self.group, self.i18n_group = self.trAlgorithm('[OGR] Geoprocessing')
 
         self.addParameter(ParameterVector(self.INPUT_LAYER,
-            self.tr('Input layer'), [ParameterVector.VECTOR_TYPE_ANY], False))
+                                          self.tr('Input layer'), [ParameterVector.VECTOR_TYPE_ANY], False))
         self.addParameter(ParameterExtent(self.CLIP_EXTENT,
-            self.tr('Clip extent')))
+                                          self.tr('Clip extent')))
         self.addParameter(ParameterString(self.OPTIONS,
-            self.tr('Additional creation options'), '', optional=True))
+                                          self.tr('Additional creation options'), '', optional=True))
 
         self.addOutput(OutputVector(self.OUTPUT_LAYER, self.tr('Clipped (extent)')))
 
@@ -59,7 +60,6 @@ class Ogr2OgrClipExtent(OgrAlgorithm):
         inLayer = self.getParameterValue(self.INPUT_LAYER)
         ogrLayer = self.ogrConnectionString(inLayer)[1:-1]
         clipExtent = self.getParameterValue(self.CLIP_EXTENT)
-        ogrclipExtent = self.ogrConnectionString(clipExtent)
 
         output = self.getOutputFromName(self.OUTPUT_LAYER)
         outFile = output.value
@@ -68,7 +68,7 @@ class Ogr2OgrClipExtent(OgrAlgorithm):
         options = unicode(self.getParameterValue(self.OPTIONS))
 
         arguments = []
-        regionCoords = ogrclipExtent.split(',')
+        regionCoords = clipExtent.split(',')
         arguments.append('-spat')
         arguments.append(regionCoords[0])
         arguments.append(regionCoords[2])
@@ -93,4 +93,4 @@ class Ogr2OgrClipExtent(OgrAlgorithm):
         return commands
 
     def commandName(self):
-        return "ogr2ogr"
\ No newline at end of file
+        return "ogr2ogr"
