@@ -50,18 +50,18 @@ class BasicStatisticsStrings(GeoAlgorithm):
     UNIQUE = 'UNIQUE'
 
     def defineCharacteristics(self):
-        self.name = 'Basic statistics for text fields'
-        self.group = 'Vector table tools'
+        self.name, self.i18n_name = self.trAlgorithm('Basic statistics for text fields')
+        self.group, self.i18n_group = self.trAlgorithm('Vector table tools')
 
         self.addParameter(ParameterVector(self.INPUT_LAYER,
-            self.tr('Input vector layer'),
-            ParameterVector.VECTOR_TYPE_ANY, False))
+                                          self.tr('Input vector layer'),
+                                          ParameterVector.VECTOR_TYPE_ANY, False))
         self.addParameter(ParameterTableField(self.FIELD_NAME,
-            self.tr('Field to calculate statistics on'),
-            self.INPUT_LAYER, ParameterTableField.DATA_TYPE_STRING))
+                                              self.tr('Field to calculate statistics on'),
+                                              self.INPUT_LAYER, ParameterTableField.DATA_TYPE_STRING))
 
         self.addOutput(OutputHTML(self.OUTPUT_HTML_FILE,
-            self.tr('Statistics for text')))
+                                  self.tr('Statistics for text')))
 
         self.addOutput(OutputNumber(self.MIN_LEN, self.tr('Minimum length')))
         self.addOutput(OutputNumber(self.MAX_LEN, self.tr('Maximum length')))
@@ -149,6 +149,6 @@ class BasicStatisticsStrings(GeoAlgorithm):
         f.write('<meta http-equiv="Content-Type" content="text/html; \
                 charset=utf-8" /></head><body>')
         for s in algData:
-            f.write('<p>' + str(s) + '</p>')
+            f.write('<p>' + unicode(s) + '</p>')
         f.write('</body></html>')
         f.close()
