@@ -50,7 +50,7 @@ class EquivalentNumField(GeoAlgorithm):
         fields = vprovider.fields()
         fields.append(QgsField('NUM_FIELD', QVariant.Int))
         writer = output.getVectorWriter(fields, vprovider.geometryType(),
-                vlayer.crs())
+                                        vlayer.crs())
         outFeat = QgsFeature()
         inGeom = QgsGeometry()
         nElement = 0
@@ -72,10 +72,10 @@ class EquivalentNumField(GeoAlgorithm):
         del writer
 
     def defineCharacteristics(self):
-        self.name = 'Create equivalent numerical field'
-        self.group = 'Vector table tools'
+        self.name, self.i18n_name = self.trAlgorithm('Add unique value index field')
+        self.group, self.i18n_group = self.trAlgorithm('Vector table tools')
         self.addParameter(ParameterVector(self.INPUT,
-            self.tr('Input layer'), [ParameterVector.VECTOR_TYPE_ANY]))
+                                          self.tr('Input layer'), [ParameterVector.VECTOR_TYPE_ANY]))
         self.addParameter(ParameterTableField(self.FIELD,
-            self.tr('Class field'), self.INPUT))
-        self.addOutput(OutputVector(self.OUTPUT, self.tr('Numeric field')))
+                                              self.tr('Class field'), self.INPUT))
+        self.addOutput(OutputVector(self.OUTPUT, self.tr('Layer with index field')))
