@@ -42,13 +42,13 @@ class ExtentFromLayer(GeoAlgorithm):
     OUTPUT = 'OUTPUT'
 
     def defineCharacteristics(self):
-        self.name = 'Polygon from layer extent'
-        self.group = 'Vector general tools'
+        self.name, self.i18n_name = self.trAlgorithm('Polygon from layer extent')
+        self.group, self.i18n_group = self.trAlgorithm('Vector general tools')
 
         self.addParameter(ParameterVector(self.INPUT_LAYER,
-            self.tr('Input layer'), [ParameterVector.VECTOR_TYPE_ANY]))
+                                          self.tr('Input layer'), [ParameterVector.VECTOR_TYPE_ANY]))
         self.addParameter(ParameterBoolean(self.BY_FEATURE,
-            self.tr('Calculate extent for each feature separately'), False))
+                                           self.tr('Calculate extent for each feature separately'), False))
 
         self.addOutput(OutputVector(self.OUTPUT, self.tr('Extent')))
 
@@ -71,7 +71,7 @@ class ExtentFromLayer(GeoAlgorithm):
         ]
 
         writer = self.getOutputFromName(self.OUTPUT).getVectorWriter(fields,
-                QGis.WKBPolygon, layer.crs())
+                                                                     QGis.WKBPolygon, layer.crs())
 
         if byFeature:
             self.featureExtent(layer, writer, progress)
