@@ -55,15 +55,24 @@ class ExtractByAttribute(GeoAlgorithm):
                  ]
 
     def defineCharacteristics(self):
-        self.name = 'Extract by attribute'
-        self.group = 'Vector selection tools'
+        self.name, self.i18n_name = self.trAlgorithm('Extract by attribute')
+        self.group, self.i18n_group = self.trAlgorithm('Vector selection tools')
+
+        self.i18n_operators = ['=',
+                               '!=',
+                               '>',
+                               '>=',
+                               '<',
+                               '<=',
+                               self.tr('begins with'),
+                               self.tr('contains')]
 
         self.addParameter(ParameterVector(self.INPUT,
-            self.tr('Input Layer'), [ParameterVector.VECTOR_TYPE_ANY]))
+                                          self.tr('Input Layer'), [ParameterVector.VECTOR_TYPE_ANY]))
         self.addParameter(ParameterTableField(self.FIELD,
-            self.tr('Selection attribute'), self.INPUT))
+                                              self.tr('Selection attribute'), self.INPUT))
         self.addParameter(ParameterSelection(self.OPERATOR,
-            self.tr('Operator'), self.OPERATORS))
+                                             self.tr('Operator'), self.i18n_operators))
         self.addParameter(ParameterString(self.VALUE, self.tr('Value')))
 
         self.addOutput(OutputVector(self.OUTPUT, self.tr('Extracted (attribute)')))
@@ -76,7 +85,7 @@ class ExtractByAttribute(GeoAlgorithm):
 
         fields = layer.pendingFields()
         writer = self.getOutputFromName(self.OUTPUT).getVectorWriter(fields,
-            layer.wkbType(), layer.crs())
+                                                                     layer.wkbType(), layer.crs())
 
         idx = layer.fieldNameIndex(fieldName)
         fieldType = fields[idx].type()
