@@ -51,26 +51,30 @@ class FieldsPyculator(GeoAlgorithm):
     OUTPUT_LAYER = 'OUTPUT_LAYER'
     RESULT_VAR_NAME = 'value'
 
-    TYPE_NAMES = ['Integer', 'Float', 'String']
     TYPES = [QVariant.Int, QVariant.Double, QVariant.String]
 
     def defineCharacteristics(self):
-        self.name = 'Advanced Python field calculator'
-        self.group = 'Vector table tools'
+        self.name, self.i18n_name = self.trAlgorithm('Advanced Python field calculator')
+        self.group, self.i18n_group = self.trAlgorithm('Vector table tools')
+
+        self.type_names = [self.tr('Integer'),
+                           self.tr('Float'),
+                           self.tr('String')]
+
         self.addParameter(ParameterVector(self.INPUT_LAYER,
-            self.tr('Input layer'), [ParameterVector.VECTOR_TYPE_ANY], False))
+                                          self.tr('Input layer'), [ParameterVector.VECTOR_TYPE_ANY], False))
         self.addParameter(ParameterString(self.FIELD_NAME,
-            self.tr('Result field name'), 'NewField'))
+                                          self.tr('Result field name'), 'NewField'))
         self.addParameter(ParameterSelection(self.FIELD_TYPE,
-            self.tr('Field type'), self.TYPE_NAMES))
+                                             self.tr('Field type'), self.type_names))
         self.addParameter(ParameterNumber(self.FIELD_LENGTH,
-            self.tr('Field length'), 1, 255, 10))
+                                          self.tr('Field length'), 1, 255, 10))
         self.addParameter(ParameterNumber(self.FIELD_PRECISION,
-            self.tr('Field precision'), 0, 10, 0))
+                                          self.tr('Field precision'), 0, 10, 0))
         self.addParameter(ParameterString(self.GLOBAL,
-            self.tr('Global expression'), multiline=True, optional=True))
+                                          self.tr('Global expression'), multiline=True, optional=True))
         self.addParameter(ParameterString(self.FORMULA,
-            self.tr('Formula'), 'value = ', multiline=True))
+                                          self.tr('Formula'), 'value = ', multiline=True))
         self.addOutput(OutputVector(self.OUTPUT_LAYER, self.tr('Calculated')))
 
     def processAlgorithm(self, progress):
@@ -89,7 +93,7 @@ class FieldsPyculator(GeoAlgorithm):
         fields.append(QgsField(fieldName, self.TYPES[fieldType], '',
                       fieldLength, fieldPrecision))
         writer = output.getVectorWriter(fields, provider.geometryType(),
-                layer.crs())
+                                        layer.crs())
         outFeat = QgsFeature()
         new_ns = {}
 
@@ -97,7 +101,7 @@ class FieldsPyculator(GeoAlgorithm):
         if globalExpression.strip() != '':
             try:
                 bytecode = compile(globalExpression, '<string>', 'exec')
-                exec bytecode in new_ns
+                exec(bytecode, new_ns)
             except:
                 raise GeoAlgorithmExecutionException(
                     self.tr("FieldPyculator code execute error.Global code block can't be executed!\n%s\n%s" % (unicode(sys.exc_info()[0].__name__), unicode(sys.exc_info()[1]))))
@@ -107,7 +111,7 @@ class FieldsPyculator(GeoAlgorithm):
         num = 0
         for field in fields:
             field_name = unicode(field.name())
-            replval = '__attr[' + str(num) + ']'
+            replval = '__attr[' + unicode(num) + ']'
             code = code.replace('<' + field_name + '>', replval)
             num += 1
 
@@ -151,7 +155,7 @@ class FieldsPyculator(GeoAlgorithm):
                 del new_ns[self.RESULT_VAR_NAME]
 
             # Exec
-            exec bytecode in new_ns
+            exec(bytecode, new_ns)
 
             # Check result
             if self.RESULT_VAR_NAME not in new_ns:
