@@ -40,6 +40,7 @@ from processing.tools import dataobjects, vector, system
 
 from ui.FieldsCalculatorDialog import FieldsCalculatorDialog
 
+
 class FieldsCalculator(GeoAlgorithm):
 
     INPUT_LAYER = 'INPUT_LAYER'
@@ -51,24 +52,29 @@ class FieldsCalculator(GeoAlgorithm):
     FORMULA = 'FORMULA'
     OUTPUT_LAYER = 'OUTPUT_LAYER'
 
-    TYPE_NAMES = ['Float', 'Integer', 'String', 'Date']
     TYPES = [QVariant.Double, QVariant.Int, QVariant.String, QVariant.Date]
 
     def defineCharacteristics(self):
-        self.name = 'Field calculator'
-        self.group = 'Vector table tools'
+        self.name, self.i18n_name = self.trAlgorithm('Field calculator')
+        self.group, self.i18n_group = self.trAlgorithm('Vector table tools')
+
+        self.type_names = [self.tr('Float'),
+                           self.tr('Integer'),
+                           self.tr('String'),
+                           self.tr('Date')]
+
         self.addParameter(ParameterVector(self.INPUT_LAYER,
-            self.tr('Input layer'), [ParameterVector.VECTOR_TYPE_ANY], False))
+                                          self.tr('Input layer'), [ParameterVector.VECTOR_TYPE_ANY], False))
         self.addParameter(ParameterString(self.FIELD_NAME,
-            self.tr('Result field name')))
+                                          self.tr('Result field name')))
         self.addParameter(ParameterSelection(self.FIELD_TYPE,
-            self.tr('Field type'), self.TYPE_NAMES))
+                                             self.tr('Field type'), self.type_names))
         self.addParameter(ParameterNumber(self.FIELD_LENGTH,
-            self.tr('Field length'), 1, 255, 10))
+                                          self.tr('Field length'), 1, 255, 10))
         self.addParameter(ParameterNumber(self.FIELD_PRECISION,
-            self.tr('Field precision'), 0, 15, 3))
+                                          self.tr('Field precision'), 0, 15, 3))
         self.addParameter(ParameterBoolean(self.NEW_FIELD,
-            self.tr('Create new field'), True))
+                                           self.tr('Create new field'), True))
         self.addParameter(ParameterString(self.FORMULA, self.tr('Formula')))
         self.addOutput(OutputVector(self.OUTPUT_LAYER, self.tr('Calculated')))
 
@@ -151,6 +157,5 @@ class FieldsCalculator(GeoAlgorithm):
         if newField and len(fieldName) == 0:
             return self.tr('Field name is not set. Please enter a field name')
 
-
     def getCustomParametersDialog(self):
         return FieldsCalculatorDialog(self)
