@@ -34,6 +34,7 @@ from processing.core.outputs import OutputVector
 
 from processing.tools import dataobjects, vector
 
+
 class HubLines(GeoAlgorithm):
     HUBS = 'HUBS'
     HUB_FIELD = 'HUB_FIELD'
@@ -42,17 +43,17 @@ class HubLines(GeoAlgorithm):
     OUTPUT = 'OUTPUT'
 
     def defineCharacteristics(self):
-        self.name = 'Hub lines'
-        self.group = 'Vector analysis tools'
+        self.name, self.i18n_name = self.trAlgorithm('Hub lines')
+        self.group, self.i18n_group = self.trAlgorithm('Vector analysis tools')
 
         self.addParameter(ParameterVector(self.HUBS,
-            self.tr('Hub point layer'), [ParameterVector.VECTOR_TYPE_ANY]))
+                                          self.tr('Hub point layer'), [ParameterVector.VECTOR_TYPE_ANY]))
         self.addParameter(ParameterTableField(self.HUB_FIELD,
-            self.tr('Hub ID field'), self.HUBS))
+                                              self.tr('Hub ID field'), self.HUBS))
         self.addParameter(ParameterVector(self.SPOKES,
-            self.tr('Spoke point layer'), [ParameterVector.VECTOR_TYPE_ANY]))
+                                          self.tr('Spoke point layer'), [ParameterVector.VECTOR_TYPE_ANY]))
         self.addParameter(ParameterTableField(self.SPOKE_FIELD,
-            self.tr('Spoke ID field'), self.SPOKES))
+                                              self.tr('Spoke ID field'), self.SPOKES))
 
         self.addOutput(OutputVector(self.OUTPUT, self.tr('Hub lines')))
 
