@@ -32,19 +32,20 @@ from processing.core.outputs import OutputVector
 
 from processing.tools import dataobjects, vector
 
+
 class Merge(GeoAlgorithm):
     LAYER1 = 'LAYER1'
     LAYER2 = 'LAYER2'
     OUTPUT = 'OUTPUT'
 
     def defineCharacteristics(self):
-        self.name = 'Merge vector layers'
-        self.group = 'Vector general tools'
+        self.name, self.i18n_name = self.trAlgorithm('Merge vector layers')
+        self.group, self.i18n_group = self.trAlgorithm('Vector general tools')
 
         self.addParameter(ParameterVector(self.LAYER1,
-            self.tr('Input layer 1'), [ParameterVector.VECTOR_TYPE_ANY]))
+                                          self.tr('Input layer 1'), [ParameterVector.VECTOR_TYPE_ANY]))
         self.addParameter(ParameterVector(self.LAYER2,
-            self.tr('Input layer 2'), [ParameterVector.VECTOR_TYPE_ANY]))
+                                          self.tr('Input layer 2'), [ParameterVector.VECTOR_TYPE_ANY]))
 
         self.addOutput(OutputVector(self.OUTPUT, self.tr('Merged')))
 
