@@ -44,8 +44,8 @@ class MultipartToSingleparts(GeoAlgorithm):
     # =========================================================================
 
     def defineCharacteristics(self):
-        self.name = 'Multipart to singleparts'
-        self.group = 'Vector geometry tools'
+        self.name, self.i18n_name = self.trAlgorithm('Multipart to singleparts')
+        self.group, self.i18n_group = self.trAlgorithm('Vector geometry tools')
 
         self.addParameter(ParameterVector(self.INPUT, self.tr('Input layer')))
         self.addOutput(OutputVector(self.OUTPUT, self.tr('Single parts')))
@@ -96,7 +96,7 @@ class MultipartToSingleparts(GeoAlgorithm):
                 return QGis.WKBPolygon
             else:
                 return QGis.WKBUnknown
-        except Exception, err:
+        except Exception as err:
             raise GeoAlgorithmExecutionException(unicode(err))
 
     def extractAsSingle(self, geom):
