@@ -42,14 +42,14 @@ class PointsInPolygon(GeoAlgorithm):
     FIELD = 'FIELD'
 
     def defineCharacteristics(self):
-        self.name = 'Count points in polygon'
-        self.group = 'Vector analysis tools'
+        self.name, self.i18n_name = self.trAlgorithm('Count points in polygon')
+        self.group, self.i18n_group = self.trAlgorithm('Vector analysis tools')
         self.addParameter(ParameterVector(self.POLYGONS,
-            self.tr('Polygons'), [ParameterVector.VECTOR_TYPE_POLYGON]))
+                                          self.tr('Polygons'), [ParameterVector.VECTOR_TYPE_POLYGON]))
         self.addParameter(ParameterVector(self.POINTS,
-            self.tr('Points'), [ParameterVector.VECTOR_TYPE_POINT]))
+                                          self.tr('Points'), [ParameterVector.VECTOR_TYPE_POINT]))
         self.addParameter(ParameterString(self.FIELD,
-            self.tr('Count field name'), 'NUMPOINTS'))
+                                          self.tr('Count field name'), 'NUMPOINTS'))
 
         self.addOutput(OutputVector(self.OUTPUT, self.tr('Count')))
 
@@ -63,7 +63,7 @@ class PointsInPolygon(GeoAlgorithm):
         fields.append(QgsField(fieldName, QVariant.Int))
 
         (idxCount, fieldList) = vector.findOrCreateField(polyLayer,
-                polyLayer.pendingFields(), fieldName)
+                                                         polyLayer.pendingFields(), fieldName)
 
         writer = self.getOutputFromName(self.OUTPUT).getVectorWriter(
             fields.toList(), polyProvider.geometryType(), polyProvider.crs())
