@@ -44,16 +44,16 @@ class PointsInPolygonUnique(GeoAlgorithm):
     CLASSFIELD = 'CLASSFIELD'
 
     def defineCharacteristics(self):
-        self.name = 'Count unique points in polygon'
-        self.group = 'Vector analysis tools'
+        self.name, self.i18n_name = self.trAlgorithm('Count unique points in polygon')
+        self.group, self.i18n_group = self.trAlgorithm('Vector analysis tools')
         self.addParameter(ParameterVector(self.POLYGONS,
-            self.tr('Polygons'), [ParameterVector.VECTOR_TYPE_POLYGON]))
+                                          self.tr('Polygons'), [ParameterVector.VECTOR_TYPE_POLYGON]))
         self.addParameter(ParameterVector(self.POINTS,
-            self.tr('Points'), [ParameterVector.VECTOR_TYPE_POINT]))
+                                          self.tr('Points'), [ParameterVector.VECTOR_TYPE_POINT]))
         self.addParameter(ParameterTableField(self.CLASSFIELD,
-            self.tr('Class field'), self.POINTS))
+                                              self.tr('Class field'), self.POINTS))
         self.addParameter(ParameterString(self.FIELD,
-            self.tr('Count field name'), 'NUMPOINTS'))
+                                          self.tr('Count field name'), 'NUMPOINTS'))
         self.addOutput(OutputVector(self.OUTPUT, self.tr('Unique count')))
 
     def processAlgorithm(self, progress):
@@ -68,7 +68,7 @@ class PointsInPolygonUnique(GeoAlgorithm):
 
         classFieldIndex = pointLayer.fieldNameIndex(classFieldName)
         (idxCount, fieldList) = vector.findOrCreateField(polyLayer,
-                polyLayer.pendingFields(), fieldName)
+                                                         polyLayer.pendingFields(), fieldName)
 
         writer = self.getOutputFromName(self.OUTPUT).getVectorWriter(
             fields.toList(), polyProvider.geometryType(), polyProvider.crs())
