@@ -49,17 +49,17 @@ class PointsInPolygonWeighted(GeoAlgorithm):
     # =========================================================================
 
     def defineCharacteristics(self):
-        self.name = 'Count points in polygon(weighted)'
-        self.group = 'Vector analysis tools'
+        self.name, self.i18n_name = self.trAlgorithm('Count points in polygon(weighted)')
+        self.group, self.i18n_group = self.trAlgorithm('Vector analysis tools')
 
         self.addParameter(ParameterVector(self.POLYGONS,
-            self.tr('Polygons'), [ParameterVector.VECTOR_TYPE_POLYGON]))
+                                          self.tr('Polygons'), [ParameterVector.VECTOR_TYPE_POLYGON]))
         self.addParameter(ParameterVector(self.POINTS,
-            self.tr('Points'), [ParameterVector.VECTOR_TYPE_POINT]))
+                                          self.tr('Points'), [ParameterVector.VECTOR_TYPE_POINT]))
         self.addParameter(ParameterTableField(self.WEIGHT,
-            self.tr('Weight field'), self.POINTS))
+                                              self.tr('Weight field'), self.POINTS))
         self.addParameter(ParameterString(self.FIELD,
-            self.tr('Count field name'), 'NUMPOINTS'))
+                                          self.tr('Count field name'), 'NUMPOINTS'))
 
         self.addOutput(OutputVector(self.OUTPUT, self.tr('Weighted count')))
 
@@ -74,7 +74,7 @@ class PointsInPolygonWeighted(GeoAlgorithm):
         fields.append(QgsField(fieldName, QVariant.Int))
 
         (idxCount, fieldList) = vector.findOrCreateField(polyLayer,
-                polyLayer.pendingFields(), fieldName)
+                                                         polyLayer.pendingFields(), fieldName)
 
         writer = self.getOutputFromName(self.OUTPUT).getVectorWriter(
             fields.toList(), polyProvider.geometryType(), polyProvider.crs())
@@ -101,13 +101,13 @@ class PointsInPolygonWeighted(GeoAlgorithm):
                 hasIntersections = True
 
             if hasIntersections:
-                progress.setText(str(len(points)))
+                progress.setText(unicode(len(points)))
                 for i in points:
                     request = QgsFeatureRequest().setFilterFid(i)
                     ftPoint = pointLayer.getFeatures(request).next()
                     tmpGeom = QgsGeometry(ftPoint.geometry())
                     if geom.contains(tmpGeom):
-                        weight = str(ftPoint.attributes()[fieldIdx])
+                        weight = unicode(ftPoint.attributes()[fieldIdx])
                         try:
                             count += float(weight)
                         except:
