@@ -45,21 +45,21 @@ class RandomExtractWithinSubsets(GeoAlgorithm):
     FIELD = 'FIELD'
     OUTPUT = 'OUTPUT'
 
-    METHODS = ['Number of selected features',
-               'Percentage of selected features']
-
     def defineCharacteristics(self):
-        self.name = 'Random extract within subsets'
-        self.group = 'Vector selection tools'
+        self.name, self.i18n_name = self.trAlgorithm('Random extract within subsets')
+        self.group, self.i18n_group = self.trAlgorithm('Vector selection tools')
+
+        self.methods = [self.tr('Number of selected features'),
+                        self.tr('Percentage of selected features')]
 
         self.addParameter(ParameterVector(self.INPUT,
-            self.tr('Input layer'), [ParameterVector.VECTOR_TYPE_ANY]))
+                                          self.tr('Input layer'), [ParameterVector.VECTOR_TYPE_ANY]))
         self.addParameter(ParameterTableField(self.FIELD,
-            self.tr('ID field'), self.INPUT))
+                                              self.tr('ID field'), self.INPUT))
         self.addParameter(ParameterSelection(self.METHOD,
-            self.tr('Method'), self.METHODS, 0))
+                                             self.tr('Method'), self.methods, 0))
         self.addParameter(ParameterNumber(self.NUMBER,
-            self.tr('Number/percentage of selected features'), 1, None, 10))
+                                          self.tr('Number/percentage of selected features'), 1, None, 10))
 
         self.addOutput(OutputVector(self.OUTPUT, self.tr('Extracted (random stratified)')))
 
@@ -120,7 +120,6 @@ class RandomExtractWithinSubsets(GeoAlgorithm):
         else:
             selran = range(0, featureCount)
 
-
         features = vector.features(layer)
         for (i, feat) in enumerate(features):
             if i in selran:
