@@ -57,20 +57,20 @@ class ZonalStatistics(GeoAlgorithm):
     OUTPUT_LAYER = 'OUTPUT_LAYER'
 
     def defineCharacteristics(self):
-        self.name = 'Zonal Statistics'
-        self.group = 'Raster tools'
+        self.name, self.i18n_name = self.trAlgorithm('Zonal Statistics')
+        self.group, self.i18n_group = self.trAlgorithm('Raster tools')
 
         self.addParameter(ParameterRaster(self.INPUT_RASTER,
-            self.tr('Raster layer')))
+                                          self.tr('Raster layer')))
         self.addParameter(ParameterNumber(self.RASTER_BAND,
-            self.tr('Raster band'), 1, 999, 1))
+                                          self.tr('Raster band'), 1, 999, 1))
         self.addParameter(ParameterVector(self.INPUT_VECTOR,
-            self.tr('Vector layer containing zones'),
-            [ParameterVector.VECTOR_TYPE_POLYGON]))
+                                          self.tr('Vector layer containing zones'),
+                                          [ParameterVector.VECTOR_TYPE_POLYGON]))
         self.addParameter(ParameterString(self.COLUMN_PREFIX,
-            self.tr('Output column prefix'), '_'))
+                                          self.tr('Output column prefix'), '_'))
         self.addParameter(ParameterBoolean(self.GLOBAL_EXTENT,
-            self.tr('Load whole raster in memory')))
+                                           self.tr('Load whole raster in memory')))
         self.addOutput(OutputVector(self.OUTPUT_LAYER, self.tr('Zonal statistics')))
 
     def processAlgorithm(self, progress):
@@ -133,28 +133,28 @@ class ZonalStatistics(GeoAlgorithm):
 
         fields = layer.pendingFields()
         (idxMin, fields) = vector.findOrCreateField(layer, fields,
-                columnPrefix + 'min', 21, 6)
+                                                    columnPrefix + 'min', 21, 6)
         (idxMax, fields) = vector.findOrCreateField(layer, fields,
-                columnPrefix + 'max', 21, 6)
+                                                    columnPrefix + 'max', 21, 6)
         (idxSum, fields) = vector.findOrCreateField(layer, fields,
-                columnPrefix + 'sum', 21, 6)
+                                                    columnPrefix + 'sum', 21, 6)
         (idxCount, fields) = vector.findOrCreateField(layer, fields,
-                columnPrefix + 'count', 21, 6)
+                                                      columnPrefix + 'count', 21, 6)
         (idxMean, fields) = vector.findOrCreateField(layer, fields,
-                columnPrefix + 'mean', 21, 6)
+                                                     columnPrefix + 'mean', 21, 6)
         (idxStd, fields) = vector.findOrCreateField(layer, fields,
-                columnPrefix + 'std', 21, 6)
+                                                    columnPrefix + 'std', 21, 6)
         (idxUnique, fields) = vector.findOrCreateField(layer, fields,
-                columnPrefix + 'unique', 21, 6)
+                                                       columnPrefix + 'unique', 21, 6)
         (idxRange, fields) = vector.findOrCreateField(layer, fields,
-                columnPrefix + 'range', 21, 6)
+                                                      columnPrefix + 'range', 21, 6)
         (idxVar, fields) = vector.findOrCreateField(layer, fields,
-                columnPrefix + 'var', 21, 6)
+                                                    columnPrefix + 'var', 21, 6)
         (idxMedian, fields) = vector.findOrCreateField(layer, fields,
-                columnPrefix + 'median', 21, 6)
+                                                       columnPrefix + 'median', 21, 6)
         if hasSciPy:
             (idxMode, fields) = vector.findOrCreateField(layer, fields,
-                    columnPrefix + 'mode', 21, 6)
+                                                         columnPrefix + 'mode', 21, 6)
 
         writer = self.getOutputFromName(self.OUTPUT_LAYER).getVectorWriter(
             fields.toList(), layer.dataProvider().geometryType(), layer.crs())
@@ -213,15 +213,15 @@ class ZonalStatistics(GeoAlgorithm):
 
             # Rasterize it
             rasterizedDS = memRasterDriver.Create('', srcOffset[2],
-                    srcOffset[3], 1, gdal.GDT_Byte)
+                                                  srcOffset[3], 1, gdal.GDT_Byte)
             rasterizedDS.SetGeoTransform(newGeoTransform)
             gdal.RasterizeLayer(rasterizedDS, [1], memLayer, burn_values=[1])
             rasterizedArray = rasterizedDS.ReadAsArray()
 
             srcArray = numpy.nan_to_num(srcArray)
             masked = numpy.ma.MaskedArray(srcArray,
-                    mask=numpy.logical_or(srcArray == noData,
-                    numpy.logical_not(rasterizedArray)))
+                                          mask=numpy.logical_or(srcArray == noData,
+                                                                numpy.logical_not(rasterizedArray)))
 
             outFeat.setGeometry(geom)
 
