@@ -45,6 +45,7 @@ WIDGET, BASE = uic.loadUiType(
 
 
 class FieldsCalculatorDialog(BASE, WIDGET):
+
     def __init__(self, alg):
         super(FieldsCalculatorDialog, self).__init__(None)
         self.setupUi(self)
@@ -74,7 +75,7 @@ class FieldsCalculatorDialog(BASE, WIDGET):
                 self.tr('[Save to temporary file]'))
 
         self.mOutputFieldTypeComboBox.blockSignals(True)
-        for t in self.alg.TYPE_NAMES:
+        for t in self.alg.type_names:
             self.mOutputFieldTypeComboBox.addItem(t)
         self.mOutputFieldTypeComboBox.blockSignals(False)
 
@@ -176,13 +177,13 @@ class FieldsCalculatorDialog(BASE, WIDGET):
         self.alg.setParameterValue('INPUT_LAYER', layer)
         self.alg.setParameterValue('FIELD_NAME', fieldName)
         self.alg.setParameterValue('FIELD_TYPE',
-                self.mOutputFieldTypeComboBox.currentIndex())
+                                   self.mOutputFieldTypeComboBox.currentIndex())
         self.alg.setParameterValue('FIELD_LENGTH',
-                self.mOutputFieldWidthSpinBox.value())
+                                   self.mOutputFieldWidthSpinBox.value())
         self.alg.setParameterValue('FIELD_PRECISION',
-                self.mOutputFieldPrecisionSpinBox.value())
+                                   self.mOutputFieldPrecisionSpinBox.value())
         self.alg.setParameterValue('NEW_FIELD',
-                self.mNewFieldGroupBox.isChecked())
+                                   self.mNewFieldGroupBox.isChecked())
         self.alg.setParameterValue('FORMULA', self.builder.expressionText())
         self.alg.setOutputValue('OUTPUT_LAYER', self.leOutputFile.text().strip() or None)
 
@@ -199,9 +200,9 @@ class FieldsCalculatorDialog(BASE, WIDGET):
             if self.setParamValues():
                 QApplication.setOverrideCursor(QCursor(Qt.WaitCursor))
                 ProcessingLog.addToLog(ProcessingLog.LOG_ALGORITHM,
-                                     self.alg.getAsCommand())
+                                       self.alg.getAsCommand())
 
-                self.executed =  runalg(self.alg, self)
+                self.executed = runalg(self.alg, self)
                 if self.executed:
                     handleAlgorithmResults(self.alg,
                                            self,
