@@ -78,14 +78,14 @@ class RAlgorithm(GeoAlgorithm):
 
     def defineCharacteristicsFromScript(self):
         lines = self.script.split('\n')
-        self.name = '[Unnamed algorithm]'
-        self.group = 'User R scripts'
+        self.name, self.i18n_name = self.trAlgorithm('[Unnamed algorithm]')
+        self.group, self.i18n_group = self.trAlgorithm('User R scripts')
         self.parseDescription(iter(lines))
 
     def defineCharacteristicsFromFile(self):
         filename = os.path.basename(self.descriptionFile)
         self.name = filename[:filename.rfind('.')].replace('_', ' ')
-        self.group = 'User R scripts'
+        self.group, self.i18n_group = self.trAlgorithm('User R scripts')
         with open(self.descriptionFile, 'r') as f:
             lines = [line.strip() for line in f]
         self.parseDescription(iter(lines))
@@ -298,7 +298,7 @@ class RAlgorithm(GeoAlgorithm):
 
         # Try to install packages if needed
         if isWindows():
-            commands.append('.libPaths(\"' + str(RUtils.RLibs()).replace('\\','/') + '\")')
+            commands.append('.libPaths(\"' + unicode(RUtils.RLibs()).replace('\\', '/') + '\")')
         packages = RUtils.getRequiredPackages(self.script)
         packages.extend(['rgdal', 'raster'])
         for p in packages:
@@ -345,7 +345,7 @@ class RAlgorithm(GeoAlgorithm):
                             ParameterFile)):
                 commands.append(param.name + '="' + param.value + '"')
             elif isinstance(param, (ParameterNumber, ParameterSelection)):
-                commands.append(param.name + '=' + str(param.value))
+                commands.append(param.name + '=' + unicode(param.value))
             elif isinstance(param, ParameterBoolean):
                 if param.value:
                     commands.append(param.name + '=TRUE')
@@ -358,13 +358,13 @@ class RAlgorithm(GeoAlgorithm):
                     for layer in layers:
                         layer = layer.replace('\\', '/')
                         if self.passFileNames:
-                            commands.append('tempvar' + str(iLayer) + ' <- "'
+                            commands.append('tempvar' + unicode(iLayer) + ' <- "'
                                             + layer + '"')
                         elif self.useRasterPackage:
-                            commands.append('tempvar' + str(iLayer) + ' <- '
+                            commands.append('tempvar' + unicode(iLayer) + ' <- '
                                             + 'brick("' + layer + '")')
                         else:
-                            commands.append('tempvar' + str(iLayer) + ' <- '
+                            commands.append('tempvar' + unicode(iLayer) + ' <- '
                                             + 'readGDAL("' + layer + '")')
                         iLayer += 1
                 else:
@@ -379,10 +379,10 @@ class RAlgorithm(GeoAlgorithm):
                         filename = os.path.basename(layer)
                         filename = filename[:-4]
                         if self.passFileNames:
-                            commands.append('tempvar' + str(iLayer) + ' <- "'
+                            commands.append('tempvar' + unicode(iLayer) + ' <- "'
                                             + layer + '"')
                         else:
-                            commands.append('tempvar' + str(iLayer) + ' <- '
+                            commands.append('tempvar' + unicode(iLayer) + ' <- '
                                             + 'readOGR("' + layer + '",layer="'
                                             + filename + '")')
                         iLayer += 1
@@ -393,7 +393,7 @@ class RAlgorithm(GeoAlgorithm):
                 for layer in layers:
                     if iLayer != 0:
                         s += ','
-                    s += 'tempvar' + str(iLayer)
+                    s += 'tempvar' + unicode(iLayer)
                     iLayer += 1
                 s += ')\n'
                 commands.append(s)
@@ -426,5 +426,3 @@ class RAlgorithm(GeoAlgorithm):
                 '<p><a href="http://docs.qgis.org/testing/en/docs/user_manual/processing/3rdParty.html">Click here</a> '
                 'to know more about how to install and configure R to be used with QGIS</p>')
             return html
-
-
