@@ -26,6 +26,7 @@ __copyright__ = '(C) 2012, Victor Olaya'
 __revision__ = '$Format:%H$'
 
 import os
+import re
 
 from PyQt4.QtGui import QWidget, QPushButton, QLineEdit, QHBoxLayout, QSizePolicy, QFileDialog
 from PyQt4.QtCore import QSettings
@@ -77,10 +78,15 @@ class BatchOutputSelectionPanel(QWidget):
             path = unicode(settings.value('/Processing/LastBatchOutputPath'))
         else:
             path = ''
-        filename = QFileDialog.getSaveFileName(self, self.tr('Save file'), path,
-                filefilter)
+        filename, selectedFileFilter = QFileDialog.getSaveFileNameAndFilter(self,
+                                                                            self.tr('Save file'), path, filefilter)
+        print filename, selectedFileFilter
         if filename:
-            filename = unicode(filename)
+            if not filename.lower().endswith(
+                    tuple(re.findall("\*(\.[a-z]{1,10})", filefilter))):
+                ext = re.search("\*(\.[a-z]{1,10})", selectedFileFilter)
+                if ext:
+                    filename += ext.group(1)
             settings.setValue('/Processing/LastBatchOutputPath', os.path.dirname(filename))
             dlg = AutofillDialog(self.alg)
             dlg.exec_()
@@ -88,28 +94,28 @@ class BatchOutputSelectionPanel(QWidget):
                 try:
                     if dlg.mode == AutofillDialog.DO_NOT_AUTOFILL:
                         self.table.cellWidget(self.row,
-                                self.col).setValue(filename)
+                                              self.col).setValue(filename)
                     elif dlg.mode == AutofillDialog.FILL_WITH_NUMBERS:
                         n = self.table.rowCount() - self.row
                         for i in range(n):
                             name = filename[:filename.rfind('.')] \
-                                + str(i + 1) + filename[filename.rfind('.'):]
+                                + unicode(i + 1) + filename[filename.rfind('.'):]
                             self.table.cellWidget(i + self.row,
-                                    self.col).setValue(name)
+                                                  self.col).setValue(name)
                     elif dlg.mode == AutofillDialog.FILL_WITH_PARAMETER:
                         n = self.table.rowCount() - self.row
                         for i in range(n):
                             widget = self.table.cellWidget(i + self.row,
-                                    dlg.param)
+                                                           dlg.param)
                             param = self.alg.parameters[dlg.param]
                             if isinstance(param, (ParameterRaster,
-                                    ParameterVector, ParameterTable,
-                                    ParameterMultipleInput)):
+                                                  ParameterVector, ParameterTable,
+                                                  ParameterMultipleInput)):
                                 s = unicode(widget.getText())
                                 s = os.path.basename(s)
                                 s = os.path.splitext(s)[0]
                             elif isinstance(param, ParameterBoolean):
-                                s = str(widget.currentIndex() == 0)
+                                s = unicode(widget.currentIndex() == 0)
                             elif isinstance(param, ParameterSelection):
                                 s = unicode(widget.currentText())
                             elif isinstance(param, ParameterFixedTable):
@@ -119,7 +125,7 @@ class BatchOutputSelectionPanel(QWidget):
                             name = filename[:filename.rfind('.')] + s \
                                 + filename[filename.rfind('.'):]
                             self.table.cellWidget(i + self.row,
-                                    self.col).setValue(name)
+                                                  self.col).setValue(name)
                 except:
                     pass
 
@@ -132,7 +138,7 @@ class BatchOutputSelectionPanel(QWidget):
             lastDir = ''
 
         dirName = QFileDialog.getExistingDirectory(self,
-            self.tr('Select directory'), lastDir, QFileDialog.ShowDirsOnly)
+                                                   self.tr('Select directory'), lastDir, QFileDialog.ShowDirsOnly)
 
         if dirName:
             self.table.cellWidget(self.row, self.col).setValue(dirName)
