@@ -52,14 +52,16 @@ class ProcessingToolbox(BASE, WIDGET):
 
     USE_CATEGORIES = '/Processing/UseSimplifiedInterface'
 
+    updateAlgList = True
+
     def __init__(self):
         super(ProcessingToolbox, self).__init__(None)
         self.setupUi(self)
         self.setAllowedAreas(Qt.LeftDockWidgetArea | Qt.RightDockWidgetArea)
 
         self.modeComboBox.clear()
-        self.modeComboBox.addItems(['Simplified interface',
-                                   'Advanced interface'])
+        self.modeComboBox.addItems([self.tr('Simplified interface'),
+                                   self.tr('Advanced interface')])
         settings = QSettings()
         if not settings.contains(self.USE_CATEGORIES):
             settings.setValue(self.USE_CATEGORIES, True)
@@ -118,11 +120,14 @@ class ProcessingToolbox(BASE, WIDGET):
         self.fillTree()
 
     def algsListHasChanged(self):
-        self.fillTree()
+        if self.updateAlgList:
+            self.fillTree()
 
     def updateProvider(self, providerName, updateAlgsList=True):
         if updateAlgsList:
+            self.updateAlgList = False
             Processing.updateAlgsList()
+            self.updateAlgList = True
         for i in xrange(self.algorithmTree.invisibleRootItem().childCount()):
             child = self.algorithmTree.invisibleRootItem().child(i)
             if isinstance(child, TreeProviderItem):
@@ -133,6 +138,7 @@ class ProcessingToolbox(BASE, WIDGET):
                     for i in xrange(child.childCount()):
                         child.child(i).sortChildren(0, Qt.AscendingOrder)
                     break
+        self.addRecentAlgorithms(True)
 
     def showPopupMenu(self, point):
         item = self.algorithmTree.itemAt(point)
@@ -163,7 +169,7 @@ class ProcessingToolbox(BASE, WIDGET):
                 action.setData(alg, self)
                 if action.isEnabled():
                     contextMenuAction = QAction(action.name,
-                            self.algorithmTree)
+                                                self.algorithmTree)
                     contextMenuAction.triggered.connect(action.execute)
                     popupmenu.addAction(contextMenuAction)
 
@@ -335,7 +341,6 @@ class ProcessingToolbox(BASE, WIDGET):
             providerItem.setHidden(providerItem.childCount() == 0)
 
 
-
 class TreeAlgorithmItem(QTreeWidgetItem):
 
     def __init__(self, alg):
@@ -361,6 +366,7 @@ class TreeActionItem(QTreeWidgetItem):
         self.setText(0, action.name)
         self.setIcon(0, action.getIcon())
 
+
 class TreeProviderItem(QTreeWidgetItem):
 
     def __init__(self, providerName):
@@ -388,8 +394,9 @@ class TreeProviderItem(QTreeWidgetItem):
                 groupItem = groups[alg.group]
             else:
                 groupItem = QTreeWidgetItem()
-                groupItem.setText(0, alg.group)
-                groupItem.setToolTip(0, alg.group)
+                name = alg.i18n_group or alg.group
+                groupItem.setText(0, name)
+                groupItem.setToolTip(0, name)
                 groups[alg.group] = groupItem
             algItem = TreeAlgorithmItem(alg)
             groupItem.addChild(algItem)
@@ -407,7 +414,7 @@ class TreeProviderItem(QTreeWidgetItem):
             groupItem.addChild(algItem)
 
         self.setText(0, self.provider.getDescription()
-                  + QCoreApplication.translate( "TreeProviderItem", " [{0} geoalgorithms]" ).format( count ) )
+                     + QCoreApplication.translate("TreeProviderItem", " [{0} geoalgorithms]").format(count))
         self.setToolTip(0, self.text(0))
         for groupItem in groups.values():
             self.addChild(groupItem)
