@@ -16,6 +16,7 @@
 *                                                                         *
 ***************************************************************************
 """
+from operator import attrgetter
 
 __author__ = 'Victor Olaya'
 __date__ = 'August 2012'
@@ -100,9 +101,8 @@ class Algorithm():
         self.outputsFolded = True
         self.active = True
 
-
     def todict(self):
-        return {k:v for k,v in self.__dict__.iteritems() if not k.startswith("_")}
+        return {k: v for k, v in self.__dict__.iteritems() if not k.startswith("_")}
 
     @property
     def algorithm(self):
@@ -113,10 +113,10 @@ class Algorithm():
     def setName(self, model):
         if self.name is None:
             i = 1
-            name = self.consoleName + "_" + str(i)
+            name = self.consoleName + "_" + unicode(i)
             while name in model.algs:
                 i += 1
-                name = self.consoleName + "_" + str(i)
+                name = self.consoleName + "_" + unicode(i)
             self.name = name
 
 
@@ -209,6 +209,7 @@ class ModelerAlgorithm(GeoAlgorithm):
                     modelOutput.name = self.getSafeNameForOutput(alg.name, out)
                     modelOutput.description = alg.outputs[out].description
                     self.outputs.append(modelOutput)
+        self.outputs.sort(key=attrgetter("description"))
 
     def addParameter(self, param):
         self.inputs[param.param.name] = param
@@ -223,19 +224,21 @@ class ModelerAlgorithm(GeoAlgorithm):
 
     def getNameForAlgorithm(self, alg):
         i = 1
-        while alg.consoleName.upper().replace(":", "") + "_" + str(i) in self.algs.keys():
+        while alg.consoleName.upper().replace(":", "") + "_" + unicode(i) in self.algs.keys():
             i += 1
-        return alg.consoleName.upper().replace(":", "") + "_" + str(i)
+        return alg.consoleName.upper().replace(":", "") + "_" + unicode(i)
 
     def updateAlgorithm(self, alg):
         alg.pos = self.algs[alg.name].pos
+        alg.paramsFolded = self.algs[alg.name].paramsFolded
+        alg.outputsFolded = self.algs[alg.name].outputsFolded
         self.algs[alg.name] = alg
 
         from processing.modeler.ModelerGraphicItem import ModelerGraphicItem
         for i, out in enumerate(alg.outputs):
             alg.outputs[out].pos = (alg.outputs[out].pos or
-                    alg.pos + QPointF(
-                        ModelerGraphicItem.BOX_WIDTH,
+                                    alg.pos + QPointF(
+                ModelerGraphicItem.BOX_WIDTH,
                         (i + 1.5) * ModelerGraphicItem.BOX_HEIGHT))
 
     def removeAlgorithm(self, name):
@@ -282,7 +285,6 @@ class ModelerAlgorithm(GeoAlgorithm):
                         return True
         return False
 
-
     def getDependsOnAlgorithms(self, name):
         """This method returns a list with names of algorithms
         a given one depends on.
@@ -302,7 +304,6 @@ class ModelerAlgorithm(GeoAlgorithm):
                 algs.add(value.alg)
                 algs.update(self.getDependsOnAlgorithms(value.alg))
 
-
         return algs
 
     def getDependentAlgorithms(self, name):
@@ -349,7 +350,7 @@ class ModelerAlgorithm(GeoAlgorithm):
                 # We allow unexistent filepaths, since that allows
                 # algorithms to skip some conversion routines
                 if not param.setValue(value) and not isinstance(param,
-                        ParameterDataObject):
+                                                                ParameterDataObject):
                     raise GeoAlgorithmExecutionException(
                         self.tr('Wrong value: %s', 'ModelerAlgorithm') % value)
         for out in algInstance.outputs:
@@ -413,7 +414,7 @@ class ModelerAlgorithm(GeoAlgorithm):
                         self.addToRegion(layer, first)
                         first = False
         if found:
-            return ','.join([str(v) for v in [self.xmin, self.xmax, self.ymin, self.ymax]])
+            return ','.join([unicode(v) for v in [self.xmin, self.xmax, self.ymin, self.ymax]])
         else:
             return None
 
@@ -429,7 +430,6 @@ class ModelerAlgorithm(GeoAlgorithm):
             self.ymin = min(self.ymin, layer.extent().yMinimum())
             self.ymax = max(self.ymax, layer.extent().yMaximum())
 
-
     def processAlgorithm(self, progress):
         executed = []
         toExecute = [alg for alg in self.algs.values() if alg.active]
@@ -448,16 +448,16 @@ class ModelerAlgorithm(GeoAlgorithm):
                                 self.tr('Prepare algorithm: %s', 'ModelerAlgorithm') % alg.name)
                             self.prepareAlgorithm(alg)
                             progress.setText(
-                                self.tr('Running %s [%i/%i]', 'ModelerAlgorithm') % (alg.description, len(executed) + 1 ,len(toExecute)))
+                                self.tr('Running %s [%i/%i]', 'ModelerAlgorithm') % (alg.description, len(executed) + 1, len(toExecute)))
                             progress.setDebugInfo('Parameters: ' + ', '.join([unicode(p).strip()
-                                                + '=' + unicode(p.value) for p in alg.algorithm.parameters]))
+                                                                              + '=' + unicode(p.value) for p in alg.algorithm.parameters]))
                             t0 = time.time()
                             alg.algorithm.execute(progress, self)
                             dt = time.time() - t0
                             executed.append(alg.name)
                             progress.setDebugInfo(
                                 self.tr('OK. Execution took %0.3f ms (%i outputs).', 'ModelerAlgorithm') % (dt, len(alg.algorithm.outputs)))
-                        except GeoAlgorithmExecutionException, e:
+                        except GeoAlgorithmExecutionException as e:
                             progress.setDebugInfo(self.tr('Failed', 'ModelerAlgorithm'))
                             raise GeoAlgorithmExecutionException(
                                 self.tr('Error executing algorithm %s\n%s', 'ModelerAlgorithm') % (alg.description, e.msg))
@@ -465,7 +465,6 @@ class ModelerAlgorithm(GeoAlgorithm):
         progress.setDebugInfo(
             self.tr('Model processed ok. Executed %i algorithms total', 'ModelerAlgorithm') % len(executed))
 
-
     def getAsCommand(self):
         if self.descriptionFile:
             return GeoAlgorithm.getAsCommand(self)
@@ -493,7 +492,7 @@ class ModelerAlgorithm(GeoAlgorithm):
 
     def todict(self):
         keys = ["inputs", "group", "name", "algs", "helpContent"]
-        return {k:v for k,v in self.__dict__.iteritems() if k in keys}
+        return {k: v for k, v in self.__dict__.iteritems() if k in keys}
 
     def toJson(self):
         def todict(o):
@@ -502,11 +501,10 @@ class ModelerAlgorithm(GeoAlgorithm):
             try:
                 d = o.todict()
                 return {"class": o.__class__.__module__ + "." + o.__class__.__name__, "values": d}
-            except Exception, e:
+            except Exception as e:
                 pass
         return json.dumps(self, default=todict, indent=4)
 
-
     @staticmethod
     def fromJson(s):
         def fromdict(d):
@@ -528,20 +526,19 @@ class ModelerAlgorithm(GeoAlgorithm):
                 module = _import(moduleName)
                 clazz = getattr(module, className)
                 instance = clazz()
-                for k,v in values.iteritems():
+                for k, v in values.iteritems():
                     instance.__dict__[k] = v
                 return instance
             except KeyError:
                 return d
-            except Exception, e:
+            except Exception as e:
                 raise e
         try:
             model = json.loads(s, object_hook=fromdict)
-        except Exception, e:
+        except Exception as e:
             raise WrongModelException(e.args[0])
         return model
 
-
     @staticmethod
     def fromJsonFile(filename):
         with open(filename) as f:
@@ -550,7 +547,6 @@ class ModelerAlgorithm(GeoAlgorithm):
         alg.descriptionFile = filename
         return alg
 
-
     ############LEGACY METHOD TO SUPPORT OLD FORMAT###########
 
     LINE_BREAK_STRING = '%%%'
@@ -560,11 +556,10 @@ class ModelerAlgorithm(GeoAlgorithm):
         try:
             alg = ModelerAlgorithm.fromJsonFile(filename)
             return alg
-        except WrongModelException, e:
+        except WrongModelException as e:
             alg = ModelerAlgorithm.fromOldFormatFile(filename)
             return alg
 
-
     @staticmethod
     def fromOldFormatFile(filename):
         def _tr(s):
@@ -589,7 +584,7 @@ class ModelerAlgorithm(GeoAlgorithm):
                     line = lines.readline().strip('\n')
                     tokens = line.split(',')
                     model.addParameter(ModelerParameter(param,
-                                       QPointF( float(tokens[0]), float(tokens[1]))))
+                                       QPointF(float(tokens[0]), float(tokens[1]))))
                     modelParameters.append(param.name)
                 elif line.startswith('VALUE:'):
                     valueLine = line[len('VALUE:'):]
@@ -614,8 +609,8 @@ class ModelerAlgorithm(GeoAlgorithm):
                         for param in alg.parameters:
                             if not param.hidden:
                                 line = lines.readline().strip('\n').strip('\r')
-                                if line == str(None):
-                                    modelAlg.params[param.name]  = None
+                                if line == unicode(None):
+                                    modelAlg.params[param.name] = None
                                 else:
                                     tokens = line.split('|')
                                     algIdx = int(tokens[0])
@@ -630,12 +625,12 @@ class ModelerAlgorithm(GeoAlgorithm):
                         for out in alg.outputs:
                             if not out.hidden:
                                 line = lines.readline().strip('\n').strip('\r')
-                                if str(None) != line:
+                                if unicode(None) != line:
                                     if '|' in line:
                                         tokens = line.split('|')
                                         name = tokens[0]
                                         tokens = tokens[1].split(',')
-                                        pos = QPointF( float(tokens[0]), float(tokens[1]))
+                                        pos = QPointF(float(tokens[0]), float(tokens[1]))
                                     else:
                                         name = line
                                         pos = None
@@ -654,7 +649,7 @@ class ModelerAlgorithm(GeoAlgorithm):
                     if isinstance(value, ValueFromOutput):
                         value.alg = modelAlgs[value.alg]
             return model
-        except Exception, e:
+        except Exception as e:
             if isinstance(e, WrongModelException):
                 raise e
             else:
