@@ -1,6 +1,8 @@
 import inspect
 import string
 from qgis._core import *
+from PyQt4.QtCore import QCoreApplication
+
 
 def register_function(function, arg_count, group, usesgeometry=False, **kwargs):
     """
@@ -30,6 +32,7 @@ def register_function(function, arg_count, group, usesgeometry=False, **kwargs):
     :return:
     """
     class QgsExpressionFunction(QgsExpression.Function):
+
         def __init__(self, func, name, args, group, helptext='', usesgeometry=False, expandargs=False):
             QgsExpression.Function.__init__(self, name, args, group, helptext, usesgeometry)
             self.function = func
@@ -64,7 +67,10 @@ def register_function(function, arg_count, group, usesgeometry=False, **kwargs):
     register = kwargs.get('register', True)
     if register and QgsExpression.isFunctionName(name):
         if not QgsExpression.unregisterFunction(name):
-            raise TypeError("Unable to unregister function")
+            msgtitle = QCoreApplication.translate("UserExpressions", "User expressions")
+            msg = QCoreApplication.translate("UserExpressions", "The user expression {0} already exists and could not be unregistered.").format(name)
+            QgsMessageLog.logMessage(msg + "\n", msgtitle, QgsMessageLog.WARNING)
+            return None
 
     function.__name__ = name
     helptext = helptemplate.safe_substitute(name=name, doc=helptext)
@@ -100,3 +106,67 @@ def qgsfunction(args='auto', group='custom', **kwargs):
     def wrapper(func):
         return register_function(func, args, group, **kwargs)
     return wrapper
+
+try:
+    # Add a __nonzero__ method onto QPyNullVariant so we can check for null values easier.
+    #   >>> value = QPyNullVariant("int")
+    #   >>> if value:
+    #   >>>	  print "Not a null value"
+    from types import MethodType
+    from PyQt4.QtCore import QPyNullVariant
+
+    def __nonzero__(self):
+        return False
+
+    def __repr__(self):
+        return 'NULL'
+
+    def __eq__(self, other):
+        return isinstance(other, QPyNullVariant) or other is None
+
+    def __ne__(self, other):
+        return not isinstance(other, QPyNullVariant) and other is not None
+
+    def __hash__(self):
+        return 2178309
+
+    QPyNullVariant.__nonzero__ = MethodType(__nonzero__, None, QPyNullVariant)
+    QPyNullVariant.__repr__ = MethodType(__repr__, None, QPyNullVariant)
+    QPyNullVariant.__eq__ = MethodType(__eq__, None, QPyNullVariant)
+    QPyNullVariant.__ne__ = MethodType(__ne__, None, QPyNullVariant)
+    QPyNullVariant.__hash__ = MethodType(__hash__, None, QPyNullVariant)
+
+    NULL = QPyNullVariant(int)
+
+except ImportError:
+    pass
+
+
+class QgsEditError(Exception):
+
+    def __init__(self, value):
+        self.value = value
+
+    def __str__(self):
+        return repr(self.value)
+
+# Define a `with edit(layer)` statement
+
+
+class edit:
+
+    def __init__(self, layer):
+        self.layer = layer
+
+    def __enter__(self):
+        assert self.layer.startEditing()
+        return self.layer
+
+    def __exit__(self, ex_type, ex_value, traceback):
+        if ex_type is None:
+            if not self.layer.commitChanges():
+                raise QgsEditError(self.layer.commitErrors())
+            return True
+        else:
+            self.layer.rollBack()
+            return False
